@@ -8,7 +8,7 @@
 #  include <unistd.h>
 #endif
 
-/* last modified 09/16/98 */
+/* last modified 10/30/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -38,6 +38,8 @@
 *                                                                              *
 *   32 bits:  learned value (floating point).                                  *
 *                                                                              *
+*   32 bits:  CAP score for this move (integer).                               *
+*                                                                              *
 *     (note:  counts are normalized to a max of 255.                           *
 *                                                                              *
 ********************************************************************************
@@ -52,13 +54,13 @@ int Book(TREE *tree, int wtm, int root_list_done) {
   static int selected_order_played[200], selected_value[200];
   static int selected_status[200], selected_percent[200], book_development[200];
   static int bs_played[200], bs_percent[200];
-  static int book_status[200], evaluations[200], bs_learn[200];
+  static int book_status[200], evaluations[200], bs_learn[200], bs_CAP[200];
   static float bs_value[200], total_value;
   int m1_status, forced=0, total_percent;
   float tempr;
-  int done, i, j, last_move, temp, which, minlv=999999, maxlv=-999999;
-  int maxp=-999999, minev=999999, maxev=-999999;
-  int *mv, mp, value, np;
+  int done, i, j, last_move, temp, which, minlv=999999, maxlv=-999999, cap;
+  int mincap=999999, maxcap=-999999, maxp=-999999, minev=999999, maxev=-999999;
+  int im, value, np, book_ponder_move;
   int cluster, scluster, test;
   BITBOARD temp_hash_key, common;
   int key, nmoves, num_selected, st;
@@ -94,21 +96,21 @@ int Book(TREE *tree, int wtm, int root_list_done) {
       fseek(books_file,key,SEEK_SET);
       fread(&scluster,sizeof(int),1,books_file);
       fread(books_buffer,sizeof(BOOK_POSITION),scluster,books_file);
-      for (mv=tree->last[0];mv<tree->last[1];mv++) {
-        common=And(HashKey,mask_16);
-        MakeMove(tree,1,*mv,wtm);
+      for (im=0;im<n_root_moves;im++) {
+        common=HashKey & mask_16;
+        MakeMove(tree,1,root_moves[im].move,wtm);
         if (RepetitionCheck(tree,2,ChangeSide(wtm))) {
-          UnMakeMove(tree,1,*mv,wtm);
+          UnMakeMove(tree,1,root_moves[im].move,wtm);
           return(0);
         }
-        temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-        temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+        temp_hash_key=HashKey ^ wtm_random[wtm];
+        temp_hash_key=(temp_hash_key & ~mask_16) | common;
         for (i=0;i<scluster;i++)
-          if (!Xor(temp_hash_key,books_buffer[i].position)) {
+          if (!(temp_hash_key ^ books_buffer[i].position)) {
             start_moves[smoves++]=books_buffer[i];
             break;
           }
-        UnMakeMove(tree,1,*mv,wtm);
+        UnMakeMove(tree,1,root_moves[im].move,wtm);
       }
     }
   }
@@ -144,7 +146,7 @@ int Book(TREE *tree, int wtm, int root_list_done) {
 */
     for (i=0;i<smoves;i++) {
       for (j=0;j<cluster;j++) 
-        if (!Xor(book_buffer[j].position,start_moves[i].position)) break;
+        if (!(book_buffer[j].position ^ start_moves[i].position)) break;
       if (j >= cluster) {
         book_buffer[cluster]=start_moves[i];
         book_buffer[cluster].status_played=
@@ -161,46 +163,47 @@ int Book(TREE *tree, int wtm, int root_list_done) {
 |                                                          |
  ----------------------------------------------------------
 */
-    initial_development=(wtm) ? EvaluateDevelopment(tree,1) : 
-                               -EvaluateDevelopment(tree,1);
+    initial_development=(wtm) ? EvaluateDevelopmentW(tree,1) : 
+                                EvaluateDevelopmentB(tree,1);
     total_moves=0;
     nmoves=0;
-    for (mv=tree->last[0];mv<tree->last[1];mv++) {
-      common=And(HashKey,mask_16);
-      MakeMove(tree,1,*mv,wtm);
+    for (im=0;im<n_root_moves;im++) {
+      common=HashKey & mask_16;
+      MakeMove(tree,1,root_moves[im].move,wtm);
       if (RepetitionCheck(tree,2,ChangeSide(wtm))) {
-        UnMakeMove(tree,1,*mv,wtm);
+        UnMakeMove(tree,1,root_moves[im].move,wtm);
         return(0);
       }
-      temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-      temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+      temp_hash_key=HashKey ^ wtm_random[wtm];
+      temp_hash_key=(temp_hash_key & ~mask_16) | common;
       for (i=0;i<cluster;i++) {
-        if (!Xor(temp_hash_key,book_buffer[i].position)) {
+        if (!(temp_hash_key ^ book_buffer[i].position)) {
           book_status[nmoves]=book_buffer[i].status_played>>24;
           bs_played[nmoves]=book_buffer[i].status_played&077777777;
           bs_learn[nmoves]=(int) (book_buffer[i].learn*100.0);
+          bs_CAP[nmoves]=book_buffer[i].CAP_score;
           if (puzzling) bs_played[nmoves]+=1;
-          tree->current_move[1]=*mv;
-          if (!Captured(*mv)) 
-            book_development[nmoves]=((wtm) ? EvaluateDevelopment(tree,2) : 
-                  -EvaluateDevelopment(tree,2))-initial_development;
+          tree->current_move[1]=root_moves[im].move;
+          if (!Captured(root_moves[im].move)) 
+            book_development[nmoves]=((wtm) ? EvaluateDevelopmentW(tree,2) : 
+                  EvaluateDevelopmentB(tree,2))-initial_development;
           else book_development[nmoves]=0;
           total_moves+=bs_played[nmoves];
           evaluations[nmoves]=Evaluate(tree,2,wtm,-999999,999999);
           evaluations[nmoves]-=(wtm) ? Material : -Material;
           bs_percent[nmoves]=0;
           for (j=0;j<smoves;j++) {
-            if (!Xor(book_buffer[i].position,start_moves[j].position)) {
+            if (!(book_buffer[i].position ^ start_moves[j].position)) {
               book_status[nmoves]|=start_moves[j].status_played>>24;
               bs_percent[nmoves]=start_moves[j].status_played&077777777;
               break;
             }
           }
-          book_moves[nmoves++]=*mv;
+          book_moves[nmoves++]=root_moves[im].move;
           break;
         }
       }
-      UnMakeMove(tree,1,*mv,wtm);
+      UnMakeMove(tree,1,root_moves[im].move,wtm);
     }
     if (!nmoves) return(0);
 /*
@@ -215,17 +218,27 @@ int Book(TREE *tree, int wtm, int root_list_done) {
     for (i=0;i<nmoves;i++) {
       minlv=Min(minlv,bs_learn[i]);
       maxlv=Max(maxlv,bs_learn[i]);
+      if (bs_CAP[i] != -2*MATE) mincap=Min(mincap,bs_CAP[i]);
+      if (bs_CAP[i] != -2*MATE) maxcap=Max(maxcap,bs_CAP[i]);
       minev=Min(minev,evaluations[i]);
       maxev=Max(maxev,evaluations[i]);
       maxp=Max(maxp,bs_played[i]);
     }
+    if (mincap == -2*MATE) mincap=0;
+    if (maxcap < 0) maxcap=0;
     maxp++;
     for (i=0;i<nmoves;i++) {
+      cap=0;
       bs_value[i]=1;
       bs_value[i]+=bs_played[i]/(float) maxp*1000.0*book_weight_freq;
       if (minlv < maxlv)
         bs_value[i]+=(bs_learn[i]-minlv)/
                      (float) (Max(maxlv-minlv,50))*1000.0*book_weight_learn;
+      if (bs_CAP[i]!=-2*MATE) {
+        cap=bs_CAP[i];
+        bs_value[i]+=(cap-mincap)/
+                     (float) (Max(maxcap-mincap,50))*1000.0*book_weight_CAP;
+      }
       if (minev < maxev)
         bs_value[i]+=(evaluations[i]-minev)/(float)(Max(maxev-minev,50))*
                      1000.0*book_weight_eval;
@@ -248,9 +261,14 @@ int Book(TREE *tree, int wtm, int root_list_done) {
       if (!wtm && !(book_status[i]&040) && !bs_percent[i] &&
           !(book_status[i] & 030)) book_status[i]|=BAD_MOVE;
       if (bs_played[i] < maxp/10 && !bs_percent[i] && book_random &&
-          !(book_status[i] & 030)) book_status[i]|=BAD_MOVE;
+          !(book_status[i] & 030) && bs_CAP[i]==-2*MATE)
+        book_status[i]|=BAD_MOVE;
       if (bs_learn[i] >= LEARN_COUNTER_GOOD &&
           !(book_status[i] & 003)) book_status[i]|=GOOD_MOVE;
+      if (bs_CAP[i]>=CAP_SCORE_GOOD &&
+          !(book_status[i] & 003)) book_status[i]|=GOOD_MOVE;
+      if (bs_CAP[i]<=CAP_SCORE_BAD && bs_CAP[i]!=-2*MATE &&
+          !(book_status[i]&003)) book_status[i]|=BAD_MOVE;
       if (bs_percent[i]) book_status[i]|=GOOD_MOVE;
     }
 /*
@@ -261,10 +279,13 @@ int Book(TREE *tree, int wtm, int root_list_done) {
 |                                                          |
  ----------------------------------------------------------
 */
-    mp=0;
-    for (i=0;i<nmoves;i++) {
-      if (book_status[i] & 030) bs_value[i]+=8000.0;
-      if (!(book_status[i] & 003)) bs_value[i]+=4000.0;
+    for (i=0;i<nmoves;i++) 
+      if (book_status[i] & 030) break;
+    if (i < nmoves) {
+      for (i=0;i<nmoves;i++) {
+        if (book_status[i] & 030) bs_value[i]+=8000.0;
+        if (!(book_status[i] & 003)) bs_value[i]+=4000.0;
+      }
     }
 /*
  ----------------------------------------------------------
@@ -291,6 +312,9 @@ int Book(TREE *tree, int wtm, int root_list_done) {
             temp=bs_learn[i];
             bs_learn[i]=bs_learn[i+1];
             bs_learn[i+1]=temp;
+            temp=bs_CAP[i];
+            bs_CAP[i]=bs_CAP[i+1];
+            bs_CAP[i+1]=temp;
             temp=book_development[i];
             book_development[i]=book_development[i+1];
             book_development[i+1]=temp;
@@ -317,7 +341,7 @@ int Book(TREE *tree, int wtm, int root_list_done) {
 */
     if (show_book) {
       Print(128,"  after screening, the following moves can be played\n");
-      Print(128,"  move     played    %%  score    learn     sortv  P%%  P\n");
+      Print(128,"  move     played    %%  score    learn     CAP     sortv  P%%  P\n");
       for (i=0;i<nmoves;i++) {
         Print(128,"%6s", OutputMove(tree,book_moves[i],1,wtm));
         st=book_status[i];
@@ -333,6 +357,7 @@ int Book(TREE *tree, int wtm, int root_list_done) {
         Print(128,"  %3d",100*bs_played[i]/Max(total_moves,1));
         Print(128,"%s",DisplayEvaluation(evaluations[i]));
         Print(128,"%9.2f",(float)bs_learn[i]/100.0);
+        Print(128,"%9.2f",(float)bs_CAP[i]/100.0);
         Print(128," %9.1f",bs_value[i]);
         Print(128," %3d",bs_percent[i]);
         if ((book_status[i]&book_accept_mask &&
@@ -528,7 +553,7 @@ int Book(TREE *tree, int wtm, int root_list_done) {
  ----------------------------------------------------------
 */
     if (show_book) {
-      Print(128,"  move     played    %%  score    learn     sortv  P%%  P\n");
+      Print(128,"  move     played    %%  score     sortv  P%%  P\n");
       for (i=0;i<nmoves;i++) {
         Print(128,"%6s", OutputMove(tree,book_moves[i],1,wtm));
         st=book_status[i];
@@ -543,7 +568,6 @@ int Book(TREE *tree, int wtm, int root_list_done) {
         Print(128,"   %6d",bs_played[i]);
         Print(128,"  %3d",100*bs_played[i]/Max(total_moves,1));
         Print(128,"%s",DisplayEvaluation(evaluations[i]));
-        Print(128,"%9.2f",(float)bs_learn[i]/100.0);
         Print(128," %9.1f",bs_value[i]);
         Print(128," %3d",bs_percent[i]);
         if ((book_status[i]&book_accept_mask &&
@@ -570,20 +594,26 @@ int Book(TREE *tree, int wtm, int root_list_done) {
       if (!puzzling && (!book_random ||
                        (mode==tournament_mode && np<book_search_trigger))) {
         if (!forced) {
-          for (i=0;i<nmoves;i++) *(tree->last[0]+i)=book_moves[i];
-          tree->last[1]=tree->last[0]+nmoves;
-          last_pv.path_iteration_depth=0;
+          n_root_moves=nmoves;
+          for (i=0;i<n_root_moves;i++) {
+            root_moves[i].move=book_moves[i];
+            root_moves[i].nodes=0;
+            root_moves[i].status=0;
+          }
+          last_pv.pathd=0;
           booking=1;
           value=Iterate(wtm,booking,1);
           booking=0;
-          if (value <- 50) {
-            last_pv.path_iteration_depth=0;
+          abort_search=0;
+          if (value < -50) {
+            last_pv.pathd=0;
             return(0);
           }
         }
         else {
           tree->pv[1].path[1]=book_moves[0];
-          tree->pv[1].path_length=1;
+          tree->pv[1].pathl=1;
+          tree->pv[1].pathd=0;
         }
         return(1);
       }
@@ -601,23 +631,24 @@ int Book(TREE *tree, int wtm, int root_list_done) {
 */
     else if (mode==tournament_mode && puzzling && !auto232) {
       RootMoveList(wtm);
-      for (i=0;i<(tree->last[1]-tree->last[0]);i++)
+      for (i=0;i<n_root_moves;i++)
         for (j=0;j<nmoves;j++)
-          if (*(tree->last[0]+i)==book_moves[j]) *(tree->last[0]+i)=0;
-      for (i=0,j=0;i<(tree->last[1]-tree->last[0]);i++)
-        if (*(tree->last[0]+i) != 0) *(tree->last[0]+j++)=*(tree->last[0]+i);
-      tree->last[1]=tree->last[0]+j;
+          if (root_moves[i].move==book_moves[j]) root_moves[i].move=0;
+      for (i=0,j=0;i<n_root_moves;i++)
+        if (root_moves[i].move != 0) root_moves[j++]=root_moves[i];
+      n_root_moves=j;
       Print(128,"               moves considered {only non-book moves}\n");
       nmoves=j;
       if (nmoves > 1) {
-        last_pv.path_iteration_depth=0;
+        last_pv.pathd=0;
         booking=1;
         (void) Iterate(wtm,booking,1);
         booking=0;
       }
       else {
         tree->pv[1].path[1]=book_moves[0];
-        tree->pv[1].path_length=1;
+        tree->pv[1].pathl=1;
+        tree->pv[1].pathd=0;
       }
       return(1);
     }
@@ -650,8 +681,13 @@ int Book(TREE *tree, int wtm, int root_list_done) {
     percent_played=100*bs_played[which]/Max(total_played,1);
     total_played=bs_played[which];
     m1_status=book_status[which];
-    tree->pv[1].path_length=1;
+    tree->pv[1].pathl=1;
+    tree->pv[1].pathd=0;
     MakeMove(tree,1,book_moves[which],wtm);
+    if ((book_ponder_move=BookPonderMove(tree,ChangeSide(wtm)))) {
+      tree->pv[1].path[2]=book_ponder_move;
+      tree->pv[1].pathl=2;
+    }
     UnMakeMove(tree,1,book_moves[which],wtm);
     Print(128,"               book   0.0s    %3d%%   ", percent_played);
     Print(128," %s",OutputMove(tree,tree->pv[1].path[1],1,wtm));
@@ -663,13 +699,90 @@ int Book(TREE *tree, int wtm, int root_list_done) {
       else if (st & 8) Print(128,"!");
       else if (st & 16) Print(128,"!!");
     }
+    MakeMove(tree,1,tree->pv[1].path[1],wtm);
+    if (tree->pv[1].pathl>1)
+      Print(128," %s",OutputMove(tree,tree->pv[1].path[2],2,ChangeSide(wtm)));
+    UnMakeMove(tree,1,tree->pv[1].path[1],wtm);
     Print(128,"\n");
     return(1);
   }
   return(0);
 }
 
-/* last modified 08/22/98 */
+/* last modified 09/27/99 */
+/*
+********************************************************************************
+*                                                                              *
+*   BookPonderMove() is used to find a move to ponder, to avoid the overhead   *
+*   of a "puzzling" search early in the game (unless there are no book moves   *
+*   found, of course.)  the algorithm is much simpler than the normal book     *
+*   move code...  just find the move with the largest frequency counter and    *
+*   assume that will be played.                                                *
+*                                                                              *
+********************************************************************************
+*/
+int BookPonderMove(TREE *tree, int wtm) {
+
+  BITBOARD temp_hash_key, common, test;
+  static int book_moves[200];
+  int i, key, *lastm, cluster, n_moves, im, played, tplayed;
+  int book_ponder_move=0;
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   position is known, read in the appropriate cluster.    |
+|   note that this cluster will have all possible book     |
+|   moves from current position in it (as well as others   |
+|   of course.)                                            |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  if (book_file) {
+    test=HashKey>>49;
+    fseek(book_file,test*sizeof(int),SEEK_SET);
+    fread(&key,sizeof(int),1,book_file);
+    if (key > 0) {
+      fseek(book_file,key,SEEK_SET);
+      fread(&cluster,sizeof(int),1,book_file);
+      fread(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
+    }
+    else cluster=0;
+    if (!cluster) return(0);
+    lastm=GenerateCaptures(tree, 2, wtm, book_moves);
+    lastm=GenerateNonCaptures(tree, 2, wtm, lastm);
+    n_moves=lastm-book_moves;
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   first cycle through the root move list, make each      |
+|   move, and see if the resulting hash key is in the book |
+|   database.                                              |
+|                                                          |
+ ----------------------------------------------------------
+*/
+    played=-1;
+    for (im=0;im<n_moves;im++) {
+      common=HashKey & mask_16;
+      MakeMove(tree,2,book_moves[im],wtm);
+      temp_hash_key=HashKey ^ wtm_random[wtm];
+      temp_hash_key=(temp_hash_key & ~mask_16) | common;
+      for (i=0;i<cluster;i++) {
+        if (!(temp_hash_key ^ book_buffer[i].position)) {
+          tplayed=book_buffer[i].status_played&077777777;
+          if (tplayed > played) {
+            played=tplayed;
+            book_ponder_move=book_moves[im];
+          }
+          break;
+        }
+      }
+      UnMakeMove(tree,2,book_moves[im],wtm);
+    }
+  }
+  return(book_ponder_move);
+}
+
+/* last modified 09/30/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -722,7 +835,8 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
   BB_POSITION *bbuffer;
   BITBOARD temp_hash_key, common;
   FILE *book_input;
-  char fname[64], *start, *ch, schar[2]={"."};
+  char fname[128], start, *ch;
+  static char schar[2]={"."};
   int result=0, played, i, mask_word, total_moves;
   int move, move_num, wtm, book_positions, major, minor;
   int cluster, max_cluster, discarded=0, discarded_mp=0, discarded_lose=0;
@@ -792,10 +906,12 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
     else if (!strcmp(args[1],"accept")) {
       book_accept_mask=BookMask(args[2]);
       book_reject_mask=book_reject_mask & ~book_accept_mask;
+      return;
     }
     else if (!strcmp(args[1],"reject")) {
       book_reject_mask=BookMask(args[2]);
       book_accept_mask=book_accept_mask & ~book_reject_mask;
+      return;
     }
   }
   else if (!strcmp(args[0],"random")) {
@@ -845,6 +961,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
     return;
   }
   InitializeChessBoard(&tree->position[1]);
+  ReadPGN(0,0);
   cp_save=tree->pos;
   sp_save=tree->position[1];
   if (book_file) fclose(book_file);
@@ -870,7 +987,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
 |                                                          |
  ----------------------------------------------------------
 */
-  start=strstr(output_filename,"books.bin");
+  start=!strstr(output_filename,"book.bin");
   printf("parsing pgn move file (10000 moves/dot)\n");
   start_cpu_time=ReadClock(cpu);
   start_elapsed_time=ReadClock(elapsed);
@@ -920,12 +1037,12 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
               ply++;
               max_search_depth=Max(max_search_depth,ply);
               total_moves++;
-              common=And(HashKey,mask_16);
+              common=HashKey & mask_16;
               MakeMove(tree,2,move,wtm);
               tree->position[2]=tree->position[3];
               if (ply <= max_ply) {
-                temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-                temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+                temp_hash_key=HashKey ^ wtm_random[wtm];
+                temp_hash_key=(temp_hash_key & ~mask_16) | common;
                 memcpy(bbuffer[buffered].position,(char*)&temp_hash_key,8);
                 if (result == 0) mask_word|=0100;
                 else if (result&2) mask_word|=0200;
@@ -975,6 +1092,10 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
     if (buffered) BookSort(bbuffer,buffered,++files);
     free(bbuffer);
     printf("S  <done>\n");
+    if (total_moves == 0) {
+      Print(4095, "ERROR - empty input PGN file\n");
+      return;
+    }
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -986,7 +1107,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
 */
     printf("merging sorted files (%d) (10K/dot)\n",files);
     counter=0;
-    index=malloc(32768*sizeof(int));
+    index=(int *) malloc(32768*sizeof(int));
     if (!index) {
       Print(4095,"Unable to malloc() index block, aborting\n");
       exit(1);
@@ -998,6 +1119,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
     if (start) current.status_played+=temp.percent_play;
     current.learn=0.0;
     played=1;
+    fclose(book_file);
     book_file=fopen(output_filename,"wb+");
     fseek(book_file,sizeof(int)*32768,SEEK_SET);
     last=current.position>>49;
@@ -1019,6 +1141,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
       next.status_played=temp.status<<24;
       if (start) next.status_played+=temp.percent_play&127;
       next.learn=0.0;
+      next.CAP_score=-MATE*2;
       counter++;
       if (counter%10000 == 0) {
         printf(".");
@@ -1040,6 +1163,7 @@ void BookUp(TREE *tree, char *output_filename, int nargs, char **args) {
           max_cluster=Max(max_cluster,cluster);
           if (!start) current.status_played+=played;
           current.learn=0.0;
+          current.CAP_score=-MATE*2;
           stat=fwrite(&current,sizeof(BOOK_POSITION),1,book_file);
           if (stat != 1)
             Print(4095,"ERROR!  write failed, disk probably full.\n");
@@ -1193,7 +1317,7 @@ BB_POSITION BookUpNextPosition(int files, int init) {
         printf("unable to open sort.%d file, may be too many files open.\n",i);
         exit(1);
       }
-      buffer[i]=malloc(sizeof(BB_POSITION)*MERGE_BLOCK);
+      buffer[i]=(BB_POSITION *) malloc(sizeof(BB_POSITION)*MERGE_BLOCK);
       if (!buffer[i]) {
         printf("out of memory.  aborting. \n");
         exit(1);
