@@ -735,275 +735,6 @@ typedef struct gamS
 	struct gamS *gam_next;          /* next game */
 	} gamT, *gamptrT;
 
-/* tablebase byte entry semispan length */
-
-#define tbbe_ssL (((bit << byteW) - 4) / 2)
-
-/* the signed byte evaulation type */
-
-typedef signed char bevT, *bevptrT;
-
-/* tablebase signed byte entry values */
-
-#define bev_broken   (tbbe_ssL + 1)  /* illegal or busted */
-
-#define bev_mi1      tbbe_ssL        /* mate in 1 move */
-#define bev_mimin    1               /* mate in 126 moves */
-
-#define bev_draw     0               /* draw */
-
-#define bev_limax    (-1)            /* mated in 125 moves */
-#define bev_li0      (-tbbe_ssL)     /* mated in 0 moves */
-
-#define bev_reserved (-tbbe_ssL - 1) /* reserved */
-#define bev_unknown  (-tbbe_ssL - 2) /* unknown */
-
-/* signed byte entry range testing macros */
-
-#define tbe_mating(bev) \
-	(((bev) >= bev_mimin) && ((bev) <= bev_mi1))
-
-#define tbe_losing(bev) \
-	(((bev) >= bev_li0) && ((bev) <= bev_limax))
-
-#define tbe_wld(bev) \
-	(((bev) >= bev_li0) && ((bev) <= bev_mi1))
-
-#define tbe_special(bev) \
-	(((bev) < bev_li0) || ((bev) > bev_mi1))
-
-/* tablebase piece limits */
-
-#define tbmecL 4 /* either color by itself */
-#define tbmbcL 5 /* both colors combined */
-
-/* tablebase class identifiers */
-
-typedef siT tbidT, *tbidptrT;
-#define tbidL 146
-#define tbid_nil (-1)
-
-#define tbid_kk      0
-#define tbid_kpk     1
-#define tbid_knk     2
-#define tbid_kbk     3
-#define tbid_krk     4
-#define tbid_kqk     5
-#define tbid_kpkp    6
-#define tbid_knkp    7
-#define tbid_knkn    8
-#define tbid_kbkp    9
-#define tbid_kbkn   10
-#define tbid_kbkb   11
-#define tbid_krkp   12
-#define tbid_krkn   13
-#define tbid_krkb   14
-#define tbid_krkr   15
-#define tbid_kqkp   16
-#define tbid_kqkn   17
-#define tbid_kqkb   18
-#define tbid_kqkr   19
-#define tbid_kqkq   20
-#define tbid_kppk   21
-#define tbid_knpk   22
-#define tbid_knnk   23
-#define tbid_kbpk   24
-#define tbid_kbnk   25
-#define tbid_kbbk   26
-#define tbid_krpk   27
-#define tbid_krnk   28
-#define tbid_krbk   29
-#define tbid_krrk   30
-#define tbid_kqpk   31
-#define tbid_kqnk   32
-#define tbid_kqbk   33
-#define tbid_kqrk   34
-#define tbid_kqqk   35
-#define tbid_kppkp  36
-#define tbid_kppkn  37
-#define tbid_kppkb  38
-#define tbid_kppkr  39
-#define tbid_kppkq  40
-#define tbid_knpkp  41
-#define tbid_knpkn  42
-#define tbid_knpkb  43
-#define tbid_knpkr  44
-#define tbid_knpkq  45
-#define tbid_knnkp  46
-#define tbid_knnkn  47
-#define tbid_knnkb  48
-#define tbid_knnkr  49
-#define tbid_knnkq  50
-#define tbid_kbpkp  51
-#define tbid_kbpkn  52
-#define tbid_kbpkb  53
-#define tbid_kbpkr  54
-#define tbid_kbpkq  55
-#define tbid_kbnkp  56
-#define tbid_kbnkn  57
-#define tbid_kbnkb  58
-#define tbid_kbnkr  59
-#define tbid_kbnkq  60
-#define tbid_kbbkp  61
-#define tbid_kbbkn  62
-#define tbid_kbbkb  63
-#define tbid_kbbkr  64
-#define tbid_kbbkq  65
-#define tbid_krpkp  66
-#define tbid_krpkn  67
-#define tbid_krpkb  68
-#define tbid_krpkr  69
-#define tbid_krpkq  70
-#define tbid_krnkp  71
-#define tbid_krnkn  72
-#define tbid_krnkb  73
-#define tbid_krnkr  74
-#define tbid_krnkq  75
-#define tbid_krbkp  76
-#define tbid_krbkn  77
-#define tbid_krbkb  78
-#define tbid_krbkr  79
-#define tbid_krbkq  80
-#define tbid_krrkp  81
-#define tbid_krrkn  82
-#define tbid_krrkb  83
-#define tbid_krrkr  84
-#define tbid_krrkq  85
-#define tbid_kqpkp  86
-#define tbid_kqpkn  87
-#define tbid_kqpkb  88
-#define tbid_kqpkr  89
-#define tbid_kqpkq  90
-#define tbid_kqnkp  91
-#define tbid_kqnkn  92
-#define tbid_kqnkb  93
-#define tbid_kqnkr  94
-#define tbid_kqnkq  95
-#define tbid_kqbkp  96
-#define tbid_kqbkn  97
-#define tbid_kqbkb  98
-#define tbid_kqbkr  99
-#define tbid_kqbkq 100
-#define tbid_kqrkp 101
-#define tbid_kqrkn 102
-#define tbid_kqrkb 103
-#define tbid_kqrkr 104
-#define tbid_kqrkq 105
-#define tbid_kqqkp 106
-#define tbid_kqqkn 107
-#define tbid_kqqkb 108
-#define tbid_kqqkr 109
-#define tbid_kqqkq 110
-#define tbid_kpppk 111
-#define tbid_knppk 112
-#define tbid_knnpk 113
-#define tbid_knnnk 114
-#define tbid_kbppk 115
-#define tbid_kbnpk 116
-#define tbid_kbnnk 117
-#define tbid_kbbpk 118
-#define tbid_kbbnk 119
-#define tbid_kbbbk 120
-#define tbid_krppk 121
-#define tbid_krnpk 122
-#define tbid_krnnk 123
-#define tbid_krbpk 124
-#define tbid_krbnk 125
-#define tbid_krbbk 126
-#define tbid_krrpk 127
-#define tbid_krrnk 128
-#define tbid_krrbk 129
-#define tbid_krrrk 130
-#define tbid_kqppk 131
-#define tbid_kqnpk 132
-#define tbid_kqnnk 133
-#define tbid_kqbpk 134
-#define tbid_kqbnk 135
-#define tbid_kqbbk 136
-#define tbid_kqrpk 137
-#define tbid_kqrnk 138
-#define tbid_kqrbk 139
-#define tbid_kqrrk 140
-#define tbid_kqqpk 141
-#define tbid_kqqnk 142
-#define tbid_kqqbk 143
-#define tbid_kqqrk 144
-#define tbid_kqqqk 145
-
-/* tablebase fold modes */
-
-typedef siT foldT;
-#define foldL 2
-#define fold_nil (-1)
-
-#define fold_flank    0
-#define fold_triangle 1
-
-#define ff_flankL    (sqL / 2)
-#define ff_triangleL (((rankL * rankL) + (rankL * 2)) / 8)
-
-/* tablebase flags */
-
-#define tbf_has_pawns      bit_00
-#define tbf_has_white_pawn bit_01
-#define tbf_has_black_pawn bit_02
-#define tbf_ep_captures    bit_03
-#define tbf_fold_triangle  bit_04
-#define tbf_fold_flank     bit_05
-
-/* piece distribution type */
-
-typedef siT distvT[rcL][rpL];
-
-/* position vector type */
-
-typedef sqT posvT[rcL][tbmecL];
-
-/* file indexing type */
-
-typedef liT indexT, *indexptrT;
-
-/* the tablebase master vector entry */
-
-typedef struct tbS
-	{
-	charptrT tb_name;                /* class name */
-	siT      tb_flags;               /* flag bits */
-	foldT    tb_fold;                /* fold mode */
-	cT       tb_pivot_c;             /* pivot color */
-	siT      tb_pivot_slot;          /* pivot slot within color */
-	siT      tb_count;               /* man count */
-	indexT   tb_length;              /* length of file */
-	siT      tb_mcv[rcL];            /* man count per color */
-	distvT   tb_distv;               /* piece distribution */
-	liT      tb_sig0;                /* distribution signature */
-	liT      tb_sig1;                /* inverted distribution signature */
-	pT       tb_pv[rcL][tbmecL];     /* pieces */
-	cpT      tb_cpv[rcL][tbmecL];    /* color-pieces */
-	siT      tb_scalev[rcL][tbmecL]; /* scale factors */
-	liT      tb_multv[rcL][tbmecL];  /* multipliers */
-	} tbT, *tbptrT;
-
-/* reflection macros */
-
-#define reflect_x(sq) ((sq) ^ 0x38)
-#define reflect_y(sq) ((sq) ^ 0x07)
-#define reflect_xy(sq) ((((sq) >> 3) & 0x07) | (((sq) << 3) & 0x38))
-
-/* tablebase file pointer cache limit (max simul open files) */
-
-#define tbcL 8
-
-/* tablebase file pointer cache entry type  */
-
-typedef struct tbcS
-	{
-	siT   tbc_inuse; /* entry in use flag */
-	tbidT tbc_tbid;  /* tablebase class ID */
-	cT    tbc_c;     /* color selector for class file pair */
-	fptrT tbc_fptr;  /* pointer to the open file */
-	} tbcT, *tbcptrT;
-
 /* statndard disply output column limit */
 
 #define columnL 80
