@@ -821,15 +821,15 @@ for (index = 0; index < (sqL * sqL); index++)
 /* clear the host killer information */
 
 for (index = 0; index < MAXPLY; index++) {
-  tree->killer_move1[index] = 0;
-  tree->killer_move2[index] = 0;
+  tree->killers[index].move1 = 0;
+  tree->killers[index].move2 = 0;
 }
 
 /* clear miscellaneous host items */
 
 ponder_move = 0;
-last_pv.path_iteration_depth = 0;
-last_pv.path_length = 0;
+last_pv.pathd = 0;
+last_pv.pathl = 0;
 over = 0;
 
 return;
@@ -991,9 +991,9 @@ if (EPDFetchMoveCount() == 1)
 
 	/* set Iterate() result variables */
 
-	tree->pv[0].path_hashed = 0;
-	tree->pv[0].path_length = 1;
-	tree->pv[0].path_iteration_depth = 1;
+	tree->pv[0].pathh = 0;
+	tree->pv[0].pathl = 1;
+	tree->pv[0].pathd = 1;
 	tree->pv[0].path[1] = move;
 	}
 else
@@ -1208,8 +1208,8 @@ switch (EPDExtractRefcomIndex(epdptr0))
 
 			ponder_move = 0;
 			thinking = 1;
-			last_pv.path_iteration_depth = 0;
-			last_pv.path_length = 0;
+			last_pv.pathd = 0;
+			last_pv.pathl = 0;
 			tree->position[1] = tree->position[0];
 
 			/* search */
@@ -1284,8 +1284,8 @@ switch (EPDExtractRefcomIndex(epdptr0))
 		ponder = 0;
 		ponder_move = 0;
 
-		last_pv.path_iteration_depth = 0;
-		last_pv.path_length = 0;
+		last_pv.pathd = 0;
+		last_pv.pathl = 0;
 
 		InitializeChessBoard(&tree->position[0]);
 		InitializeHashTables();
@@ -1329,42 +1329,6 @@ if (!(*flagptr))
 return (epdptr1);
 }
 
-/*--> EGTBScore: fetch a tablebase score for the indicated position */
-nonstatic
-int
-EGTBScore(TREE *tree, int posdex, int active, int *scoreptr)
-{
-siT flag;
-cpevT cpev;
-
-/* this routine is called from Crafty at various points in the search */
-
-/* set default return value: score unfound */
-
-flag = 0;
-*scoreptr = 0;
-
-/* copy the indexed host position as the EPD Kit new current position */
-
-EGGetIndexedHostPosition(tree, (siT)posdex, active);
-
-/* perform the probe */
-
-cpev = EPDTBScore();
-if (cpev != cpev_wrck)
-	{
-	/* set return value */
-
-	flag = 1;
-
-	/* convert and copy score */
-
-	*scoreptr = EGMapToHostScore(cpev);
-	};
-
-return (flag);
-}
-
 /*--> EGProcessAPGN: process the EG command epdapgn */
 static
 siT
@@ -1525,152 +1489,6 @@ if (fptr1 != NULL)
 return (flag);
 }
 
-/*--> EGProcessCERT: process the EG command epdcert */
-static
-siT
-EGProcessCERT(void)
-{
-siT flag;
-siT done;
-cpevT cpev=0;
-mptrT mptr;
-mT m;
-sanT san;
-
-/* this is an internal EPD glue routine */
-
-/* set the default return value: success */
-
-flag = 1;
-
-/* clear the completion flag */
-
-done = 0;
-
-/* parameter count check */
-
-if (EPDTokenCount() != 1)
-	{
-	EGPL("This command takes no parameters.");
-	flag = 0;
-	};
-
-/* process the epdcert command */
-
-if (flag)
-	{
-	/* copy the host position into the EPD Kit */
-
-	EGGetHostPosition();
-
-	/* check for legality */
-
-	if (!EPDIsLegal())
-		{
-		EGPL("This position is illegal.");
-		done = 1;
-		flag = 0;
-		};
-
-	/* check for checkmate */
-
-	if (flag && !done)
-		if (EPDIsCheckmate())
-			{
-			sprintf(tbufv, "%s is checkmated.\n",
-				EPDPlayerString(EPDFetchACTC()));
-			EGPrintTB();
-			cpev = synth_loss(0);
-			done = 1;
-			};
-
-	/* check for stalemate */
-
-	if (flag && !done)
-		if (EPDIsStalemate())
-			{
-			sprintf(tbufv, "%s is stalemated.\n",
-				EPDPlayerString(EPDFetchACTC()));
-			EGPrintTB();
-			cpev = cpev_draw;
-			done = 1;
-			};
-
-	/* check for insufficient material */
-
-	if (flag && !done)
-		if (EPDIsInsufficientMaterial())
-			{
-			EGPL("Position is drawn: insufficient mating material.");
-			cpev = cpev_draw;
-			done = 1;
-			};
-
-	/* check for mate in one */
-
-	if (flag && !done)
-		if ((mptr = EPDMateInOne()) != NULL)
-			{
-			m = *mptr;
-			EPDSANEncode(&m, san);
-			sprintf(tbufv, "%s can checkmate in one move with %s.\n",
-				EPDPlayerString(EPDFetchACTC()), san);
-			EGPrintTB();
-			cpev = synth_mate(1);
-			done = 1;
-			};
-
-	/* probe the tablebases */
-
-	if (flag && !done)
-		{
-		cpev = EPDTBScore();
-		if (cpev != cpev_wrck)
-			{
-			EGPL("The position score was located in a tablebase file.");
-			if (cpev == cpev_draw)
-				EGPL("The position is a draw with best play.");
-			else
-				if (forced_mate(cpev))
-					{
-					sprintf(tbufv, "%s can mate in %hd move%s.\n",
-						EPDPlayerString(EPDFetchACTC()),
-						synth_distance_mate(cpev),
-						((synth_distance_mate(cpev) == 1) ? "" : "s"));
-					EGPrintTB();
-					}
-				else
-					{
-					sprintf(tbufv, "%s can be mated in %hd move%s.\n",
-						EPDPlayerString(EPDFetchACTC()),
-						synth_distance_loss(cpev),
-						((synth_distance_loss(cpev) == 1) ? "" : "s"));
-					EGPrintTB();
-					};
-			done = 1;
-			};
-		};
-
-	/* output score if available */
-
-	if (flag && done)
-		{
-		/* output score */
-
-		sprintf(tbufv, "Centipawn evaluation: %hd\n", cpev);
-		EGPrintTB();
-		}
-	else
-		{
-		/* output diagnostic */
-
-		EGPL("No certain evaluation is available.");
-		};
-	};
-
-return (flag);
-}
-
 /*--> EGProcessCICS: process the EG command epdcics */
 static
 siT
@@ -2791,7 +2609,7 @@ if (flag)
 				EPDDropIfLocEOPCode(epdptr, epdso_pv);
 				eopptr = EPDCreateEOPCode(epdso_pv);
 
-				for (index = 1; index <= (int) tree->pv[0].path_length; index++)
+				for (index = 1; index <= (int) tree->pv[0].pathl; index++)
 					{
 					/* generate moves for the current position */
 
@@ -2835,6 +2653,7 @@ if (flag)
 
 				s = EPDEncode(epdptr);
 				fprintf(fptr1, "%s\n", s);
+				fflush(fptr1);
 				EPDMemoryFree(s);
 				};
 
@@ -3355,47 +3174,6 @@ if (flag)
 return (flag);
 }
 
-/*--> EGCommandParmCount: return parameter count for a command */
-nonstatic
-int
-EGCommandParmCount(char *s)
-{
-siT count;
-egcommT egcomm;
-
-/* this is called by Option() in option.c */
-
-/*
-This routine is required for interfacing with Crafty to support EPD glue
-command line construction.  Because Crafty only distributes command input
-one token at a time, it is necessary to have input processor code in
-Option() assemble an EPD glue command line complete with parameter tokens.
-To assist with this task, the code in Option has to have a way of knowing
-how many parameters are associated with a given EPD glue command.
-
-Note that the Crafty is unable to uniformly process commands that have a
-variable number of parameters.  This is why every EPD glue command
-parameter count in this integration is fixed for the corresponding command.
-
-Other implementations may send an entire command text line.  This is a
-simpler approach and also easily supports having a variable number of
-parameters for EPD glue commands.  For these other implementations, the
-driver code in the host program need only call the EGCommand() routine
-with the whole command input string as the single EGCommand() parameter.
-*/
-
-/* get command index */
-
-egcomm = EGLocateCommand(s);
-
-if (egcomm == egcomm_nil)
-	count = 0;
-else
-	count = egparmcountv[egcomm];
-
-return (count);
-}
-
 /*--> EGCommandCheck: check if a string starts with an EPD command token */
 nonstatic
 int
@@ -3500,10 +3278,6 @@ else
 			flag = EGProcessBFIX();
 			break;
 
-		case egcomm_epdcert:
-			flag = EGProcessCERT();
-			break;
-
 		case egcomm_epdcics:
 			flag = EGProcessCICS();
 			break;
@@ -3616,9 +3390,6 @@ nonstatic
 void
 EGInit(void)
 {
-tbidT tbid;
-cT c;
-siT count;
 
 /* this is called by Initialize() in init.c */
 
@@ -3719,31 +3490,6 @@ egparmcountv[egcomm_epdtest] = 1;
 
 default_gamptr = EPDGameOpen();
 
-/* tablebase survey */
-
-count = 0;
-for (tbid = 0; tbid < tbidL; tbid++)
-	for (c = c_w; c <= c_b; c++)
-		if (EPDTBIsFilePresent(tbid, c))
-			count++;
-
-if (count == 0)
-	{
-#ifdef DEBUG
-	sprintf(tbufv,
-		"No tablebase files found in the %s directory.\n",
-		tb_path);
-	EGPrintTB();
-#endif /* DEBUG */
-	}
-else
-	{
-	sprintf(tbufv,
-		"%hd tablebase file(s) found in the %s directory.\n",
-		count, tb_path);
-	EGPrintTB();
-	};
-
 return;
 }
 
