@@ -26,19 +26,17 @@
 *                                                                              *
 ********************************************************************************
 */
-void EVTest(char *filename)
-{
+void EVTest(char *filename) {
   FILE *test_input;
   int i, len;
   char *eof;
-  TREE *tree=local[0];
+  TREE * const tree=local[0];
 /*
  ----------------------------------------------------------
 |                                                          |
-|   read in the position and then the solutions.  after    |
-|   executing a search to find the best move (according    |
-|   to the program, anyway) compare it against the list    |
-|   of solutions and count it right or wrong.              |
+|   read in the position and then the solutions.  then do  |
+|   a call to Evaluate() which will normally display the   |
+|   debugging stuff that is enabled.                       |
 |                                                          |
  ----------------------------------------------------------
 */
@@ -73,9 +71,16 @@ void EVTest(char *filename)
       Print(4095,"======================================================================\n");
     }
     else if (!strcmp(args[0],"setboard")) {
+      int s;
       SetBoard(nargs-1,args+1,0);
+      WhiteCastle(0)=0;
+      BlackCastle(0)=0;
+      root_wtm=wtm;
+      PreEvaluate(tree,wtm);
+      tree->pawn_score.key=0;
       DisplayChessBoard(stdout,tree->pos);
-      Print(4095,"Evaluation=%d\n",Evaluate(tree,0,wtm,-999999,999999));
+      s=Evaluate(tree,0,wtm,-999999,999999);
+      Print(4095,"score=%d\n",s);
     }
   }
   input_stream=stdin;
