@@ -24,13 +24,13 @@ int InputMove(TREE *tree, char *text, int ply, int wtm, int silent,
   int moves[220], *mv, *mvp, *goodmove=0;
   int piece=-1, capture, promote, give_check;
   int ffile, frank, tfile, trank;
-  int current, i, nleft, ambig;
+  int current, i, nleft;
   char *goodchar;
   char movetext[128];
-  char pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
-                   'B','B','R','r','Q','q','\0'};
-  char pro_pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
-                       'B','b','R','r','Q','q','\0'};
+  static const char pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
+                                'B','B','R','r','Q','q','\0'};
+  static const char pro_pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
+                                    'B','b','R','r','Q','q','\0'};
 
 /*
    check for fully-qualified input (f1e1) and handle if needed.
@@ -55,7 +55,6 @@ int InputMove(TREE *tree, char *text, int ply, int wtm, int silent,
   ffile=-1;
   trank=-1;
   tfile=-1;
-  ambig=0;
   goodchar=strchr(movetext,'#');
   if (goodchar) *goodchar=0;
 /*
@@ -215,21 +214,6 @@ int InputMove(TREE *tree, char *text, int ply, int wtm, int silent,
     }
   }
   if (nleft == 1) return(*goodmove);
-  if (ambig) {
-    if (nleft > 1) {
-      for (mv=&moves[0];mv<mvp;mv++) 
-        if (Piece(*mv) != pawn) *mv=0;
-      nleft=0;
-      for (mv=&moves[0];mv<mvp;mv++) {
-        if (*mv) {
-          nleft++;
-          goodmove=mv;
-        }
-      }
-      if (nleft == 1)
-        return(*goodmove);
-    }
-  }
   if (!silent) {
     if (nleft == 0) Print(4095,"Illegal move: %s\n",text);
     else if (piece < 0) Print(4095,"Illegal move (unrecognizable): %s\n",text);
@@ -254,8 +238,8 @@ int InputMoveICS(TREE *tree, char *text, int ply, int wtm, int silent,
   int ffile, frank, tfile, trank;
   int i, nleft;
   char movetext[128];
-  char pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
-                   'B','b','R','r','Q','q','\0'};
+  static const char pieces[17]={' ',' ','P','p','N','n','K','k',' ',' ',
+                                'B','b','R','r','Q','q','\0'};
 /*
    initialize move structure in case an error is found
 */
