@@ -5,7 +5,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 05/06/98 */
+/* last modified 10/18/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -18,11 +18,10 @@
 *                                                                              *
 ********************************************************************************
 */
-void Interrupt(int ply)
-{
-  int temp, *mvp, left, readstat, result, time_used;
+void Interrupt(int ply) {
+  int temp, i, left=0, readstat, result, time_used;
   int save_move_number;
-  TREE *tree=local[0];
+  TREE * const tree=local[0];
   static int busy=0;
 /*
  ----------------------------------------------------------
@@ -97,9 +96,9 @@ void Interrupt(int ply)
         printf("stat01: %d ",time_used);
         printf("%d ",tree->nodes_searched);
         printf("%d ",iteration_depth); 
-        for (left=0,mvp=tree->last[0];mvp<tree->last[1];mvp++) 
-          if (!tree->searched_this_root_move[mvp-tree->last[0]]) left++;
-        printf("%d %d\n",left,tree->last[1]-tree->last[0]);
+        for (i=0;i<n_root_moves;i++)
+          if (!(root_moves[i].status&128)) left++;
+        printf("%d %d\n",left,n_root_moves);
         fflush(stdout);
         break;
       }
@@ -155,13 +154,13 @@ void Interrupt(int ply)
           Print(4095,"command not legal now.\n");
         else {
           abort_search=1;
-          analyze_move_read=1;
+          input_status=2;
           break;
         }
       }
       else if ((result != 1) && analyze_mode) {
         abort_search=1;
-        analyze_move_read=1;
+        input_status=2;
         break;
       }
 /*
@@ -181,8 +180,8 @@ void Interrupt(int ply)
           temp=InputMove(tree,args[0],0,ChangeSide(root_wtm),1,1);
           if (temp) {
             if (auto232) {
-              char *mv=OutputMoveICS(tree,temp);
-              Delay232(auto232_delay);
+              const char *mv=OutputMoveICS(temp);
+              DelayTime(auto232_delay);
               if (!wtm) fprintf(auto_file,"\t");
               fprintf(auto_file, " %c%c-%c%c", mv[0], mv[1], mv[2], mv[3]);
               if ((mv[4] != ' ') && (mv[4] != 0))
@@ -196,7 +195,7 @@ void Interrupt(int ply)
                 (Captured(temp) == Captured(ponder_move)) &&
                 (Promote(temp) == Promote(ponder_move))) {
               predicted++;
-              made_predicted_move=1;
+              input_status=1;
               pondering=0;
               thinking=1;
               opponent_end_time=ReadClock(elapsed);
@@ -204,6 +203,7 @@ void Interrupt(int ply)
               Print(128,"predicted move made.\n");
             }
             else {
+              input_status=2;
               abort_search=1;
               break;
             }
@@ -213,10 +213,7 @@ void Interrupt(int ply)
             abort_search=1;
             break;
           }
-          else {
-            Print(4095,"Illegal move: %s\n", args[0]);
-            if (log_file) DisplayChessBoard(log_file,tree->pos);
-          }
+          else Print(4095,"Illegal move: %s\n", args[0]);
         }
         else Print(4095,"unrecognized/illegal command: %s\n", args[0]);
       }
@@ -225,33 +222,3 @@ void Interrupt(int ply)
   if (log_file) fflush(log_file);
   busy=0;
 }
-/*
-********************************************************************************
-*                                                                              *
-*   SignalInterrupt() is used to catch SIGINT and SIGTERM which are used by    *
-*   Xboard.  SIGINT is used when the operator clicks the "move now" button,    *
-*   while SIGTERM is used to detect when Crafty is terminating.                *
-*                                                                              *
-********************************************************************************
-*/
-#if defined(NT_i386) || defined(NT_AXP)
-void _cdecl SignalInterrupt(int signal_type)
-#else
-void SignalInterrupt(int signal_type)
-#endif
-{
-  switch (signal_type) {
-  case SIGINT:
-    if (xboard) {
-      if (thinking) {
-        time_abort=1;
-        abort_search=1;
-      }
-      signal(SIGINT,SignalInterrupt);
-      break;
-    }
-    break;
-  default:
-    break;
-  }
-}
