@@ -5,7 +5,7 @@
 #include "data.h"
 #include "epdglue.h"
 
-/* last modified 07/08/98 */
+/* last modified 08/27/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -15,15 +15,13 @@
 *                                                                              *
 ********************************************************************************
 */
-int Iterate(int wtm, int search_type, int root_list_done)
-{
-  int *mvp;
+int Iterate(int wtm, int search_type, int root_list_done) {
+  ROOT_MOVE temp;
   int wpawn, bpawn, TB_use_ok;
   int i, value=0, time_used;
-  int twtm, used_w, used_b;
-  int correct, correct_count, material=0, sorted, temp;
-  TREE *tree=local[0];
-
+  int twtm, used, search_value=last_search_value;
+  int correct, correct_count, material=0, sorted;
+  TREE * const tree=local[0];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -35,6 +33,8 @@ int Iterate(int wtm, int search_type, int root_list_done)
 |                                                          |
  ----------------------------------------------------------
 */
+  largest_positional_score=Max(largest_positional_score>>1,100);
+  if (average_nps == 0) average_nps=150000*max_threads;
   time_abort=0;
   abort_search=0;
   book_move=0;
@@ -42,6 +42,7 @@ int Iterate(int wtm, int search_type, int root_list_done)
   start_time=ReadClock(time_type);
   cpu_time_used=0;
   elapsed_start=ReadClock(elapsed);
+  root_wtm=wtm;
   PreEvaluate(tree,wtm);
   tree->nodes_searched=0;
   tree->fail_high=0;
@@ -62,7 +63,7 @@ int Iterate(int wtm, int search_type, int root_list_done)
   if (booking || !Book(tree,wtm,root_list_done)) do {
     if (abort_search) break;
     if (!root_list_done) RootMoveList(wtm);
-    if (EGTB_draw) EGTB_use=0;
+    if (EGTB_draw && !puzzling && swindle_mode) EGTB_use=0;
     else EGTB_use=EGTBlimit;
     if (EGTBlimit && !EGTB_use)
       Print(128,"Drawn at root, trying for swindle.\n");
@@ -82,17 +83,14 @@ int Iterate(int wtm, int search_type, int root_list_done)
     tree->pawn_probes=0;
     tree->pawn_hits=0;
 #endif
-    tree->tb_probes=0;
-    tree->tb_probes_successful=0;
+    tree->egtb_probes=0;
+    tree->egtb_probes_successful=0;
     tree->check_extensions_done=0;
+    tree->threat_extensions_done=0;
     tree->recapture_extensions_done=0;
     tree->passed_pawn_extensions_done=0;
     tree->one_reply_extensions_done=0;
     root_wtm=wtm;
-    root_total_white_pieces=TotalWhitePieces;
-    root_total_white_pawns=TotalWhitePawns;
-    root_total_black_pieces=TotalBlackPieces;
-    root_total_black_pawns=TotalBlackPawns;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -102,21 +100,20 @@ int Iterate(int wtm, int search_type, int root_list_done)
 |                                                          |
  ----------------------------------------------------------
 */
-    if (tree->last[0] == tree->last[1]) {
+    if (n_root_moves == 0) {
       program_end_time=ReadClock(time_type);
-      tree->pv[0].path_length=0;
-      tree->pv[0].path_iteration_depth=10;
+      tree->pv[0].pathl=0;
+      tree->pv[0].pathd=10;
       if (Check(wtm)) {
         root_value=-(MATE-1);
-        last_search_value=-(MATE-1);
       }
       else {
-        root_value=DrawScore(crafty_is_white);
-        last_search_value=DrawScore(crafty_is_white);
+        root_value=DrawScore(1);
       }
       Print(6,"              depth   time  score   variation\n");
       Print(6,"                                    (no moves)\n");
       tree->nodes_searched=1;
+      if (!puzzling) last_search_value=root_value;
       return(root_value);
     }
 /*
@@ -139,9 +136,9 @@ int Iterate(int wtm, int search_type, int root_list_done)
 */
     TimeSet(search_type);
     iteration_depth=1;
-    if (last_pv.path_iteration_depth > 1)
-      iteration_depth=last_pv.path_iteration_depth+1;
-    Print(6,"              depth   time  score   variation (%d)\n",
+    if (last_pv.pathd > 1)
+      iteration_depth=last_pv.pathd+1;
+    Print(6,"         nss  depth   time  score   variation (%d)\n",
           iteration_depth);
     time_abort=0;
     abort_search=0;
@@ -156,7 +153,7 @@ int Iterate(int wtm, int search_type, int root_list_done)
 |                                                          |
  ----------------------------------------------------------
 */
-    LearnPositionLoad(tree);
+    LearnPositionLoad();
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -176,7 +173,6 @@ int Iterate(int wtm, int search_type, int root_list_done)
       root_value=-MATE-1;
       root_beta=MATE+1;
     }
-    for (i=0;i<256;i++) tree->root_nodes[i]=0;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -190,17 +186,15 @@ int Iterate(int wtm, int search_type, int root_list_done)
     if (max_threads>smp_idle+1) {
       pthread_t pt;
       int proc;
-      if (!EGTB_use || !(TotalPieces<=5 && TB_use_ok &&
-          EGTBScore(tree, 1, wtm, &i))) {
-        for (proc=smp_threads+1;proc<max_threads;proc++) {
-          Print(128,"starting thread %d\n",proc);
-          thread[proc]=0;
-          tfork(pt,ThreadInit,(void *) proc);
-          smp_threads++;
-        }
+      for (proc=smp_threads+1;proc<max_threads;proc++) {
+        Print(128,"starting thread %d\n",proc);
+        thread[proc]=0;
+        tfork(pt,ThreadInit,(void *) proc);
+        smp_threads++;
       }
     }
 #endif
+    root_print_ok=0;
     for (;iteration_depth<=60;iteration_depth++) {
 /*
  ----------------------------------------------------------
@@ -211,7 +205,7 @@ int Iterate(int wtm, int search_type, int root_list_done)
  ----------------------------------------------------------
 */
       twtm=wtm;
-      for (i=1;i<=(int) tree->pv[0].path_length;i++) {
+      for (i=1;i<=(int) tree->pv[0].pathl;i++) {
         tree->pv[i]=tree->pv[i-1];
         if (!LegalMove(tree,i,twtm,tree->pv[i].path[i])) {
           Print(4095,"ERROR, not installing bogus move at ply=%d\n",i);
@@ -220,7 +214,7 @@ int Iterate(int wtm, int search_type, int root_list_done)
                 Piece(tree->pv[i].path[i]));
           break;
         }
-        StorePV(tree, i, twtm);
+        HashStorePV(tree, i, twtm);
         MakeMove(tree, i,tree->pv[0].path[i],twtm);
         twtm=ChangeSide(twtm);
       }
@@ -233,10 +227,6 @@ int Iterate(int wtm, int search_type, int root_list_done)
         printf("=      search iteration %2d       =\n",iteration_depth);
         printf("==================================\n");
       }
-      for (mvp=tree->last[0];mvp<tree->last[1];mvp++)
-        tree->searched_this_root_move[mvp-tree->last[0]]=0;
-      search_failed_high=0;
-      search_failed_low=0;
       if (tree->nodes_searched) {
         nodes_between_time_checks=nodes_per_second;
         nodes_between_time_checks=Min(nodes_between_time_checks,MAX_TC_NODES);
@@ -254,38 +244,41 @@ int Iterate(int wtm, int search_type, int root_list_done)
 #endif
         thread_start_time[0]=ReadClock(cpu);
         value=SearchRoot(tree,root_alpha, root_beta, wtm,
-                         iteration_depth*INCREMENT_PLY+45);
+                         iteration_depth*INCPLY+45);
+        root_print_ok=tree->nodes_searched > noise_level;
         cpu_time_used+=ReadClock(cpu)-thread_start_time[0];
         if (value >= root_beta) {
-          search_failed_high=1;
-          root_alpha=root_beta-1;
+          root_moves[0].status|=2;
+          root_moves[0].status&=255-128;
+          if (root_moves[0].status&1) root_alpha=-MATE-1;
+          else root_alpha=root_beta-1;
           root_value=root_alpha;
           root_beta=MATE+1;
-          tree->searched_this_root_move[0]=0;
+          root_moves[0].nodes=0;
         }
         else if (value <= root_alpha) {
-          if (!search_failed_high) {
-            for (mvp=tree->last[0];mvp<tree->last[1];mvp++)
-              tree->searched_this_root_move[mvp-tree->last[0]]=0;
-            search_failed_low=1;
+          if (!(root_moves[0].status&2)) {
+            root_moves[0].status&=255-128;
+            root_moves[0].nodes=0;
+            root_moves[0].status|=1;
+            if (root_moves[0].status&2) root_beta=MATE+1;
             root_alpha=-MATE-1;
             root_value=root_alpha;
             easy_move=0;
-            if (tree->nodes_searched>noise_level && !time_abort && !abort_search) {
+            if (root_print_ok && !time_abort && !abort_search) {
               Print(4,"               %2i   %s     --   ",iteration_depth,
                     DisplayTime(ReadClock(time_type)-start_time));
               if (display_options&64) Print(4,"%d. ",move_number);
               if ((display_options&64) && !wtm) Print(4,"... ");
-              Print(4,"%s\n",OutputMove(tree,*tree->last[0],1,wtm));
+              Print(4,"%s\n",OutputMove(tree,root_moves[0].move,1,wtm));
             }
           }
           else break;
         }
-        else
-          break;
+        else break;
       }
       if (root_value>root_alpha && root_value<root_beta) 
-        last_search_value=root_value;
+        search_value=root_value;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -318,46 +311,67 @@ int Iterate(int wtm, int search_type, int root_list_done)
 */
       twtm=wtm;
       end_time=ReadClock(time_type);
+      do {
+        sorted=1;
+        for (i=1;i<n_root_moves-1;i++) {
+          if (root_moves[i].nodes < root_moves[i+1].nodes) {
+            temp=root_moves[i];
+            root_moves[i]=root_moves[i+1];
+            root_moves[i+1]=temp;
+            sorted=0;
+          }
+        }
+      } while(!sorted);
+      for (i=0;i<n_root_moves;i++) root_moves[i].status=0;
+      if (root_moves[0].nodes > 1000)
+        for (i=0;i<Min(n_root_moves,4);i++) {
+          if (root_moves[i].nodes > root_moves[0].nodes/2)
+            root_moves[i].status|=64;
+        }
+      if (display_options&256) {
+        unsigned int total_nodes=0;
+        Print(4095,"       move       nodes      hi/low\n");
+        for (i=0;i<n_root_moves;i++) {
+          total_nodes+=root_moves[i].nodes;
+          Print(4095," %10s  %10d       %d   %d\n",
+            OutputMove(tree,root_moves[i].move,1,wtm),
+                       (unsigned int)root_moves[i].nodes,
+                       (root_moves[i].status&2)>0,(root_moves[i].status&1)>0);
+        }
+        Print(256,"      total  %10d\n",total_nodes);
+      }
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   notice if there are multiple moves that are producing  |
+|   large trees.  if so, don't search those in parallel by |
+|   setting the flag to avoid this.                        |
+|                                                          |
+ ----------------------------------------------------------
+*/
+      for (i=0;i<n_root_moves;i++) root_moves[i].nodes=0;
       if (end_time-start_time > 10)
         nodes_per_second=(BITBOARD) tree->nodes_searched*100/(BITBOARD) (end_time-start_time);
       else
         nodes_per_second=10000;
-      if (!time_abort && !abort_search && (tree->nodes_searched>noise_level ||
-          correct_count>=early_exit || value>MATE-100 || tree->pv[0].path_hashed==2)) {
+      if (!time_abort && !abort_search && (root_print_ok ||
+          correct_count>=early_exit || value>MATE-300 || tree->pv[0].pathh==2)) {
         if (value != -(MATE-1))
           DisplayPV(tree,5,wtm,end_time-start_time,value,&tree->pv[0]);
       }
       root_alpha=value-40;
       root_value=root_alpha;
       root_beta=value+40;
-      if ((iteration_depth > 1) && (value > MATE-100) &&
-          (value > last_mate_score)) break;
+      if (iteration_depth>3 && value>MATE-300 &&
+          value>=(MATE-iteration_depth-1) && value>last_mate_score) break;
       if ((iteration_depth >= search_depth) && search_depth) break;
       if (time_abort || abort_search) break;
       end_time=ReadClock(time_type)-start_time;
-      if (thinking && ((int) end_time >= time_limit)) break;
+      if (thinking && (int)end_time>=time_limit) break;
       if (correct_count >= early_exit) break;
-      if (iteration_depth>=2 && TotalPieces<=5 && TB_use_ok &&
-          EGTBScore(tree, 1, wtm, &i) && EGTB_use) break;
-      do {
-        sorted=1;
-        for (mvp=tree->last[0]+1;mvp<tree->last[1]-1;mvp++) {
-          if (tree->root_nodes[mvp-tree->last[0]] < tree->root_nodes[mvp-tree->last[0]+1]) {
-            temp=*mvp;
-            *mvp=*(mvp+1);
-            *(mvp+1)=temp;
-            temp=tree->root_nodes[mvp-tree->last[0]];
-            tree->root_nodes[mvp-tree->last[0]]=tree->root_nodes[mvp-tree->last[0]+1];
-            tree->root_nodes[mvp-tree->last[0]+1]=temp;
-            sorted=0;
-          }
-        }
-      } while(!sorted);
-/*
-      for (mvp=tree->last[0];mvp<tree->last[1];mvp++) {
-        Print(4095," %10s  %10d\n",OutputMove(tree,*mvp,1,wtm),tree->root_nodes[mvp-tree->last[0]]);
-      }
-*/
+      if (iteration_depth>3 && TotalPieces<=EGTBlimit && TB_use_ok &&
+          EGTB_use && !EGTB_search && EGTBProbe(tree, 1, wtm, &i)) break;
+      if (search_nodes && tree->nodes_searched>search_nodes) break;
     }
 /*
  ----------------------------------------------------------
@@ -367,12 +381,13 @@ int Iterate(int wtm, int search_type, int root_list_done)
 |                                                          |
  ----------------------------------------------------------
 */
-    used_w=0;
-    used_b=0;
+    used=0;
 #if !defined(FAST)
     for (i=0;i<hash_table_size;i++) {
-      if ((int) Shiftr((trans_ref_ba+i)->word1,61) == transposition_id) used_b++;
-      if ((int) Shiftr((trans_ref_wa+i)->word1,61) == transposition_id) used_w++;
+      if ((trans_ref_a+i)->word1>>61 == transposition_id) used++;
+    }
+    for (i=0;i<hash_table_size*2;i++) {
+      if ((trans_ref_b+i)->word1>>61 == transposition_id) used++;
     }
 #endif
     end_time=ReadClock(time_type);
@@ -383,7 +398,11 @@ int Iterate(int wtm, int search_type, int root_list_done)
       cpu_percent=100*cpu_time_used/elapsed_end;
     else cpu_percent=100;
     if (elapsed_end > 10)
-      nodes_per_second=(BITBOARD) tree->nodes_searched*100/(BITBOARD) elapsed_end;
+      nodes_per_second=(BITBOARD)tree->nodes_searched*100/(BITBOARD) elapsed_end;
+    if (!tree->egtb_probes) {
+      if (average_nps) average_nps=(9*average_nps+nodes_per_second)/10;
+      else average_nps=nodes_per_second;
+    }
     tree->evaluations=(tree->evaluations) ? tree->evaluations : 1;
     if ((!abort_search || time_abort) && !puzzling) {
       tree->fail_high++;
@@ -395,18 +414,19 @@ int Iterate(int wtm, int search_type, int root_list_done)
       Print(8,"  n=%u", tree->nodes_searched);
       Print(8,"  fh=%u%%", tree->fail_high_first*100/tree->fail_high);
       Print(8,"  nps=%d\n", nodes_per_second);
-      Print(16,"              ext-> checks=%d recaps=%d pawns=%d 1rep=%d\n",
+      Print(16,"              ext-> checks=%d recaps=%d pawns=%d 1rep=%d thrt:%d\n",
             tree->check_extensions_done, tree->recapture_extensions_done,
-            tree->passed_pawn_extensions_done, tree->one_reply_extensions_done);
+            tree->passed_pawn_extensions_done, tree->one_reply_extensions_done,
+            tree->threat_extensions_done);
       Print(16,"              predicted=%d  nodes=%u  evals=%u\n", 
              predicted, tree->nodes_searched, tree->evaluations);
       Print(16,"              endgame tablebase-> probes done=%d  successful=%d\n",
-            tree->tb_probes, tree->tb_probes_successful);
+            tree->egtb_probes, tree->egtb_probes_successful);
 #if !defined(FAST)
-      Print(16,"              hashing-> trans/ref=%d%%  pawn=%d%%  used=w%d%% b%d%%\n",
+      Print(16,"              hashing-> trans/ref=%d%%  pawn=%d%%  used=%d%%\n",
             100*tree->transposition_hits/(tree->transposition_probes+1),
             100*tree->pawn_hits/(tree->pawn_probes+1),
-            used_w*100/(hash_table_size+1), used_b*100/(hash_table_size+1));
+            used*100/(3*hash_table_size+1));
 #endif
 #if defined(SMP)
       Print(16,"              SMP->  split=%d  stop=%d  data=%d/%d  ",
@@ -418,18 +438,13 @@ int Iterate(int wtm, int search_type, int root_list_done)
   } while(0);
   else {
     root_value=0;
-    last_search_value=0;
+    search_value=0;
     book_move=1;
     tree->pv[0]=tree->pv[1];
-    if (analyze_mode) Whisper(4,0,0,0,0,0,whisper_text);
+    if (analyze_mode) Whisper(4,0,0,0,0,0,0,whisper_text);
   }
   program_end_time=ReadClock(time_type);
-#if defined(SMP)
-  if (TB_use_ok && EGTB_use && TotalPieces<= 5 && EGTBScore(tree, 1, wtm, &i)) {
-    int proc;
-    for (proc=1;proc<CPUS;proc++) thread[proc]=(TREE*)-1;
-    smp_threads=0;
-  }
-#endif
-  return(last_search_value);
+  search_move=0;
+  if (!puzzling) last_search_value=search_value;
+  return(search_value);
 }
