@@ -9,7 +9,7 @@
 #  include <unistd.h>
 #endif
 
-/* last modified 03/11/98 */
+/* last modified 04/15/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -29,7 +29,6 @@
 *                                                                              *
 ********************************************************************************
 */
-
 void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
                int force) {
 /*
@@ -42,7 +41,7 @@ void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
 |                                                          |
  ----------------------------------------------------------
 */
-  int t_wtm=wtm;
+  const int t_wtm=wtm;
   if (!book_file) return;
   if (!(learning&book_learning)) return;
   if (moves_out_of_book <= LEARN_INTERVAL && !force) {
@@ -67,7 +66,7 @@ void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
     float temp_value;
     char cmd[32], buff[80], *nextc;
     int best_eval=-999999, best_eval_p=0;
-    int worst_eval=999999, worst_eval_p=0, save_wtm;
+    int worst_eval=999999, worst_eval_p=0;
     int best_after_worst_eval=-999999, worst_after_best_eval=999999;
     struct tm *timestruct;
     int n_book_moves[512];
@@ -188,7 +187,6 @@ void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
 |                                                          |
  ----------------------------------------------------------
 */
-    save_wtm=wtm;
     InitializeChessBoard(&tree->position[0]);
     for (i=0;i<512;i++) n_book_moves[i]=0;
     wtm=1;
@@ -217,12 +215,12 @@ void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
         }
         else cluster=0;
         for (mv=tree->last[0];mv<tree->last[1];mv++) {
-          common=And(HashKey,mask_16);
+          common=HashKey & mask_16;
           MakeMove(tree, 1,*mv,wtm);
-          temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-          temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+          temp_hash_key=HashKey ^ wtm_random[wtm];
+          temp_hash_key=(temp_hash_key & ~mask_16) | common;
           for (j=0;j<cluster;j++)
-            if (!Xor(temp_hash_key,book_buffer[j].position) &&
+            if (!(temp_hash_key ^ book_buffer[j].position) &&
                 book_buffer[j].learn > (float) LEARN_COUNTER_BAD/100.0) {
                 n_book_moves[i]++;
                 last_book_move=i;
@@ -250,7 +248,10 @@ void LearnBook(TREE *tree, int wtm, int search_value, int search_depth, int lv,
     t_learn_value=((float) learn_value)/100.0;
     for (i=511;i>=0;i--) {
       book_learn[i]=t_learn_value;
-      if (n_book_moves[i] > 1) t_learn_value/=n_book_moves[i];
+/*
+      if (n_book_moves[i] > 1) t_learn_value/=Max(n_book_moves[i]>>1,1);
+*/
+      if (n_book_moves[i] > 1) t_learn_value=3*t_learn_value/4;
     }
 /*
  ----------------------------------------------------------
@@ -367,12 +368,12 @@ void LearnBookUpdate(TREE *tree, int wtm, int move, float learn_value) {
       fseek(book_file,key,SEEK_SET);
       fread(&cluster,sizeof(int),1,book_file);
       fread(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
-      common=And(HashKey,mask_16);
+      common=HashKey & mask_16;
       MakeMove(tree, 1,move,wtm);
-      temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-      temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+      temp_hash_key=HashKey ^ wtm_random[wtm];
+      temp_hash_key=(temp_hash_key & ~mask_16) | common;
       for (move_index=0;move_index<cluster;move_index++)
-        if (!Xor(temp_hash_key,book_buffer[move_index].position)) break;
+        if (!(temp_hash_key ^ book_buffer[move_index].position)) break;
       UnMakeMove(tree, 1,move,wtm);
       if (move_index >= cluster) return;
       if (book_buffer[move_index].learn == 0.0)
@@ -402,9 +403,9 @@ void LearnBookUpdate(TREE *tree, int wtm, int move, float learn_value) {
 */
 int LearnFunction(int sv, int search_depth, int rating_difference,
                   int trusted_value) {
-  float rating_multiplier_trusted[11] = {.00625, .0125, .025, .05, .075, .1,
-                                         0.15, 0.2, 0.25, 0.3, 0.35};
-  float rating_multiplier_untrusted[11] = {.25, .2, .15, .1, .05, .025, .012,
+  static const float rating_mult_t[11] = {.00625, .0125, .025, .05, .075, .1,
+                                          0.15, 0.2, 0.25, 0.3, 0.35};
+  static const float rating_mult_ut[11] = {.25, .2, .15, .1, .05, .025, .012,
                                            .006, .003, .001};
   float multiplier;
   int sd, rd;
@@ -412,14 +413,14 @@ int LearnFunction(int sv, int search_depth, int rating_difference,
   sd=Max(Min(search_depth,19),0);
   rd=Max(Min(rating_difference/200,5),-5)+5;
   if (trusted_value)
-    multiplier=rating_multiplier_trusted[rd]*sd;
+    multiplier=rating_mult_t[rd]*sd;
   else
-    multiplier=rating_multiplier_untrusted[rd]*sd;
+    multiplier=rating_mult_ut[rd]*sd;
   sv=Max(Min(sv,600),-600);
-  return(sv*multiplier);
+  return((int) (sv*multiplier));
 }
 
-/* last modified 03/11/98 */
+/* last modified 10/03/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -442,10 +443,13 @@ int LearnFunction(int sv, int search_depth, int rating_difference,
 *  eight bytes of the file, then the positions and scores are read in and      *
 *  added to the position.bin file.                                             *
 *                                                                              *
+*  LearnImport() also will import data from the C.A.P. project by Dan Corbitt  *
+*  and add the scores to book positions in book.bin, when these positions are  *
+*  found.                                                                      *
+*                                                                              *
 ********************************************************************************
 */
 void LearnImport(TREE *tree, int nargs, char **args) {
-
   FILE *learn_in;
   char text[128];
   int eof;
@@ -459,6 +463,12 @@ void LearnImport(TREE *tree, int nargs, char **args) {
  ----------------------------------------------------------
 */
   display_options&=4095-128;
+  if (!strcmp(*args,"book.lrn") || !strcmp(*args,"position.lrn")) {
+    Print(4095,"ERROR  you must not import either book.lrn or position.lrn\n");
+    Print(4095,"       if you really want to do this, first rename them to\n");
+    Print(4095,"       another filename and import those files.\n");
+    return;
+  }
   learn_in=fopen(*args,"r");
   if (learn_in == NULL) {
     Print(4095,"unable to open %s for input\n", *args);
@@ -468,7 +478,9 @@ void LearnImport(TREE *tree, int nargs, char **args) {
   fclose(learn_in);
   if  (eof == 0) return;
   if (!strcmp(text,"position")) LearnImportPosition(tree,nargs,args);
-  else LearnImportBook(tree,nargs,args);
+  else if (strstr(text,"[White")) LearnImportBook(tree,nargs,args);
+  else LearnImportCAP(tree,nargs,args);
+  InitializeChessBoard(&tree->position[0]);
 }
 
 /* last modified 03/11/98 */
@@ -480,13 +492,11 @@ void LearnImport(TREE *tree, int nargs, char **args) {
 *                                                                              *
 ********************************************************************************
 */
-
 #if defined(MACOS)
   int index[32768];
 #endif
 
 void LearnImportBook(TREE *tree, int nargs, char **args) {
-
   FILE *learn_in;
   char nextc, text[128], *eof;
   int wtm, learn_value, depth, rating_difference, move=0, i, added_lines=0;
@@ -607,6 +617,172 @@ void LearnImportBook(TREE *tree, int nargs, char **args) {
   Print(4095,"\nadded %d learned book lines to book.bin\n",added_lines);
 }
 
+/* last modified 10/03/99 */
+/*
+********************************************************************************
+*                                                                              *
+*   LearnImportCAP() is used to import data from Dan Corbitt's C.A.P. project  *
+*   and update the opening book with the scores of these searches.  we are     *
+*   interested in three fields of a CAP record:  the FEN position string that  *
+*   includes the position, castling rights and en passant target; the "ce"     *
+*   field that contains the 'centipawn evaluation'; and finally, the "pm"      *
+*   field that contains the best (preferred) move in this position according   *
+*   to the search results.                                                     *
+*                                                                              *
+*   the FEN is used to set the current board position, then the usual book     *
+*   indexing scheme is used to index to see if the position _after_ the "pm"
+*   is in the book.  If so, the CAP score for that move will be set to the     *
+*   "ce" score and written back to disk.                                       *
+*                                                                              *
+*   Note that these scores are not adjusted by Crafty in any way, so that the  *
+*   data is 'constant' unless the C.A.P. project revises the scores as faster  *
+*   hardware comes along.  re-importing new data will simply overwrite any     *
+*   existing CAP scores that are in the new data, but will not bother the old  *
+*   scores, unless the 'clear' option is used, as in other import functions.   *
+*                                                                              *
+********************************************************************************
+*/
+void LearnImportCAP(TREE *tree, int nargs, char **args) {
+  BITBOARD temp_hash_key, common;
+  char *eof, *pmp, *acd, buffer[2048];
+  int ce, move, CAP_used=0, CAP_found=0, key, cluster, test, i;
+  FILE *CAP_in;
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   if the 'clear' option was given, first run through     |
+|   book.bin and clear every CAP score.  this should not   |
+|   be a common event.                                     |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  if (nargs>1 && !strcmp(args[1],"clear")) {
+#if defined(MACOS)
+    int i, j, cluster;
+#else
+    int index[32768], i, j, cluster;
+#endif
+    fseek(book_file,0,SEEK_SET);
+    fread(index,sizeof(int),32768,book_file);
+    for (i=0;i<32768;i++)
+      if (index[i] > 0) {
+        fseek(book_file,index[i],SEEK_SET);
+        fread(&cluster,sizeof(int),1,book_file);
+        fread(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
+        for (j=0;j<cluster;j++) book_buffer[j].CAP_score=-2*MATE;
+        fseek(book_file,index[i]+sizeof(int),SEEK_SET);
+        fwrite(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
+      }
+  }
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   loop through the file, reading in a CAP record.  from  |
+|   this we extract the FEN position string, the score     |
+|   (ce) and the preferred move (pm).                      |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  CAP_in=fopen(args[0],"r");
+  while (1) {
+    CAP_found++;
+    if ((CAP_found)%1000==0) {
+      printf(".");
+      fflush(stdout);
+    }
+    if ((CAP_found)%60000 == 0) printf(" (%d)\n",CAP_found);
+    eof=fgets(buffer,512,CAP_in);
+    if (eof) {
+      char *delim;
+      delim=strchr(buffer,'\n');
+      if (delim) *delim=0;
+      delim=strchr(buffer,'\r');
+      if (delim) *delim=' ';
+    }
+    else break;
+    if (!strstr(buffer,"ce ")) {
+      Print(4095,"\nERROR  CAP input line with no ce field\n");
+      Print(4095,"line number %d\n",CAP_found);
+      continue;
+    }
+    ce=atoi(strstr(buffer,"ce ")+2);
+    pmp=strstr(buffer,"pm")+2;
+    if (!pmp) {
+      Print(4095,"\nERROR  CAP input line with no pm field\n");
+      Print(4095,"line number %d\n",CAP_found);
+      continue;
+    }
+    else while (*pmp == ' ') pmp++;
+    if (!strchr(pmp,';')) {
+      Print(4095,"\nERROR  CAP input line with partial pm field\n");
+      Print(4095,"line number %d\n",CAP_found);
+      continue;
+    }
+    *strchr(pmp,';')=0;
+    if (!strlen(pmp)) continue;
+    acd=strstr(buffer,"acd ");
+    if (!acd) {
+      Print(4095,"\nERROR  CAP input line with no acd field\n");
+      Print(4095,"line number %d\n",CAP_found);
+      continue;
+    }
+    *acd=0;
+    nargs=ReadParse(buffer,args," 	;");
+    SetBoard(nargs,args,0);
+    move=InputMove(tree,pmp,0,wtm,1,0);
+    if (!move) {
+      Print(4095,"\nERROR  bad move in CAP input file\n");
+      Print(4095,"line number %d  pm=/%s/  wtm=%d\n",CAP_found,pmp,wtm);
+      DisplayChessBoard(stdout,tree->pos);
+      continue;
+    }
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   now we have the right position.  time to find the      |
+|   position (if it is present) and update the CAP_score   |
+|   field.                                                 |
+|                                                          |
+ ----------------------------------------------------------
+*/
+    test=HashKey>>49;
+    fseek(book_file,test*sizeof(int),SEEK_SET);
+    fread(&key,sizeof(int),1,book_file);
+    if (key > 0) {
+      fseek(book_file,key,SEEK_SET);
+      fread(&cluster,sizeof(int),1,book_file);
+      fread(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
+    }
+    else cluster=0;
+    if (!cluster) return;
+    common=HashKey & mask_16;
+    MakeMove(tree,0,move,wtm);
+    temp_hash_key=HashKey ^ wtm_random[wtm];
+    temp_hash_key=(temp_hash_key & ~mask_16) | common;
+    for (i=0;i<cluster;i++) {
+      if (!(temp_hash_key ^ book_buffer[i].position)) {
+        book_buffer[i].CAP_score=ce;
+        fseek(book_file,key+sizeof(int),SEEK_SET);
+        fwrite(book_buffer,sizeof(BOOK_POSITION),cluster,book_file);
+        CAP_used++;
+        break;
+      }
+    }
+    UnMakeMove(tree,0,move,wtm);
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   now update the position.lrn file so that the position  |
+|   is saved in a form that can be imported later in other |
+|   versions of crafty on different machines.              |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  }
+  Print(4095,"updated   %d book CAP scores.\n",CAP_used);
+  Print(4095,"processed %d book CAP scores.\n",CAP_found-1);
+}
+
 /* last modified 03/11/98 */
 /*
 ********************************************************************************
@@ -617,12 +793,9 @@ void LearnImportBook(TREE *tree, int nargs, char **args) {
 ********************************************************************************
 */
 void LearnImportPosition(TREE *tree, int nargs, char **args) {
-
   BITBOARD word1, word2;
   int positions, nextp, secs;
   struct tm *timestruct;
-  char xlate[15]={'q','r','b',0,'k','n','p',0,'P','N','K',0,'B','R','Q'};
-  char empty[9]={' ','1','2','3','4','5','6','7','8'};
   int i, rank, file, nempty, value, move, depth, added_positions=0;
   char *eof, text[80];
   FILE *learn_in;
@@ -756,15 +929,15 @@ void LearnImportPosition(TREE *tree, int nargs, char **args) {
 |                                                          |
  ----------------------------------------------------------
 */
-    if (abs(value) < MATE-100)
-      word1=Shiftl((BITBOARD) (value+65536),43);
+    if (abs(value) < MATE-300)
+      word1=(BITBOARD) (value+65536)<<43;
     else if (value > 0)
-      word1=Shiftl((BITBOARD) (value+65536),43);
+      word1=(BITBOARD) (value+65536)<<43;
     else
-      word1=Shiftl((BITBOARD) (value+65536),43);
-    word1=Or(word1,Shiftl((BITBOARD) wtm,63));
-    word1=Or(word1,Shiftl((BITBOARD) move,16));
-    word1=Or(word1,(BITBOARD) depth);
+      word1=(BITBOARD) (value+65536)<<43;
+    word1=word1 | (BITBOARD) wtm<<63;
+    word1=word1 | (BITBOARD) move<<16;
+    word1=word1 | (BITBOARD) depth;
   
     word2=HashKey;
 
@@ -800,12 +973,12 @@ void LearnImportPosition(TREE *tree, int nargs, char **args) {
     for (rank=RANK8;rank>=RANK1;rank--) {
       nempty=0;
       for (file=FILEA;file<=FILEH;file++) {
-        if (PieceOnSquare((rank<<3)+file)) {
+        if (PcOnSq((rank<<3)+file)) {
           if (nempty) {
             fprintf(position_lrn_file,"%c",empty[nempty]);
             nempty=0;
           }
-          fprintf(position_lrn_file,"%c",xlate[PieceOnSquare((rank<<3)+file)+7]);
+          fprintf(position_lrn_file,"%c",xlate[PcOnSq((rank<<3)+file)+7]);
         }
         else nempty++;
       }
@@ -826,7 +999,7 @@ void LearnImportPosition(TREE *tree, int nargs, char **args) {
   fflush(position_lrn_file);
 }
 
-/* last modified 03/11/98 */
+/* last modified 01/26/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -839,17 +1012,15 @@ void LearnImportPosition(TREE *tree, int nargs, char **args) {
 *   were learned.                                                              *
 *                                                                              *
 *     bits     name  SL  description                                           *
-*       1       wtm  63  used to control which transposition table gets this   *
-*                        position.                                             *
-*      19     value  43  unsigned integer value of this position + 65536.      *
-*                        this might be a good score or search bound.           *
-*      21      move  16  best move from the current position, according to the *
+*      21      move  32  best move from the current position, according to the *
 *                        search at the time this position was stored.          *
 *                                                                              *
-*      16     draft   0  the depth of the search below this position, which is *
+*      15     draft  17  the depth of the search below this position, which is *
 *                        used to see if we can use this entry at the current   *
 *                        position.  note that this is in units of 1/60th of a  *
 *                        ply.                                                  *
+*      17     value   0  unsigned integer value of this position + 65536.      *
+*                        this might be a good score or search bound.           *
 *      64       key   0  complete 64bit hash key.                              *
 *                                                                              *
 *    the file will, by default, hold 65536 learned positions.  the first word  *
@@ -864,8 +1035,6 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
   BITBOARD word1, word2;
   int positions, nextp, secs;
   struct tm *timestruct;
-  char xlate[15]={'q','r','b',0,'k','n','p',0,'P','N','K',0,'B','R','Q'};
-  char empty[9]={' ','1','2','3','4','5','6','7','8'};
   int rank, file, nempty;
 /*
  ----------------------------------------------------------
@@ -879,6 +1048,7 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
 |                                                          |
  ----------------------------------------------------------
 */
+  if (!(learning & position_learning)) return;
   if ((!position_lrn_file) || (!position_file)) return;
   if (last_value < -2*PAWN_VALUE) return;
   if (last_value < value+PAWN_VALUE/3) return;
@@ -892,14 +1062,10 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
  ----------------------------------------------------------
 */
   Print(4095,"learning position, wtm=%d  value=%d\n",wtm,value);
-  word1=Shiftl((BITBOARD) (value+65536),43);
-  word1=Or(word1,Shiftl((BITBOARD) wtm,63));
-  word1=Or(word1,Shiftl((BITBOARD) tree->pv[0].path[1],16));
-  word1=Or(word1,(BITBOARD) (tree->pv[0].path_iteration_depth*INCREMENT_PLY-INCREMENT_PLY));
-
-  
-  word2=HashKey;
-
+  word1=(BITBOARD) (value+65536);
+  word1=word1 | (BITBOARD) (tree->pv[0].pathd*INCPLY-INCPLY)<<17;
+  word1=word1 | (BITBOARD) tree->pv[0].path[1]<<32;
+  word2=(wtm) ? HashKey : ~HashKey;
   fseek(position_file,0,SEEK_SET);
   fread(&positions,sizeof(int),1,position_file);
   fread(&nextp,sizeof(int),1,position_file);
@@ -922,8 +1088,8 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
 |                                                          |
  ----------------------------------------------------------
 */
-  fprintf(position_lrn_file,"[Black \"%s\"]\n",pgn_white);
-  fprintf(position_lrn_file,"[White \"%s\"]\n",pgn_black);
+  fprintf(position_lrn_file,"[White \"%s\"]\n",pgn_white);
+  fprintf(position_lrn_file,"[Black \"%s\"]\n",pgn_black);
   secs=time(0);
   timestruct=localtime((time_t*) &secs);
   fprintf(position_lrn_file,"[Date \"%4d.%02d.%02d\"]\n",timestruct->tm_year+1900,
@@ -932,12 +1098,12 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
   for (rank=RANK8;rank>=RANK1;rank--) {
     nempty=0;
     for (file=FILEA;file<=FILEH;file++) {
-      if (PieceOnSquare((rank<<3)+file)) {
+      if (PcOnSq((rank<<3)+file)) {
         if (nempty) {
           fprintf(position_lrn_file,"%c",empty[nempty]);
           nempty=0;
         }
-        fprintf(position_lrn_file,"%c",xlate[PieceOnSquare((rank<<3)+file)+7]);
+        fprintf(position_lrn_file,"%c",xlate[PcOnSq((rank<<3)+file)+7]);
       }
       else nempty++;
     }
@@ -952,11 +1118,11 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
                             Rank(EnPassant(0))+'1');
   fprintf(position_lrn_file,"\n{%d %d %d}\n",value,
           tree->pv[0].path[1],
-          tree->pv[0].path_iteration_depth*INCREMENT_PLY);
+          tree->pv[0].pathd*INCPLY);
   fflush(position_lrn_file);
 }
 
-/* last modified 03/11/98 */
+/* last modified 10/25/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -964,9 +1130,8 @@ void LearnPosition(TREE *tree, int wtm, int last_value, int value) {
 *                                                                              *
 ********************************************************************************
 */
-void LearnPositionLoad(TREE *tree) {
-  register BITBOARD temp_hash_key;
-  BITBOARD word1, word2, worda, wordb;
+void LearnPositionLoad(void) {
+  BITBOARD word1, word2;
   register HASH_ENTRY *htable;
   int n, positions;
 /*
@@ -977,6 +1142,7 @@ void LearnPositionLoad(TREE *tree) {
 |                                                          |
  ----------------------------------------------------------
 */
+  if (!(learning & position_learning)) return;
   if (!position_file) return; 
   if (time_limit < 100) return;
 /*
@@ -1002,17 +1168,9 @@ void LearnPositionLoad(TREE *tree) {
   for (n=0;n<positions;n++) {
     fread(&word1,sizeof(BITBOARD),1,position_file);
     fread(&word2,sizeof(BITBOARD),1,position_file);
-    temp_hash_key=word2;
-    htable=((Shiftr(word1,63)) ? trans_ref_wa : trans_ref_ba)+
-      (((int) temp_hash_key)&hash_maska);
-    temp_hash_key=temp_hash_key>>16;
-    wordb=Shiftr(word2,16);
-    wordb=Or(wordb,Shiftl(And(word1,mask_112),48));
-
-    worda=Shiftl((BITBOARD) (Shiftr(word1,43) & 01777777),21);
-    worda=Or(worda,Shiftl((BITBOARD) 3,59));
-    htable->word1=worda;
-    htable->word2=wordb;
+    htable=trans_ref_a+(((int) word2)&hash_maska);
+    htable->word1=((BITBOARD) word1 & ((~(BITBOARD)0)>>3)) | ((BITBOARD)3<<59);
+    htable->word2=word2 ^ htable->word1;
   }
 }
 
@@ -1028,14 +1186,13 @@ void LearnPositionLoad(TREE *tree) {
 *                                                                              *
 ********************************************************************************
 */
-
 void LearnResult(TREE *tree, int wtm) {
   int move, i, j;
   int secs, last_choice;
   char cmd[32], buff[80], *nextc;
   struct tm *timestruct;
   int n_book_moves[512];
-  int t_wtm=wtm;
+  const int t_wtm=wtm;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -1076,12 +1233,12 @@ void LearnResult(TREE *tree, int wtm) {
       }
       else cluster=0;
       for (mv=tree->last[0];mv<tree->last[1];mv++) {
-        common=And(HashKey,mask_16);
+        common=HashKey & mask_16;
         MakeMove(tree, 1,*mv,wtm);
-        temp_hash_key=Xor(HashKey,wtm_random[wtm]);
-        temp_hash_key=Or(And(temp_hash_key,Compl(mask_16)),common);
+        temp_hash_key=HashKey ^ wtm_random[wtm];
+        temp_hash_key=(temp_hash_key & ~mask_16) | common;
         for (j=0;j<cluster;j++)
-          if (!Xor(temp_hash_key,book_buffer[j].position) &&
+          if (!(temp_hash_key ^ book_buffer[j].position) &&
               book_buffer[j].learn > (float) LEARN_COUNTER_BAD/100.0)
             n_book_moves[i]++;
         UnMakeMove(tree, 1,*mv,wtm);
