@@ -3,7 +3,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 03/11/98 */
+/* last modified 08/23/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -15,8 +15,7 @@
 *                                                                              *
 ********************************************************************************
 */
-void MakeMove(TREE *tree, int ply, int move, int wtm)
-{
+void MakeMove(TREE *tree, int ply, int move, int wtm) {
   register int piece, from, to, captured, promote;
   BITBOARD bit_move;
 /*
@@ -58,8 +57,8 @@ MakePieceMove:
   SetRL90(to,OccupiedRL90);
   SetRL45(to,OccupiedRL45);
   SetRR45(to,OccupiedRR45);
-  bit_move=Or(set_mask[from],set_mask[to]);
-  PieceOnSquare(from)=0;
+  bit_move=SetMask(from) | SetMask(to);
+  PcOnSq(from)=0;
   switch (piece) {
 /*
 ********************************************************************************
@@ -80,9 +79,8 @@ MakePieceMove:
       HashPW32(from,PawnHashKey);
       HashPW(to,HashKey);
       HashPW32(to,PawnHashKey);
-      PieceOnSquare(to)=pawn;
       if (captured == 1) {
-        if(!And(BlackPawns,set_mask[to])) {
+        if(!PcOnSq(to)) {
           ClearRL90(to-8,OccupiedRL90);
           ClearRL45(to-8,OccupiedRL45);
           ClearRR45(to-8,OccupiedRR45);
@@ -90,22 +88,23 @@ MakePieceMove:
           Clear(to-8,BlackPieces);
           HashPB(to-8,HashKey);
           HashPB32(to-8,PawnHashKey);
-          PieceOnSquare(to-8)=0;
+          PcOnSq(to-8)=0;
           Material+=PAWN_VALUE;
           TotalBlackPawns--;
           TotalPieces--;
           captured=0;
         }
       }
-  /*
-   --------------------------------------------------------------------
-  |                                                                    |
-  |  if this is a pawn promotion, remove the pawn from the counts      |
-  |  then update the correct piece board to reflect the piece just     |
-  |  created.                                                          |
-  |                                                                    |
-   --------------------------------------------------------------------
-  */
+      PcOnSq(to)=pawn;
+/*
+ --------------------------------------------------------------------
+|                                                                    |
+|  if this is a pawn promotion, remove the pawn from the counts      |
+|  then update the correct piece board to reflect the piece just     |
+|  created.                                                          |
+|                                                                    |
+ --------------------------------------------------------------------
+*/
       if (promote) {
         TotalWhitePawns--;
         Material-=PAWN_VALUE;
@@ -116,7 +115,7 @@ MakePieceMove:
         case knight:
           Set(to,WhiteKnights);
           HashNW(to,HashKey);
-          PieceOnSquare(to)=knight;
+          PcOnSq(to)=knight;
           TotalWhitePieces+=knight_v;
           WhiteMinors++;
           Material+=KNIGHT_VALUE;
@@ -125,7 +124,7 @@ MakePieceMove:
           Set(to,WhiteBishops);
           Set(to,BishopsQueens);
           HashBW(to,HashKey);
-          PieceOnSquare(to)=bishop;
+          PcOnSq(to)=bishop;
           TotalWhitePieces+=bishop_v;
           WhiteMinors++;
           Material+=BISHOP_VALUE;
@@ -134,7 +133,7 @@ MakePieceMove:
           Set(to,WhiteRooks);
           Set(to,RooksQueens);
           HashRW(to,HashKey);
-          PieceOnSquare(to)=rook;
+          PcOnSq(to)=rook;
           TotalWhitePieces+=rook_v;
           WhiteMajors++;
           Material+=ROOK_VALUE;
@@ -144,7 +143,7 @@ MakePieceMove:
           Set(to,BishopsQueens);
           Set(to,RooksQueens);
           HashQW(to,HashKey);
-          PieceOnSquare(to)=queen;
+          PcOnSq(to)=queen;
           TotalWhitePieces+=queen_v;
           WhiteMajors+=2;
           Material+=QUEEN_VALUE;
@@ -152,7 +151,7 @@ MakePieceMove:
         }
       }
       else 
-        if (((to-from) == 16) && And(mask_eptest[to],BlackPawns)) {
+        if (((to-from) == 16) && (mask_eptest[to] & BlackPawns)) {
           EnPassant(ply+1)=to-8;
           HashEP(to-8,HashKey);
         }
@@ -164,9 +163,8 @@ MakePieceMove:
       HashPB32(from,PawnHashKey);
       HashPB(to,HashKey);
       HashPB32(to,PawnHashKey);
-      PieceOnSquare(to)=-pawn;
       if (captured == 1) {
-        if(!And(WhitePawns,set_mask[to])) {
+        if(!PcOnSq(to)) {
           ClearRL90(to+8,OccupiedRL90);
           ClearRL45(to+8,OccupiedRL45);
           ClearRR45(to+8,OccupiedRR45);
@@ -174,13 +172,14 @@ MakePieceMove:
           Clear(to+8,WhitePieces);
           HashPW(to+8,HashKey);
           HashPW32(to+8,PawnHashKey);
-          PieceOnSquare(to+8)=0;
+          PcOnSq(to+8)=0;
           Material-=PAWN_VALUE;
           TotalWhitePawns--;
           TotalPieces--;
           captured=0;
         }
       }
+      PcOnSq(to)=-pawn;
 /*
  --------------------------------------------------------------------
 |                                                                    |
@@ -200,7 +199,7 @@ MakePieceMove:
         case knight:
           Set(to,BlackKnights);
           HashNB(to,HashKey);
-          PieceOnSquare(to)=-knight;
+          PcOnSq(to)=-knight;
           TotalBlackPieces+=knight_v;
           BlackMinors++;
           Material-=KNIGHT_VALUE;
@@ -209,7 +208,7 @@ MakePieceMove:
           Set(to,BlackBishops);
           Set(to,BishopsQueens);
           HashBB(to,HashKey);
-          PieceOnSquare(to)=-bishop;
+          PcOnSq(to)=-bishop;
           TotalBlackPieces+=bishop_v;
           BlackMinors++;
           Material-=BISHOP_VALUE;
@@ -218,7 +217,7 @@ MakePieceMove:
           Set(to,BlackRooks);
           Set(to,RooksQueens);
           HashRB(to,HashKey);
-          PieceOnSquare(to)=-rook;
+          PcOnSq(to)=-rook;
           TotalBlackPieces+=rook_v;
           BlackMajors++;
           Material-=ROOK_VALUE;
@@ -228,7 +227,7 @@ MakePieceMove:
           Set(to,BishopsQueens);
           Set(to,RooksQueens);
           HashQB(to,HashKey);
-          PieceOnSquare(to)=-queen;
+          PcOnSq(to)=-queen;
           TotalBlackPieces+=queen_v;
           BlackMajors+=2;
           Material-=QUEEN_VALUE;
@@ -236,7 +235,7 @@ MakePieceMove:
         }
       }
       else 
-        if (((from-to) == 16) && And(mask_eptest[to],WhitePawns)) {
+        if (((from-to) == 16) && (mask_eptest[to] & WhitePawns)) {
           EnPassant(ply+1)=to+8;
           HashEP(to+8,HashKey);
         }
@@ -256,14 +255,14 @@ MakePieceMove:
       ClearSet(bit_move,WhitePieces);
       HashNW(from,HashKey);
       HashNW(to,HashKey);
-      PieceOnSquare(to)=knight;
+      PcOnSq(to)=knight;
     }
     else {
       ClearSet(bit_move,BlackKnights);
       ClearSet(bit_move,BlackPieces);
       HashNB(from,HashKey);
       HashNB(to,HashKey);
-      PieceOnSquare(to)=-knight;
+      PcOnSq(to)=-knight;
     }
     break;
 /*
@@ -274,20 +273,21 @@ MakePieceMove:
 ********************************************************************************
 */
   case bishop:
-    ClearSet(bit_move,BishopsQueens);
+    Clear(from,BishopsQueens);
+    Set(to,BishopsQueens);
     if (wtm) {
       ClearSet(bit_move,WhiteBishops);
       ClearSet(bit_move,WhitePieces);
       HashBW(from,HashKey);
       HashBW(to,HashKey);
-      PieceOnSquare(to)=bishop;
+      PcOnSq(to)=bishop;
     }
     else {
       ClearSet(bit_move,BlackBishops);
       ClearSet(bit_move,BlackPieces);
       HashBB(from,HashKey);
       HashBB(to,HashKey);
-      PieceOnSquare(to)=-bishop;
+      PcOnSq(to)=-bishop;
     }
     break;
 /*
@@ -301,19 +301,20 @@ MakePieceMove:
 ********************************************************************************
 */
   case rook:
-    ClearSet(bit_move,RooksQueens);
+    Clear(from,RooksQueens);
+    Set(to,RooksQueens);
     if (wtm) {
       ClearSet(bit_move,WhiteRooks);
       ClearSet(bit_move,WhitePieces);
       HashRW(from,HashKey);
       HashRW(to,HashKey);
-      PieceOnSquare(to)=rook;
+      PcOnSq(to)=rook;
       if (WhiteCastle(ply+1) > 0) {
-        if ((from == 0) && (WhiteCastle(ply+1)&2)) {
+        if ((from == A1) && (WhiteCastle(ply+1)&2)) {
           WhiteCastle(ply+1)&=1;
           HashCastleW(1,HashKey);
         }
-        else if ((from == 7) && (WhiteCastle(ply+1)&1)) {
+        else if ((from == H1) && (WhiteCastle(ply+1)&1)) {
           WhiteCastle(ply+1)&=2;
           HashCastleW(0,HashKey);
         }
@@ -324,13 +325,13 @@ MakePieceMove:
       ClearSet(bit_move,BlackPieces);
       HashRB(from,HashKey);
       HashRB(to,HashKey);
-      PieceOnSquare(to)=-rook;
+      PcOnSq(to)=-rook;
       if (BlackCastle(ply+1) > 0) {
-        if ((from == 56) && (BlackCastle(ply+1)&2)) {
+        if ((from == A8) && (BlackCastle(ply+1)&2)) {
           BlackCastle(ply+1)&=1;
           HashCastleB(1,HashKey);
         }
-        else if ((from == 63) && (BlackCastle(ply+1)&1)) {
+        else if ((from == H8) && (BlackCastle(ply+1)&1)) {
           BlackCastle(ply+1)&=2;
           HashCastleB(0,HashKey);
         }
@@ -345,28 +346,30 @@ MakePieceMove:
 ********************************************************************************
 */
   case queen:
-    ClearSet(bit_move,BishopsQueens);
-    ClearSet(bit_move,RooksQueens);
+    Clear(from,BishopsQueens);
+    Set(to,BishopsQueens);
+    Clear(from,RooksQueens);
+    Set(to,RooksQueens);
     if (wtm) {
       ClearSet(bit_move,WhiteQueens);
       ClearSet(bit_move,WhitePieces);
       HashQW(from,HashKey);
       HashQW(to,HashKey);
-      PieceOnSquare(to)=queen;
+      PcOnSq(to)=queen;
     }
     else {
       ClearSet(bit_move,BlackQueens);
       ClearSet(bit_move,BlackPieces);
       HashQB(from,HashKey);
       HashQB(to,HashKey);
-      PieceOnSquare(to)=-queen;
+      PcOnSq(to)=-queen;
     }
     break;
 /*
 ********************************************************************************
 *                                                                              *
 *   make king moves.  the only special case is castling, which is indicated    *
-*   by from=4, to=6 for o-o as an example.  the king is moving from e1-g1      *
+*   by from=E1, to=G1 for o-o as an example.  the king is moving from e1-g1    *
 *   which is normally illegal.  in this case, the correct rook is also moved.  *
 *                                                                              *
 *   note that moving the king in any direction resets the x_castle [x=w or b]  *
@@ -379,7 +382,7 @@ MakePieceMove:
       ClearSet(bit_move,WhitePieces);
       HashKW(from,HashKey);
       HashKW(to,HashKey);
-      PieceOnSquare(to)=king;
+      PcOnSq(to)=king;
       WhiteKingSQ=to;
       if (WhiteCastle(ply) > 0) {
         if (WhiteCastle(ply+1)&2) HashCastleW(1,HashKey);
@@ -387,16 +390,15 @@ MakePieceMove:
         if (abs(to-from) == 2) WhiteCastle(ply+1)=-4;
         else WhiteCastle(ply+1)=0;
         if (abs(to-from) == 2) {
+          piece=rook;
           if (to == G1) {
             from=H1;
             to=F1;
-            piece=rook;
             goto MakePieceMove;
           }
           else {
             from=A1;
             to=D1;
-            piece=rook;
             goto MakePieceMove;
           }
         }
@@ -406,7 +408,7 @@ MakePieceMove:
       ClearSet(bit_move,BlackPieces);
       HashKB(from,HashKey);
       HashKB(to,HashKey);
-      PieceOnSquare(to)=-king;
+      PcOnSq(to)=-king;
       BlackKingSQ=to;
       if (BlackCastle(ply+1) > 0) {
         if (BlackCastle(ply+1)&2) HashCastleB(1,HashKey);
@@ -414,16 +416,15 @@ MakePieceMove:
         if (abs(to-from) == 2) BlackCastle(ply+1)=-4;
         else BlackCastle(ply+1)=0;
         if (abs(to-from) == 2) {
+          piece=rook;
           if (to == G8) {
             from=H8;
             to=F8;
-            piece=rook;
             goto MakePieceMove;
           }
           else {
             from=A8;
             to=D8;
-            piece=rook;
             goto MakePieceMove;
           }
         }
@@ -502,8 +503,7 @@ MakePieceMove:
  ----------------------------------------------------------
 */
     case bishop: 
-      if (SlidingDiag(piece)) Set(to,BishopsQueens);
-      else Clear(to,BishopsQueens);
+      if (!SlidingDiag(piece)) Clear(to,BishopsQueens);
       if (wtm) {
         Clear(to,BlackBishops);
         Clear(to,BlackPieces);
@@ -529,18 +529,17 @@ MakePieceMove:
  ----------------------------------------------------------
 */
     case rook: 
-      if (SlidingRow(piece)) Set(to,RooksQueens);
-      else Clear(to,RooksQueens);
+      if (!SlidingRow(piece)) Clear(to,RooksQueens);
       if (wtm) {
         Clear(to,BlackRooks);
         Clear(to,BlackPieces);
         HashRB(to,HashKey);
         if (BlackCastle(ply) > 0) {
-          if ((to == 56) && (BlackCastle(ply+1)&2)) {
+          if ((to == A8) && (BlackCastle(ply+1)&2)) {
             BlackCastle(ply+1)&=1;
             HashCastleB(1,HashKey);
           }
-          else if ((to == 63) && (BlackCastle(ply+1)&1)) {
+          else if ((to == H8) && (BlackCastle(ply+1)&1)) {
             BlackCastle(ply+1)&=2;
             HashCastleB(0,HashKey);
           }
@@ -554,11 +553,11 @@ MakePieceMove:
         Clear(to,WhitePieces);
         HashRW(to,HashKey);
         if (WhiteCastle(ply) > 0) {
-          if ((to == 0) && (WhiteCastle(ply+1)&2)) {
+          if ((to == A1) && (WhiteCastle(ply+1)&2)) {
             WhiteCastle(ply+1)&=1;
             HashCastleW(1,HashKey);
           }
-          else if ((to == 7) && (WhiteCastle(ply+1)&1)) {
+          else if ((to == H1) && (WhiteCastle(ply+1)&1)) {
             WhiteCastle(ply+1)&=2;
             HashCastleW(0,HashKey);
           }
@@ -576,10 +575,8 @@ MakePieceMove:
  ----------------------------------------------------------
 */
     case queen: 
-      if (SlidingDiag(piece)) Set(to,BishopsQueens);
-      else Clear(to,BishopsQueens);
-      if (SlidingRow(piece)) Set(to,RooksQueens);
-      else Clear(to,RooksQueens);
+      if (!SlidingDiag(piece)) Clear(to,BishopsQueens);
+      if (!SlidingRow(piece)) Clear(to,RooksQueens);
       if (wtm) {
         Clear(to,BlackQueens);
         Clear(to,BlackPieces);
@@ -629,8 +626,7 @@ MakePieceMove:
 *                                                                              *
 ********************************************************************************
 */
-void MakeMoveRoot(TREE *tree, int move, int wtm)
-{
+void MakeMoveRoot(TREE *tree, int move, int wtm) {
 /*
  ----------------------------------------------------------
 |                                                          |
