@@ -3,7 +3,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* modified 03/11/97 */
+/* modified 03/23/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -16,13 +16,11 @@
 *                                                                              *
 ********************************************************************************
 */
-int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
-{
+int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move) {
   register BITBOARD target, piecebd, moves;
   register BITBOARD  promotions, pcapturesl, pcapturesr;
   register int from, to, temp;
 
-  if (wtm) {
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -33,14 +31,15 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
+  if (wtm) {
     piecebd=WhiteKnights;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(knight_attacks[from],BlackPieces);
+      moves=knight_attacks[from] & BlackPieces;
       temp=from+(knight<<12);
       while (moves) {
         to=LastOne(moves);
-        *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+        *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -58,11 +57,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteBishops;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksBishop(from),BlackPieces);
+      moves=AttacksBishop(from) & BlackPieces;
       temp=from+(bishop<<12);
       while (moves) {
         to=LastOne(moves);
-        *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+        *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -80,11 +79,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteRooks;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksRook(from),BlackPieces);
+      moves=AttacksRook(from) & BlackPieces;
       temp=from+(rook<<12);
       while (moves) {
         to=LastOne(moves);
-        *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+        *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -102,11 +101,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteQueens;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksQueen(from),BlackPieces);
+      moves=AttacksQueen(from) & BlackPieces;
       temp=from+(queen<<12);
       while (moves) {
         to=LastOne(moves);
-        *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+        *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -122,11 +121,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=WhiteKingSQ;
-    moves=And(king_attacks[from],BlackPieces);
+    moves=king_attacks[from] & BlackPieces;
     temp=from+(king<<12);
     while (moves) {
       to=LastOne(moves);
-      *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+      *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
       Clear(to,moves);
     }
 /*
@@ -143,39 +142,35 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    promotions=And(Shiftr(And(WhitePawns,rank_mask[RANK7]),8),Compl(Occupied));
+    promotions=(WhitePawns & rank_mask[RANK7])>>8 & ~Occupied;
     while (promotions) {
       to=LastOne(promotions);
       *move++=(to-8)|(to<<6)|(pawn<<12)|(queen<<18);
       Clear(to,promotions);
     }
 
-    target=Or(BlackPieces,EnPassantTarget(ply));
-    pcapturesl=And(Shiftr(And(WhitePawns,mask_left_edge),7),target);
+    target=BlackPieces | EnPassantTarget(ply);
+    pcapturesl=(WhitePawns & mask_left_edge)>>7 & target;
     while (pcapturesl) {
       to=LastOne(pcapturesl);
       if (to < 56) {
-        if(PieceOnSquare(to)) 
-          *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15);
-        else
-          *move++=(to-7)|(to<<6)|(pawn<<12)|(pawn<<15);
+        register int cap=(PcOnSq(to)) ? -PcOnSq(to) : pawn;
+        *move++=(to-7)|(to<<6)|(pawn<<12)|(cap<<15);
       }
       else 
-        *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(queen<<18);
+        *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(queen<<18);
       Clear(to,pcapturesl);
     }
 
-    pcapturesr=And(Shiftr(And(WhitePawns,mask_right_edge),9),target);
+    pcapturesr=(WhitePawns & mask_right_edge)>>9 & target;
     while (pcapturesr) {
       to=LastOne(pcapturesr);
       if (to < 56) {
-        if(PieceOnSquare(to)) 
-          *move++=(to-9)|(to<<6)|(pawn<<12)|(-PieceOnSquare(to)<<15);
-        else
-          *move++=(to-9)|(to<<6)|(pawn<<12)|(pawn<<15);
+        register int cap=(PcOnSq(to)) ? -PcOnSq(to) : pawn;
+        *move++=(to-9)|(to<<6)|(pawn<<12)|(cap<<15);
       }
       else 
-        *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(queen<<18);
+        *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(queen<<18);
       Clear(to,pcapturesr);
     }
   }
@@ -193,11 +188,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackKnights;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(knight_attacks[from],WhitePieces);
+      moves=knight_attacks[from] & WhitePieces;
       temp=from+(knight<<12);
       while (moves) {
         to=FirstOne(moves);
-        *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+        *move++=temp|(to<<6)|(PcOnSq(to)<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -215,11 +210,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackBishops;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksBishop(from),WhitePieces);
+      moves=AttacksBishop(from) & WhitePieces;
       temp=from+(bishop<<12);
       while (moves) {
         to=FirstOne(moves);
-        *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+        *move++=temp|(to<<6)|(PcOnSq(to)<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -237,11 +232,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackRooks;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksRook(from),WhitePieces);
+      moves=AttacksRook(from) & WhitePieces;
       temp=from+(rook<<12);
       while (moves) {
         to=FirstOne(moves);
-        *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+        *move++=temp|(to<<6)|(PcOnSq(to)<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -259,11 +254,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackQueens;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksQueen(from),WhitePieces);
+      moves=AttacksQueen(from) & WhitePieces;
       temp=from+(queen<<12);
       while (moves) {
         to=FirstOne(moves);
-        *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+        *move++=temp|(to<<6)|(PcOnSq(to)<<15);
         Clear(to,moves);
       }
       Clear(from,piecebd);
@@ -279,11 +274,11 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=BlackKingSQ;
-    moves=And(king_attacks[from],WhitePieces);
+    moves=king_attacks[from] & WhitePieces;
     temp=from+(king<<12);
     while (moves) {
       to=FirstOne(moves);
-      *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+      *move++=temp|(to<<6)|(PcOnSq(to)<<15);
       Clear(to,moves);
     }
 /*
@@ -300,47 +295,42 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    promotions=And(Shiftl(And(BlackPawns,rank_mask[RANK2]),8),
-                   Compl(Occupied));
+    promotions=(BlackPawns & rank_mask[RANK2])<<8 & ~Occupied;
     while (promotions) {
       to=FirstOne(promotions);
       *move++=(to+8)|(to<<6)|(pawn<<12)|(queen<<18);
       Clear(to,promotions);
     }
 
-    target=Or(WhitePieces,EnPassantTarget(ply));
-    pcapturesl=And(Shiftl(And(BlackPawns,mask_left_edge),9),target);
+    target=WhitePieces | EnPassantTarget(ply);
+    pcapturesl=(BlackPawns & mask_left_edge)<<9 & target;
     while (pcapturesl) {
       to=FirstOne(pcapturesl);
       if (to > 7) {
-        if(PieceOnSquare(to)) 
-          *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15);
-        else
-          *move++=(to+9)|(to<<6)|(pawn<<12)|(pawn<<15);
+        register int cap=(PcOnSq(to)) ? PcOnSq(to) : pawn;
+        *move++=(to+9)|(to<<6)|(pawn<<12)|(cap<<15);
       }
       else
-        *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(queen<<18);
+        *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(queen<<18);
       Clear(to,pcapturesl);
     }
 
-    pcapturesr=And(Shiftl(And(BlackPawns,mask_right_edge),7),target);
+    pcapturesr=(BlackPawns & mask_right_edge)<<7 & target;
     while (pcapturesr) {
       to=FirstOne(pcapturesr);
       if (to > 7) {
-        if(PieceOnSquare(to)) 
-          *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15);
-        else
-          *move++=(to+7)|(to<<6)|(pawn<<12)|(pawn<<15);
+        register int cap=(PcOnSq(to)) ? PcOnSq(to) : pawn;
+        *move++=(to+7)|(to<<6)|(pawn<<12)|(cap<<15);
       }
       else
-        *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(queen<<18);
+        *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(queen<<18);
       Clear(to,pcapturesr);
     }
   }
   return(move);
 }
 
-/* modified 01/11/96 */
+/* modified 08/23/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -364,8 +354,7 @@ int* GenerateCaptures(TREE *tree, int ply, int wtm, int *move)
 *                                                                              *
 ********************************************************************************
 */
-int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
-{
+int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move) {
   register BITBOARD target, targetc, targetp, piecebd, moves;
   register BITBOARD padvances1, padvances2, pcapturesl, pcapturesr;
   register BITBOARD padvances1_all, empty, checksqs;
@@ -384,25 +373,24 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
 */
   if (wtm) {
     king_square=WhiteKingSQ;
-    checksqs=And(AttacksTo(tree,king_square),BlackPieces);
+    checksqs=AttacksTo(tree,king_square) & BlackPieces;
     checkers=PopCnt(checksqs);
     if (checkers == 1) {
-      checking_square=FirstOne(And(AttacksTo(tree,king_square),
-                                    BlackPieces));
-      if (PieceOnSquare(checking_square) != -pawn)
+      checking_square=FirstOne(AttacksTo(tree,king_square) & BlackPieces);
+      if (PcOnSq(checking_square) != -pawn)
         check_direction1=directions[checking_square][king_square];
       target=InterposeSquares(check_direction1,king_square,checking_square);
-      target=Or(target,And(AttacksTo(tree,king_square),BlackPieces));
-      target=Or(target,BlackKing);
+      target=target | (AttacksTo(tree,king_square) & BlackPieces);
+      target=target | BlackKing;
     }
     else {
       target=BlackKing;
       checking_square=FirstOne(checksqs);
-      if (PieceOnSquare(checking_square) != -pawn)
+      if (PcOnSq(checking_square) != -pawn)
         check_direction1=directions[checking_square][king_square];
       Clear(checking_square,checksqs);
       checking_square=FirstOne(checksqs);
-      if (PieceOnSquare(checking_square) != -pawn)
+      if (PcOnSq(checking_square) != -pawn)
         check_direction2=directions[checking_square][king_square];
     }
 /*
@@ -426,13 +414,13 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=king_square;
-    moves=And(king_attacks[from],Compl(WhitePieces));
+    moves=king_attacks[from] & ~WhitePieces;
     temp=from+(king<<12);
     while (moves) {
       to=LastOne(moves);
       if (!Attacked(tree,to,0) && (directions[from][to] != check_direction1) &&
                                  (directions[from][to] != check_direction2))
-        *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+        *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
       Clear(to,moves);
     }
 /*
@@ -450,11 +438,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=LastOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(knight_attacks[from],target);
+          moves=knight_attacks[from] & target;
           temp=from+(knight<<12);
           while (moves) {
             to=LastOne(moves);
-            *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+            *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
             Clear(to,moves);
           }
         }
@@ -474,11 +462,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=LastOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksBishop(from),target);
+          moves=AttacksBishop(from) & target;
           temp=from+(bishop<<12);
           while (moves) {
             to=LastOne(moves);
-            *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+            *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
             Clear(to,moves);
           }
         }
@@ -498,11 +486,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=LastOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksRook(from),target);
+          moves=AttacksRook(from) & target;
           temp=from+(rook<<12);
           while (moves) {
             to=LastOne(moves);
-            *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+            *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
             Clear(to,moves);
           }
         }
@@ -522,11 +510,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=LastOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksQueen(from),target);
+          moves=AttacksQueen(from) & target;
           temp=from+(queen<<12);
           while (moves) {
             to=LastOne(moves);
-            *move++=temp|(to<<6)|((-PieceOnSquare(to))<<15);
+            *move++=temp|(to<<6)|((-PcOnSq(to))<<15);
             Clear(to,moves);
           }
         }
@@ -546,11 +534,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-      empty=Compl(Occupied);
-      targetp=And(target,empty);
-      padvances1=And(Shiftr(WhitePawns,8),targetp);
-      padvances1_all=And(Shiftr(WhitePawns,8),empty);
-      padvances2=And(Shiftr(And(padvances1_all,Shiftr(mask_8,16)),8),targetp);
+      empty=~Occupied;
+      targetp=target & empty;
+      padvances1=WhitePawns>>8 & targetp;
+      padvances1_all=WhitePawns>>8& empty;
+      padvances2=(padvances1_all & (mask_8>>16))>>8 & targetp;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -579,26 +567,24 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
         Clear(to,padvances1);
       }
 
-      targetc=Or(BlackPieces,EnPassantTarget(ply));
-      targetc=And(targetc,target);
-      if (And(And(BlackPawns,target),Shiftl(EnPassantTarget(ply),8)))
-        targetc=Or(targetc,EnPassantTarget(ply));
-      pcapturesl=And(Shiftr(And(WhitePawns,mask_left_edge),7),targetc);
-      pcapturesr=And(Shiftr(And(WhitePawns,mask_right_edge),9),targetc);
+      targetc=BlackPieces | EnPassantTarget(ply);
+      targetc=targetc & target;
+      if (BlackPawns & target & EnPassantTarget(ply)<<8)
+        targetc=targetc | EnPassantTarget(ply);
+      pcapturesl=(WhitePawns & mask_left_edge)>>7 & targetc;
+      pcapturesr=(WhitePawns & mask_right_edge)>>9 & targetc;
       while (pcapturesl) {
         to=LastOne(pcapturesl);
         if (!PinnedOnKing(tree,wtm,to-7)) {
           if (to < 56) {
-            if(PieceOnSquare(to)) 
-              *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15);
-            else
-              *move++=(to-7)|(to<<6)|(pawn<<12)|(pawn<<15);
+            register int cap=(PcOnSq(to)) ? -PcOnSq(to) : pawn;
+            *move++=(to-7)|(to<<6)|(pawn<<12)|(cap<<15);
           }
           else {
-            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(queen<<18);
-            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(rook<<18);
-            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(bishop<<18);
-            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(knight<<18);
+            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(queen<<18);
+            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(rook<<18);
+            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(bishop<<18);
+            *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(knight<<18);
           }
         }
         Clear(to,pcapturesl);
@@ -607,16 +593,14 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
         to=LastOne(pcapturesr);
         if (!PinnedOnKing(tree,wtm,to-9)) {
           if (to < 56) {
-            if(PieceOnSquare(to)) 
-              *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15);
-            else
-              *move++=(to-9)|(to<<6)|(pawn<<12)|(pawn<<15);
+            register int cap=(PcOnSq(to)) ? -PcOnSq(to) : pawn;
+            *move++=(to-9)|(to<<6)|(pawn<<12)|(cap<<15);
           }
           else {
-            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(queen<<18);
-            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(rook<<18);
-            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(bishop<<18);
-            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(knight<<18);
+            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(queen<<18);
+            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(rook<<18);
+            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(bishop<<18);
+            *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(knight<<18);
           }
         }
         Clear(to,pcapturesr);
@@ -634,25 +618,24 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
 */
   else {
     king_square=BlackKingSQ;
-    checksqs=And(AttacksTo(tree,king_square),WhitePieces);
+    checksqs=AttacksTo(tree,king_square) & WhitePieces;
     checkers=PopCnt(checksqs);
     if (checkers == 1) {
-      checking_square=FirstOne(And(AttacksTo(tree,king_square),
-                                    WhitePieces));
-      if (PieceOnSquare(checking_square) != pawn)
+      checking_square=FirstOne(AttacksTo(tree,king_square) & WhitePieces);
+      if (PcOnSq(checking_square) != pawn)
         check_direction1=directions[checking_square][king_square];
       target=InterposeSquares(check_direction1,king_square,checking_square);
-      target=Or(target,And(AttacksTo(tree,king_square),WhitePieces));
-      target=Or(target,WhiteKing);
+      target=target | (AttacksTo(tree,king_square) & WhitePieces);
+      target=target | WhiteKing;
     }
     else {
       target=WhiteKing;
       checking_square=FirstOne(checksqs);
-      if (PieceOnSquare(checking_square) != pawn)
+      if (PcOnSq(checking_square) != pawn)
         check_direction1=directions[checking_square][king_square];
       Clear(checking_square,checksqs);
       checking_square=FirstOne(checksqs);
-      if (PieceOnSquare(checking_square) != pawn)
+      if (PcOnSq(checking_square) != pawn)
         check_direction2=directions[checking_square][king_square];
     }
 /*
@@ -676,13 +659,13 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=king_square;
-    moves=And(king_attacks[from],Compl(BlackPieces));
+    moves=king_attacks[from] & ~BlackPieces;
     temp=from+(king<<12);
     while (moves) {
       to=FirstOne(moves);
       if (!Attacked(tree,to,1) && (directions[from][to] != check_direction1) &&
                                  (directions[from][to] != check_direction2))
-        *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+        *move++=temp|(to<<6)|(PcOnSq(to)<<15);
       Clear(to,moves);
     }
 /*
@@ -700,11 +683,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=FirstOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(knight_attacks[from],target);
+          moves=knight_attacks[from] & target;
           temp=from+(knight<<12);
           while (moves) {
             to=FirstOne(moves);
-            *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+            *move++=temp|(to<<6)|(PcOnSq(to)<<15);
             Clear(to,moves);
           }
         }
@@ -724,11 +707,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=FirstOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksBishop(from),target);
+          moves=AttacksBishop(from) & target;
           temp=from+(bishop<<12);
           while (moves) {
             to=FirstOne(moves);
-            *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+            *move++=temp|(to<<6)|(PcOnSq(to)<<15);
             Clear(to,moves);
           }
         }
@@ -748,11 +731,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=FirstOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksRook(from),target);
+          moves=AttacksRook(from) & target;
           temp=from+(rook<<12);
           while (moves) {
             to=FirstOne(moves);
-            *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+            *move++=temp|(to<<6)|(PcOnSq(to)<<15);
             Clear(to,moves);
           }
         }
@@ -770,11 +753,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
       while (piecebd) {
         from=FirstOne(piecebd);
         if (!PinnedOnKing(tree,wtm,from)) {
-          moves=And(AttacksQueen(from),target);
+          moves=AttacksQueen(from) & target;
           temp=from+(queen<<12);
           while (moves) {
             to=FirstOne(moves);
-            *move++=temp|(to<<6)|(PieceOnSquare(to)<<15);
+            *move++=temp|(to<<6)|(PcOnSq(to)<<15);
             Clear(to,moves);
           }
         }
@@ -800,11 +783,11 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-      empty=Compl(Occupied);
-      targetp=And(target,empty);
-      padvances1=And(Shiftl(BlackPawns,8),targetp);
-      padvances1_all=And(Shiftl(BlackPawns,8),empty);
-      padvances2=And(Shiftl(And(padvances1_all,Shiftl(mask_120,16)),8),targetp);
+      empty=~Occupied;
+      targetp=target & empty;
+      padvances1=BlackPawns<<8 & targetp;
+      padvances1_all=BlackPawns<<8 & empty;
+      padvances2=(padvances1_all & (mask_120<<16))<<8 & targetp;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -833,26 +816,24 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
         Clear(to,padvances1);
       }
 
-      targetc=Or(WhitePieces,EnPassantTarget(ply));
-      targetc=And(targetc,target);
-      if (And(And(WhitePawns,target),Shiftr(EnPassantTarget(ply),8)))
-        targetc=Or(targetc,EnPassantTarget(ply));
-      pcapturesl=And(Shiftl(And(BlackPawns,mask_left_edge),9),targetc);
-      pcapturesr=And(Shiftl(And(BlackPawns,mask_right_edge),7),targetc);
+      targetc=WhitePieces | EnPassantTarget(ply);
+      targetc=targetc & target;
+      if (WhitePawns & target & EnPassantTarget(ply)>>8)
+        targetc=targetc | EnPassantTarget(ply);
+      pcapturesl=(BlackPawns & mask_left_edge)<<9 & targetc;
+      pcapturesr=(BlackPawns & mask_right_edge)<<7 & targetc;
       while (pcapturesl) {
         to=FirstOne(pcapturesl);
         if (!PinnedOnKing(tree,wtm,to+9)) {
           if (to > 7) {
-            if(PieceOnSquare(to)) 
-              *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15);
-            else
-              *move++=(to+9)|(to<<6)|(pawn<<12)|(pawn<<15);
+            register int cap=(PcOnSq(to)) ? PcOnSq(to) : pawn;
+            *move++=(to+9)|(to<<6)|(pawn<<12)|(cap<<15);
           }
           else {
-            *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(queen<<18);
-            *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(rook<<18);
-            *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(bishop<<18);
-            *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(knight<<18);
+            *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(queen<<18);
+            *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(rook<<18);
+            *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(bishop<<18);
+            *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(knight<<18);
           }
         }
         Clear(to,pcapturesl);
@@ -861,16 +842,14 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
         to=FirstOne(pcapturesr);
         if (!PinnedOnKing(tree,wtm,to+7)) {
           if (to > 7) {
-            if(PieceOnSquare(to)) 
-              *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15);
-            else
-              *move++=(to+7)|(to<<6)|(pawn<<12)|(pawn<<15);
+            register int cap=(PcOnSq(to)) ? PcOnSq(to) : pawn;
+            *move++=(to+7)|(to<<6)|(pawn<<12)|(cap<<15);
           }
           else {
-            *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(queen<<18);
-            *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(rook<<18);
-            *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(bishop<<18);
-            *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(knight<<18);
+            *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(queen<<18);
+            *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(rook<<18);
+            *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(bishop<<18);
+            *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(knight<<18);
           }
         }
         Clear(to,pcapturesr);
@@ -903,8 +882,7 @@ int* GenerateCheckEvasions(TREE *tree, int ply, int wtm, int *move)
 *                                                                              *
 ********************************************************************************
 */
-int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
-{
+int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move) {
   register BITBOARD target, piecebd, moves;
   register BITBOARD  padvances1, padvances2, pcapturesl, pcapturesr;
   register int from, to, temp;
@@ -918,11 +896,11 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     if (WhiteCastle(ply) > 0) {
-      if ((WhiteCastle(ply)&1) && !And(Occupied,Shiftr(mask_2,5)) &&
+      if ((WhiteCastle(ply)&1) && !(Occupied & mask_white_OO) &&
           !Attacked(tree,E1,0) && !Attacked(tree,F1,0) && !Attacked(tree,G1,0)) {
         *move++=12676;
       }
-      if ((WhiteCastle(ply)&2) && !And(Occupied,Shiftr(mask_3,1)) &&
+      if ((WhiteCastle(ply)&2) && !(Occupied & mask_white_OOO) &&
           !Attacked(tree,C1,0) && !Attacked(tree,D1,0) && !Attacked(tree,E1,0)) {
         *move++=12420;
       }
@@ -937,11 +915,11 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    target=Compl(Occupied);
+    target=~Occupied;
     piecebd=WhiteKnights;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(knight_attacks[from],target);
+      moves=knight_attacks[from] & target;
       temp=from+(knight<<12);
       while (moves) {
         to=LastOne(moves);
@@ -963,7 +941,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteBishops;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksBishop(from),target);
+      moves=AttacksBishop(from) & target;
       temp=from+(bishop<<12);
       while (moves) {
         to=LastOne(moves);
@@ -985,7 +963,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteRooks;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksRook(from),target);
+      moves=AttacksRook(from) & target;
       temp=from+(rook<<12);
       while (moves) {
         to=LastOne(moves);
@@ -1007,7 +985,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=WhiteQueens;
     while (piecebd) {
       from=LastOne(piecebd);
-      moves=And(AttacksQueen(from),target);
+      moves=AttacksQueen(from) & target;
       temp=from+(queen<<12);
       while (moves) {
         to=LastOne(moves);
@@ -1027,7 +1005,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=WhiteKingSQ;
-    moves=And(king_attacks[from],target);
+    moves=king_attacks[from] & target;
     temp=from+(king<<12);
     while (moves) {
       to=LastOne(moves);
@@ -1053,8 +1031,8 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    padvances1=And(Shiftr(WhitePawns,8),target);
-    padvances2=And(Shiftr(And(padvances1,mask_advance_2_w),8),target);
+    padvances1=WhitePawns>>8 & target;
+    padvances2=(padvances1 & mask_advance_2_w)>>8 & target;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -1081,21 +1059,21 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
       Clear(to,padvances1);
     }
 
-    target=And(BlackPieces,rank_mask[RANK8]);
-    pcapturesl=And(Shiftr(And(WhitePawns,mask_left_edge),7),target);
-    pcapturesr=And(Shiftr(And(WhitePawns,mask_right_edge),9),target);
+    target=BlackPieces & rank_mask[RANK8];
+    pcapturesl=(WhitePawns & mask_left_edge)>>7 & target;
+    pcapturesr=(WhitePawns & mask_right_edge)>>9 & target;
     while (pcapturesl) {
       to=LastOne(pcapturesl);
-      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(rook<<18);
-      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(bishop<<18);
-      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(knight<<18);
+      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(rook<<18);
+      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(bishop<<18);
+      *move++=(to-7)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(knight<<18);
       Clear(to,pcapturesl);
     }
     while (pcapturesr) {
       to=LastOne(pcapturesr);
-      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(rook<<18);
-      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(bishop<<18);
-      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PieceOnSquare(to))<<15)|(knight<<18);
+      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(rook<<18);
+      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(bishop<<18);
+      *move++=(to-9)|(to<<6)|(pawn<<12)|((-PcOnSq(to))<<15)|(knight<<18);
       Clear(to,pcapturesr);
     }
   }
@@ -1108,11 +1086,11 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
 */
   else {
     if (BlackCastle(ply) > 0) {
-      if ((BlackCastle(ply)&1) && !And(Occupied,Shiftr(mask_2,61)) &&
+      if ((BlackCastle(ply)&1) && !(Occupied & mask_black_OO) &&
           !Attacked(tree,E8,1) && !Attacked(tree,F8,1) && !Attacked(tree,G8,1)) {
         *move++=16316;
       }
-      if ((BlackCastle(ply)&2) && !And(Occupied,Shiftr(mask_3,57)) &&
+      if ((BlackCastle(ply)&2) && !(Occupied & mask_black_OOO) &&
           !Attacked(tree,C8,1) && !Attacked(tree,D8,1) && !Attacked(tree,E8,1)) {
         *move++=16060;
       }
@@ -1127,11 +1105,11 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    target=Compl(Occupied);
+    target=~Occupied;
     piecebd=BlackKnights;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(knight_attacks[from],target);
+      moves=knight_attacks[from] & target;
       temp=from+(knight<<12);
       while (moves) {
         to=FirstOne(moves);
@@ -1153,7 +1131,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackBishops;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksBishop(from),target);
+      moves=AttacksBishop(from) & target;
       temp=from+(bishop<<12);
       while (moves) {
         to=FirstOne(moves);
@@ -1175,7 +1153,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackRooks;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksRook(from),target);
+      moves=AttacksRook(from) & target;
       temp=from+(rook<<12);
       while (moves) {
         to=FirstOne(moves);
@@ -1197,7 +1175,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
     piecebd=BlackQueens;
     while (piecebd) {
       from=FirstOne(piecebd);
-      moves=And(AttacksQueen(from),target);
+      moves=AttacksQueen(from) & target;
       temp=from+(queen<<12);
       while (moves) {
         to=FirstOne(moves);
@@ -1217,7 +1195,7 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
  ----------------------------------------------------------
 */
     from=BlackKingSQ;
-    moves=And(king_attacks[from],target);
+    moves=king_attacks[from] & target;
     temp=from+(king<<12);
     while (moves) {
       to=FirstOne(moves);
@@ -1243,8 +1221,8 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
 |                                                          |
  ----------------------------------------------------------
 */
-    padvances1=And(Shiftl(BlackPawns,8),target);
-    padvances2=And(Shiftl(And(padvances1,mask_advance_2_b),8),target);
+    padvances1=BlackPawns<<8 & target;
+    padvances2=(padvances1 & mask_advance_2_b)<<8 & target;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -1269,21 +1247,21 @@ int* GenerateNonCaptures(TREE *tree, int ply, int wtm, int *move)
       }
       Clear(to,padvances1);
     }
-    target=And(WhitePieces,rank_mask[RANK1]);
-    pcapturesl=And(Shiftl(And(BlackPawns,mask_left_edge),9),target);
-    pcapturesr=And(Shiftl(And(BlackPawns,mask_right_edge),7),target);
+    target=WhitePieces & rank_mask[RANK1];
+    pcapturesl=(BlackPawns & mask_left_edge)<<9 & target;
+    pcapturesr=(BlackPawns & mask_right_edge)<<7 & target;
     while (pcapturesl) {
       to=FirstOne(pcapturesl);
-      *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(rook<<18);
-      *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(bishop<<18);
-      *move++=(to+9)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(knight<<18);
+      *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(rook<<18);
+      *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(bishop<<18);
+      *move++=(to+9)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(knight<<18);
       Clear(to,pcapturesl);
     }
     while (pcapturesr) {
       to=FirstOne(pcapturesr);
-      *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(rook<<18);
-      *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(bishop<<18);
-      *move++=(to+7)|(to<<6)|(pawn<<12)|(PieceOnSquare(to)<<15)|(knight<<18);
+      *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(rook<<18);
+      *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(bishop<<18);
+      *move++=(to+7)|(to<<6)|(pawn<<12)|(PcOnSq(to)<<15)|(knight<<18);
       Clear(to,pcapturesr);
     }
   }
