@@ -21,7 +21,7 @@ char* OutputMove(TREE *tree, int move, int ply, int wtm) {
   static char text_move[10], new_text[10];
   int *mvp;
   char *text;
-  char piece_names[8] = { ' ','P','N','K',' ','B','R','Q'};
+  static const char piece_names[8] = { ' ','P','N','K',' ','B','R','Q'};
 
   text=text_move;
 /*
@@ -165,10 +165,10 @@ char* OutputMove(TREE *tree, int move, int ply, int wtm) {
 *                                                                              *
 ********************************************************************************
 */
-char* OutputMoveICS(TREE *tree, int move) {
+char* OutputMoveICS(int move) {
   static char text_move[10];
   char *text;
-  char piece_names[8] = { ' ','P','N','K',' ','B','R','Q'};
+  static const char piece_names[8] = { ' ','P','N','K',' ','B','R','Q'};
 
 /*
    convert to fully-qualified algebraic form first.
@@ -184,8 +184,7 @@ char* OutputMoveICS(TREE *tree, int move) {
   return (text_move);
 }
 
-int OutputGood(TREE *tree, char* text, int ply, int wtm)
-{
+int OutputGood(TREE *tree, char* text, int ply, int wtm) {
   int new_move;
   new_move=InputMove(tree,text,ply,wtm,1,0);
   return (Piece(new_move));
