@@ -4,7 +4,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 07/08/98 */
+/* last modified 10/18/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -24,11 +24,10 @@
 *                                                                              *
 ********************************************************************************
 */
-int Ponder(int wtm)
-{
-  int dummy=0, i, *n_ponder_moves, *mv;
+int Ponder(int wtm) {
+  int dalpha=-999999, dbeta=999999, dthreat=0, i, *n_ponder_moves, *mv;
   int save_move_number;
-  TREE *tree=local[0];
+  TREE * const tree=local[0];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -58,49 +57,49 @@ int Ponder(int wtm)
     if (!LegalMove(tree,1,wtm,ponder_move)) {
       ponder_move=0;
       Print(4095,"ERROR.  ponder_move is illegal (1).\n");
-      Print(4095,"ERROR.  PV path_length=%d\n",last_pv.path_length);
-      Print(4095,"ERROR.  move=%d  %x\n",last_pv,last_pv);
+      Print(4095,"ERROR.  PV pathl=%d\n",last_pv.pathl);
+      Print(4095,"ERROR.  move=%d  %x\n",ponder_move,ponder_move);
     }
   }
   if (!ponder_move) {
-    (void) LookUp(tree,0,0,wtm,&dummy,&dummy,&dummy);
+    (void) HashProbe(tree,0,0,wtm,&dalpha,&dbeta,&dthreat);
     if (tree->hash_move[0]) ponder_move=tree->hash_move[0];
     if (ponder_move) {
       if (!LegalMove(tree,1,wtm,ponder_move)) {
         ponder_move=0;
         Print(4095,"ERROR.  ponder_move is illegal (2).\n");
-        Print(4095,"ERROR.  PV path_length=%d\n",last_pv.path_length);
-        Print(4095,"ERROR.  move=%d  %x\n",last_pv,last_pv);
+        Print(4095,"ERROR.  PV pathl=%d\n",last_pv.pathl);
+        Print(4095,"ERROR.  move=%d  %x\n",ponder_move,ponder_move);
       }
     }
   }
   if (!ponder_move) {
     TimeSet(puzzle);
-    if (time_limit < 10) return(0);
+    if (time_limit < 20) return(0);
     puzzling=1;
     tree->position[1]=tree->position[0];
     Print(128,"              puzzling over a move to ponder.\n");
-    last_pv.path_length=0;
-    last_pv.path_iteration_depth=0;
+    last_pv.pathl=0;
+    last_pv.pathd=0;
     for (i=0;i<MAXPLY;i++) {
-      tree->killer_move1[i]=0;
-      tree->killer_move2[i]=0;
+      tree->killers[i].move1=0;
+      tree->killers[i].move2=0;
     }
     (void) Iterate(wtm,puzzle,0);
     for (i=0;i<MAXPLY;i++) {
-      tree->killer_move1[i]=0;
-      tree->killer_move2[i]=0;
+      tree->killers[i].move1=0;
+      tree->killers[i].move2=0;
     }
     puzzling=0;
-    if (tree->pv[0].path_length) ponder_move=tree->pv[0].path[1];
+    if (tree->pv[0].pathl) ponder_move=tree->pv[0].path[1];
     if (!ponder_move) return(0);
-    for (i=1;i<(int) tree->pv[0].path_length;i++) last_pv.path[i]=tree->pv[0].path[i+1];
-    last_pv.path_length=tree->pv[0].path_length-1;
-    last_pv.path_iteration_depth=0;
+    for (i=1;i<(int) tree->pv[0].pathl;i++) last_pv.path[i]=tree->pv[0].path[i+1];
+    last_pv.pathl=tree->pv[0].pathl-1;
+    last_pv.pathd=0;
     if (!LegalMove(tree,1,wtm,ponder_move)) {
       ponder_move=0;
       Print(4095,"ERROR.  ponder_move is illegal (3).\n");
-      Print(4095,"ERROR.  PV path_length=%d\n",last_pv.path_length);
+      Print(4095,"ERROR.  PV pathl=%d\n",last_pv.pathl);
       return(0);
     }
   }
@@ -147,7 +146,7 @@ int Ponder(int wtm)
  ----------------------------------------------------------
 */
   MakeMove(tree,0,ponder_move,wtm);
-  if (Rule50Moves(1)==90 || Rule50Moves(1)==91) ClearHashTables();
+  if (Rule50Moves(1)==90 || Rule50Moves(1)==91) ClearHashTableScores();
   last_opponent_move=ponder_move;
   if (ChangeSide(wtm))
     *tree->rephead_w++=HashKey;
@@ -194,7 +193,7 @@ int Ponder(int wtm)
 |                                                          |
  ----------------------------------------------------------
 */
-  if (made_predicted_move) return(1);
-  if (abort_search) return(3);
+  if (input_status == 1) return(1);
+  if (input_status == 2) return(3);
   return(2);
 }
