@@ -4,7 +4,7 @@
 #include "data.h"
 #include "evaluate.h"
 
-/* last modified 05/18/96 */
+/* last modified 10/20/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -18,15 +18,16 @@
 *                                                                              *
 ********************************************************************************
 */
-void PreEvaluate(TREE *tree, int wtm)
-{
+void PreEvaluate(TREE *tree, int wtm) {
   int i, j;
   static int hashing_pawns = 0;
   static int hashing_opening = 0;
   static int hashing_middle_game = 0;
   static int hashing_end_game = 0;
+  static int hashing_kings = 0;
   static int last_wtm = 0;
-  int hash_pawns=0;
+  int hash_pawns=0, hash_kings=0;
+  int pawn_advance[8], pawn_base[8];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -40,25 +41,12 @@ void PreEvaluate(TREE *tree, int wtm)
 /*
  ----------------------------------------------------------
 |                                                          |
-|   pawn advances.  before castling, moving the king-side  |
-|   pawns is a no-no.  also, the b-pawn is restrained just |
-|   in case we castle queen-side.                          |
+|   pawn advances.                                         |
 |                                                          |
  ----------------------------------------------------------
 */
-  if (opening) {
+  if (opening || middle_game) {
     hash_pawns=1;
-    pawn_advance[0]=PAWN_ADVANCE_BC_A;
-    pawn_advance[1]=PAWN_ADVANCE_BC_B;
-    pawn_advance[2]=PAWN_ADVANCE_BC_C;
-    pawn_advance[3]=PAWN_ADVANCE_BC_D;
-    pawn_advance[4]=PAWN_ADVANCE_BC_E;
-    pawn_advance[5]=PAWN_ADVANCE_BC_F;
-    pawn_advance[6]=PAWN_ADVANCE_BC_G;
-    pawn_advance[7]=PAWN_ADVANCE_BC_H;
-  }
-  else if (middle_game) {
-    hash_pawns=2;
     pawn_advance[0]=PAWN_ADVANCE_A;
     pawn_advance[1]=PAWN_ADVANCE_B;
     pawn_advance[2]=PAWN_ADVANCE_C;
@@ -69,7 +57,7 @@ void PreEvaluate(TREE *tree, int wtm)
     pawn_advance[7]=PAWN_ADVANCE_H;
   }
   else {
-    hash_pawns=3;
+    hash_pawns=2;
     pawn_advance[0]=PAWN_ADVANCE_EG_A;
     pawn_advance[1]=PAWN_ADVANCE_EG_B;
     pawn_advance[2]=PAWN_ADVANCE_EG_C;
@@ -79,46 +67,92 @@ void PreEvaluate(TREE *tree, int wtm)
     pawn_advance[6]=PAWN_ADVANCE_EG_G;
     pawn_advance[7]=PAWN_ADVANCE_EG_H;
   }
+  pawn_base[0]=PAWN_BASE_A;
+  pawn_base[1]=PAWN_BASE_B;
+  pawn_base[2]=PAWN_BASE_C;
+  pawn_base[3]=PAWN_BASE_D;
+  pawn_base[4]=PAWN_BASE_E;
+  pawn_base[5]=PAWN_BASE_F;
+  pawn_base[6]=PAWN_BASE_G;
+  pawn_base[7]=PAWN_BASE_H;
 /*
  ----------------------------------------------------------
 |                                                          |
-|   white pawns.                                           |
+|   pawns.                                                 |
 |                                                          |
  ----------------------------------------------------------
 */
   for (i=1;i<7;i++)
     for (j=0;j<8;j++)
-      pawn_value_w[i*8+j]=pawn_advance[j]*(i-3);
+      pval_w[i*8+j]=pawn_base[j]+pawn_advance[j]*(i-1);
   for (j=A6;j<A8;j++)
-    pawn_value_w[j]=PAWN_JAM;
-  if (!end_game) {
-    pawn_value_w[E4]+=CENTER_PAWNS;
-    pawn_value_w[E5]+=CENTER_PAWNS;
-    pawn_value_w[E6]+=CENTER_PAWNS;
-    pawn_value_w[D4]+=CENTER_PAWNS;
-    pawn_value_w[D5]+=CENTER_PAWNS;
-    pawn_value_w[D6]+=CENTER_PAWNS;
+    pval_w[j]+=PAWN_JAM;
+  pval_w[D2]-=CENTER_PAWN_UNMOVED;
+  pval_w[E2]-=CENTER_PAWN_UNMOVED;
+  for (i=6;i>0;i--)
+    for (j=0;j<8;j++)
+      pval_b[i*8+j]=pawn_base[j]+pawn_advance[j]*(6-i);
+  for (j=A2;j<A4;j++)
+    pval_b[j]+=PAWN_JAM;
+  pval_b[D7]-=CENTER_PAWN_UNMOVED;
+  pval_b[E7]-=CENTER_PAWN_UNMOVED;
+/*
+ 9---------------------------------------------------------
+|                                                          |
+|   kings.                                                 |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  if (((WhitePawns | BlackPawns) & mask_efgh) &&
+      ((WhitePawns | BlackPawns) & mask_abcd)) {
+    hash_kings=1;
+    for (i=0;i<64;i++) {
+      kval_w[i]=kval_wn[i];
+      kval_b[i]=kval_bn[i];
+    }
+  }
+  else if ((WhitePawns | BlackPawns) & mask_efgh) {
+    hash_kings=2;
+    for (i=0;i<64;i++) {
+      kval_w[i]=kval_wk[i];
+      kval_b[i]=kval_bk[i];
+    }
+  }
+  else if ((WhitePawns | BlackPawns) & mask_abcd) {
+    hash_kings=3;
+    for (i=0;i<64;i++) {
+      kval_w[i]=kval_wq[i];
+      kval_b[i]=kval_bq[i];
+    }
   }
 /*
  ----------------------------------------------------------
 |                                                          |
-|   black pawns.                                           |
+|   now we set the king safety values based on the values  |
+|   set by the user, or the default values.                |
 |                                                          |
  ----------------------------------------------------------
 */
-  for (i=6;i>0;i--)
-    for (j=0;j<8;j++)
-      pawn_value_b[i*8+j]=pawn_advance[j]*(4-i);
-  for (j=A2;j<A4;j++)
-    pawn_value_b[j]=PAWN_JAM;
-  if (!end_game) {
-    pawn_value_b[E3]+=CENTER_PAWNS;
-    pawn_value_b[E4]+=CENTER_PAWNS;
-    pawn_value_b[E5]+=CENTER_PAWNS;
-    pawn_value_b[D3]+=CENTER_PAWNS;
-    pawn_value_b[D4]+=CENTER_PAWNS;
-    pawn_value_b[D5]+=CENTER_PAWNS;
+  if (wtm) {
+    for (i=0;i<64;i++) {
+      temper_w[i]=temper[i];
+      temper_b[i]=temper[i]+temper[i]*king_safety_asymmetry/100;
+    }
   }
+  else {
+    for (i=0;i<64;i++) {
+      temper_w[i]=temper[i]+temper[i]*king_safety_asymmetry/100;
+      temper_b[i]=temper[i];
+    }
+  }
+  for (i=0;i<64;i++) {
+    temper_w[i]=temper_w[i]*king_safety_scale/100;
+    temper_b[i]=temper_b[i]*king_safety_scale/100;
+  }
+  for (i=0;i<128;i++)
+    tropism[i]=king_tropism[i]*king_safety_tropism/100;
+  for (i=0;i<9;i++)
+    pawn_rams[i]=blocked_scale*pawn_rams_v[i]/100;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -130,6 +164,7 @@ void PreEvaluate(TREE *tree, int wtm)
 */
   if (((last_wtm            != wtm) ||
        (hashing_pawns       != hash_pawns) ||
+       (hashing_kings       != hash_kings) ||
        (hashing_opening     != opening) ||
        (hashing_middle_game != middle_game) ||
        (hashing_end_game    != end_game)) && !test_mode) {
@@ -142,9 +177,10 @@ void PreEvaluate(TREE *tree, int wtm)
  ------------------------------------------------
 */
     Print(128,"              clearing hash tables\n");
-    ClearHashTables();
+    ClearHashTableScores();
   }
   hashing_pawns=hash_pawns;
+  hashing_kings=hash_kings;
   hashing_opening=opening;
   hashing_middle_game=middle_game;
   hashing_end_game=end_game;
