@@ -4,7 +4,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 06/05/98 */
+/* last modified 10/20/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -16,7 +16,7 @@
 ********************************************************************************
 */
 int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
-  register int initial_alpha, value, delta;
+  register int o_alpha, value, delta;
   register int *next_move;
   register int *goodmv, *movep, moves=0, *sortv, temp;
 /*
@@ -30,7 +30,7 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
   tree->nodes_searched++;
   next_time_check--;
   tree->last[ply]=tree->last[ply-1];
-  initial_alpha=alpha;
+  o_alpha=alpha;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -46,9 +46,9 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
   if (value > alpha) {
     if (value >= beta) return(value);
     alpha=value;
-    tree->pv[ply].path_length=ply-1;
-    tree->pv[ply].path_hashed=0;
-    tree->pv[ply].path_iteration_depth=iteration_depth;
+    tree->pv[ply].pathl=ply-1;
+    tree->pv[ply].pathh=0;
+    tree->pv[ply].pathd=iteration_depth;
   }
 /*
  ----------------------------------------------------------
@@ -63,7 +63,7 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
  ----------------------------------------------------------
 */
   tree->last[ply]=GenerateCaptures(tree, ply, wtm, tree->last[ply-1]);
-  delta=alpha-50-(wtm?Material:-Material);
+  delta=alpha-100-(wtm?Material:-Material);
   goodmv=tree->last[ply-1];
   sortv=tree->sort_value;
   for (movep=tree->last[ply-1];movep<tree->last[ply];movep++)
@@ -88,30 +88,32 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
 /*
  ----------------------------------------------------------
 |                                                          |
-|   don't disdain the lowly bubble sort here.  the list of |
-|   captures is always short, and experiments with other   |
-|   algorithms are always slightly slower.                 |
+|   this is a simple insertion sort algorithm.  it seems   |
+|   be no faster than a normal bubble sort, but using this |
+|   eliminated a lot of explaining about "why?". :)        |
 |                                                          |
  ----------------------------------------------------------
 */
-  if (moves > 1) {
-    register int done;
-    register int *end=tree->last[ply-1]+moves-1;
-    do {
-      done=1;
-      sortv=tree->sort_value;
-      movep=tree->last[ply-1];
-      for (;movep<end;movep++,sortv++)
-        if (*sortv < *(sortv+1)) {
-          temp=*sortv;
-          *sortv=*(sortv+1);
-          *(sortv+1)=temp;
-          temp=*movep;
-          *movep=*(movep+1);
-          *(movep+1)=temp;
-          done=0;
-        }
-    } while(!done);
+  if (moves) {
+    int temp1, temp2, *movep, *tmovep, *sortv, *tsortv;
+    int *end;
+    sortv=tree->sort_value+1;
+    movep=tree->last[ply-1]+1;
+    end=tree->last[ply-1]+moves;
+    for (;movep<end;movep++,sortv++) {
+      temp1=*movep;
+      temp2=*sortv;
+      tmovep=movep-1;
+      tsortv=sortv-1;
+      while (tmovep>=tree->last[ply-1] && *tsortv<temp2) {
+        *(tsortv+1)=*tsortv;
+        *(tmovep+1)=*tmovep;
+        tmovep--;
+        tsortv--;
+      }
+      *(tmovep+1)=temp1;
+      *(tsortv+1)=temp2;
+    }
   }
   next_move=tree->last[ply-1];
 /*
@@ -124,7 +126,7 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
 */
   while (moves--) {
     tree->current_move[ply]=*(next_move++);
-#if !defined(FAST)
+#if defined(TRACE)
     if (ply <= trace_level)
       SearchTrace(tree,ply,0,wtm,alpha,beta,"quiesce",CAPTURE_MOVES);
 #endif
@@ -147,10 +149,10 @@ int Quiesce(TREE *tree, int alpha, int beta, int wtm, int ply) {
 |                                                          |
  ----------------------------------------------------------
 */
-  if (alpha != initial_alpha) {
+  if (alpha != o_alpha) {
     memcpy(&tree->pv[ply-1].path[ply],&tree->pv[ply].path[ply],
-           (tree->pv[ply].path_length-ply+1)*sizeof(int));
-    memcpy(&tree->pv[ply-1].path_hashed,&tree->pv[ply].path_hashed,3);
+           (tree->pv[ply].pathl-ply+1)*sizeof(int));
+    memcpy(&tree->pv[ply-1].pathh,&tree->pv[ply].pathh,3);
     tree->pv[ply-1].path[ply-1]=tree->current_move[ply-1];
   }
   return(alpha);
