@@ -3,7 +3,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 03/11/98 */
+/* last modified 01/14/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -23,8 +23,7 @@
 *                                                                              *
 ********************************************************************************
 */
-int RepetitionCheck(TREE *tree, int ply, int wtm)
-{
+int RepetitionCheck(TREE *tree, int ply, int wtm) {
   register int entries;
   register BITBOARD *replist, *thispos;
 /*
@@ -39,15 +38,6 @@ int RepetitionCheck(TREE *tree, int ply, int wtm)
 /*
  ----------------------------------------------------------
 |                                                          |
-|   check for trivial draws, like insufficient material.   |
-|                                                          |
- ----------------------------------------------------------
-*/
-  if (!(TotalWhitePawns+TotalBlackPawns) &&
-      TotalWhitePieces<5 && TotalBlackPieces<5) return(1);
-/*
- ----------------------------------------------------------
-|                                                          |
 |   insert the board into the next slot in the repetition  |
 |   list.  then scan the list.  we look for the case where |
 |   the position has been seen one time before.            |
@@ -58,7 +48,7 @@ int RepetitionCheck(TREE *tree, int ply, int wtm)
   thispos=((wtm)?tree->rephead_w:tree->rephead_b)+((ply-1)>>1);
   *thispos=HashKey;
   for (replist=thispos-1;entries;replist--,entries--)
-    if(*thispos == *replist) return(1);
+    if(HashKey == *replist) return(1);
   return(0);
 }
 
@@ -73,8 +63,7 @@ int RepetitionCheck(TREE *tree, int ply, int wtm)
 *                                                                              *
 ********************************************************************************
 */
-int RepetitionDraw(TREE *tree, int wtm)
-{
+int RepetitionDraw(TREE *tree, int wtm) {
   register int reps;
   BITBOARD *thispos;
 /*
