@@ -4,7 +4,7 @@
 #include "data.h"
 #include "epdglue.h"
 
-/* last modified 03/11/97 */
+/* last modified 07/16/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -20,12 +20,12 @@
 *                                                                              *
 ********************************************************************************
 */
-void RootMoveList(int wtm)
-{
-  int *mvp, tempm;
+void RootMoveList(int wtm) {
+  int *mvp, *lastm, rmoves[256];
   int square, i, side, done, temp, value;
-  TREE *tree=local[0];
+  TREE * const tree=local[0];
   int tb_value;
+  int mating_via_tb=0;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -39,20 +39,12 @@ void RootMoveList(int wtm)
  ----------------------------------------------------------
 */
   EGTB_draw=0;
-  if (TotalPieces<=5 && EGTBScore(tree, 1, wtm, &tb_value)) {
-    register int wpawn, bpawn;
-    if (TotalWhitePawns && TotalBlackPawns) {
-      wpawn=FirstOne(WhitePawns);
-      bpawn=FirstOne(BlackPawns);
-      if (FileDistance(wpawn,bpawn) == 1) {
-        if(((Rank(wpawn)==RANK2) && (Rank(bpawn)>RANK3)) ||
-           ((Rank(bpawn)==RANK7) && (Rank(wpawn)<RANK6)) || 
-           EnPassant(1)) tb_value=1;
-      }
-    }
-    if (tb_value == 0) {
+  if (swindle_mode && EGTBlimit && TotalPieces<=EGTBlimit &&
+      EGTBProbe(tree, 1, wtm, &tb_value)) {
+    if (tb_value == DrawScore(1))
       if ((wtm && Material>0) || (!wtm && Material<0)) EGTB_draw=1;
-    }
+    if (tb_value > MATE-300)
+        mating_via_tb=-tb_value-1;
   }
 /*
  ----------------------------------------------------------
@@ -63,9 +55,9 @@ void RootMoveList(int wtm)
  ----------------------------------------------------------
 */
   easy_move=0;
-  tree->last[1]=GenerateCaptures(tree, 1, wtm, tree->last[0]);
-  tree->last[1]=GenerateNonCaptures(tree, 1, wtm, tree->last[1]);
-  if (tree->last[1] == tree->last[0]+1) return;
+  lastm=GenerateCaptures(tree, 1, wtm, rmoves);
+  lastm=GenerateNonCaptures(tree, 1, wtm, lastm);
+  n_root_moves=lastm-rmoves;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -74,15 +66,20 @@ void RootMoveList(int wtm)
 |                                                          |
  ----------------------------------------------------------
 */
-  for (mvp=tree->last[0];mvp<tree->last[1];mvp++) {
+  for (mvp=rmoves;mvp<lastm;mvp++) {
     value=-4000000;
     MakeMove(tree, 1, *mvp, wtm);
     if (!Check(wtm)) do {
-      if (EGTB_draw) {
-        i=EGTBScore(tree, 2, ChangeSide(wtm), &tb_value);
-        if (tb_value != 0) break;
-      }
       tree->current_move[1]=*mvp;
+      if (TotalPieces<=EGTBlimit && EGTB_draw) {
+        i=EGTBProbe(tree, 2, ChangeSide(wtm), &tb_value);
+        if (i && tb_value != DrawScore(0)) break;
+      }
+      if (mating_via_tb && TotalPieces<=EGTBlimit) {
+        i=EGTBProbe(tree, 2, ChangeSide(wtm), &tb_value);
+        if (i && ((mating_via_tb > DrawScore(0) && tb_value < mating_via_tb) ||
+                  (mating_via_tb < DrawScore(0) && tb_value > mating_via_tb))) break;
+      }
       value=-Evaluate(tree,2,ChangeSide(wtm),-99999,99999);
 /*
  ----------------------------------------------------------
@@ -95,7 +92,7 @@ void RootMoveList(int wtm)
 */
       side=(wtm) ? 1 : -1;
       for (square=0;square<64;square++) 
-        if (PieceOnSquare(square)*side > 0)
+        if (PcOnSq(square)*side > 0)
           value-=Max(EnPrise(square,ChangeSide(wtm)),0);
 /*
  ----------------------------------------------------------
@@ -126,7 +123,7 @@ void RootMoveList(int wtm)
 */
       if (Promote(*mvp) && (Promote(*mvp) != queen)) value-=50;
     } while(0);
-    tree->sort_value[mvp-tree->last[0]]=value;
+    tree->sort_value[mvp-rmoves]=value;
     UnMakeMove(tree, 1, *mvp, wtm);
   }
 /*
@@ -140,14 +137,14 @@ void RootMoveList(int wtm)
 */
   do {
     done=1;
-    for (i=0;i<tree->last[1]-tree->last[0]-1;i++) {
+    for (i=0;i<lastm-rmoves-1;i++) {
       if (tree->sort_value[i] < tree->sort_value[i+1]) {
         temp=tree->sort_value[i];
         tree->sort_value[i]=tree->sort_value[i+1];
         tree->sort_value[i+1]=temp;
-        tempm=*(tree->last[0]+i);
-        *(tree->last[0]+i)=*(tree->last[0]+i+1);
-        *(tree->last[0]+i+1)=tempm;
+        temp=rmoves[i];
+        rmoves[i]=rmoves[i+1];
+        rmoves[i+1]=temp;
         done=0;
       }
     }
@@ -160,24 +157,70 @@ void RootMoveList(int wtm)
 |                                                          |
  ----------------------------------------------------------
 */
-  for (;tree->last[1]>tree->last[0];tree->last[1]--) 
-    if (tree->sort_value[tree->last[1]-tree->last[0]-1] > -3000000) break;
+  for (;n_root_moves;n_root_moves--)
+    if (tree->sort_value[n_root_moves-1] > -3000000) break;
   if (tree->sort_value[0] > 1000000) tree->sort_value[0]-=2000000;
   if (tree->sort_value[0] > tree->sort_value[1]+200 &&
-      ((To(*tree->last[0]) == To(last_opponent_move) &&
-        Captured(*tree->last[0]) == Piece(last_opponent_move)) || 
+      ((To(rmoves[0]) == To(last_opponent_move) &&
+        Captured(rmoves[0]) == Piece(last_opponent_move)) || 
       tree->sort_value[0] < PAWN_VALUE)) easy_move=1;
-  if (trace_level > 0) {
-    printf("produced %d moves at root\n",tree->last[1]-tree->last[0]);
-    for (mvp=tree->last[0];mvp<tree->last[1];mvp++) {
-      tree->current_move[1]=*mvp;
-      printf("%s",OutputMove(tree,*mvp,1,wtm));
-      MakeMove(tree, 1, *mvp, wtm);
-      printf("/%d/%d  ",tree->sort_value[mvp-tree->last[0]],
-             -Evaluate(tree,2,ChangeSide(wtm),-99999,99999));
-      if (!((mvp-tree->last[0]+1) % 5)) printf("\n");
-      UnMakeMove(tree, 1, *mvp, wtm);
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   debugging output to dump root move list and the stuff  |
+|   used to sort them, for testing and debugging.          |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  if (display_options & 512) {
+    int score;
+    int orig_score=Evaluate(tree,1,wtm,-99999,99999)-Material;
+    Print(512,"%d moves at root\n",n_root_moves);
+    Print(512,"        move   score      eval     (+/-)\n");
+    for (i=0;i<n_root_moves;i++) {
+      tree->current_move[1]=rmoves[i];
+      Print(512,"%12s",OutputMove(tree,rmoves[i],1,wtm));
+      MakeMove(tree, 1, rmoves[i], wtm);
+      score=-Evaluate(tree,2,ChangeSide(wtm),-99999,99999);
+      Print(512,"%8d  %8d  %8d\n",tree->sort_value[i], score,
+            score-orig_score-Material);
+      UnMakeMove(tree, 1, rmoves[i], wtm);
     }
   }
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   now check to see if we are in the special mode where   |
+|   moves need to be searched because of missing EGTBs.    |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  if (mating_via_tb) {
+    for (i=0;i<n_root_moves;i++) {
+      tree->current_move[1]=rmoves[i];
+      MakeMove(tree, 1, rmoves[i], wtm);
+      if (mating_via_tb && TotalPieces <= EGTBlimit)
+        temp=(EGTBProbe(tree, 2, ChangeSide(wtm), &tb_value) != DrawScore(0));
+      else
+        temp=0;
+      UnMakeMove(tree, 1, rmoves[i], wtm);
+      if (temp) break;
+    }
+    EGTB_search=(i==n_root_moves);
+  }
+  else EGTB_search=0;
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   now copy the root moves into the root_move structure   |
+|   array for use by NextRootMove().                       |
+|                                                          |
+ ----------------------------------------------------------
+*/
+  for (i=0;i<n_root_moves;i++) {
+    root_moves[i].move=rmoves[i];
+    root_moves[i].nodes=0;
+    root_moves[i].status=0;
+  }
   return;
 }
