@@ -5,7 +5,7 @@
 #include "data.h"
 #include "epdglue.h"
 
-/* last modified 06/05/98 */
+/* last modified 10/18/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -21,10 +21,10 @@
 int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
            int ply, int do_null) {
   register int moves_searched=0;
-  register BITBOARD save_hash_key;
-  register int initial_alpha, value=0;
+  register int o_alpha, value=0;
   register int extensions, pieces;
   int threat=0;
+  register int full_extension=ply<=2*iteration_depth;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -42,8 +42,8 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
   if (--next_time_check <= 0) {
     next_time_check=nodes_between_time_checks;
     if (CheckInput()) Interrupt(ply);
-    time_abort+=TimeCheck(0);
-    if (time_abort) {
+    if (TimeCheck(0)) {
+      time_abort++;
       abort_search=1;
       return(0);
     }
@@ -57,9 +57,9 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
  ----------------------------------------------------------
 */
   if (RepetitionCheck(tree,ply,wtm)) {
-    value=DrawScore(root_wtm==wtm);
+    value=DrawScore(ply&1);
     if (value < beta) SavePV(tree,ply,value,0);
-#if !defined(FAST)
+#if defined(TRACE)
     if(ply <= trace_level) printf("draw by repetition detected, ply=%d.\n",ply);
 #endif
     return(value);
@@ -67,43 +67,43 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 /*
  ----------------------------------------------------------
 |                                                          |
-|   now call LookUp() to see if this position has been     |
+|   now call HashProbe() to see if this position has been  |
 |   searched before.  if so, we may get a real score,      |
 |   produce a cutoff, or get nothing more than a good move |
 |   to try first.  there are four cases to handle:         |
 |                                                          |
-|   1. LookUp() returned "EXACT_SCORE" if this score is    |
+|   1. HashProbe() returned "EXACT" if this score is       |
 |   greater than beta, return beta.  otherwise, return the |
 |   score.  In either case, no further searching is needed |
 |   from this position.  note that lookup verified that    |
 |   the table position has sufficient "draft" to meet the  |
 |   requirements of the current search depth remaining.    |
 |                                                          |
-|   2.  LookUp() returned "UPPER_BOUND" which means that   |
+|   2. HashProbe() returned "UPPER" which means that       |
 |   when this position was searched previously, every move |
 |   was "refuted" by one of its descendents.  as a result, |
 |   when the search was completed, we returned alpha at    |
 |   that point.  we simply return alpha here as well.      |
 |                                                          |
-|   3.  LookUp() returned "LOWER_BOUND" which means that   |
+|   3. HashProbe() returned "LOWER" which means that       |
 |   when we encountered this position before, we searched  |
 |   one branch (probably) which promptly refuted the move  |
 |   at the previous ply.                                   |
 |                                                          |
-|   4.  LookUp() returned "AVOID_NULL_MOVE" which means    |
+|   4. HashProbe() returned "AVOID_NULL_MOVE" which means  |
 |   the hashed score/bound was no good, but it indicated   |
-|   that trying a null-move in this position will be a     |
+|   that trying a null-move in this position would be a    |
 |   waste of time.                                         |
 |                                                          |
  ----------------------------------------------------------
 */
-  switch (LookUp(tree,ply,depth,wtm,&alpha,&beta,&threat)) {
-    case EXACT_SCORE:
+  switch (HashProbe(tree,ply,depth,wtm,&alpha,&beta,&threat)) {
+    case EXACT:
       if(alpha < beta) SavePV(tree,ply,alpha,1);
       return(alpha);
-    case LOWER_BOUND:
+    case LOWER:
       return(beta);
-    case UPPER_BOUND:
+    case UPPER:
       return(alpha);
     case AVOID_NULL_MOVE:
       do_null=0;
@@ -112,47 +112,26 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
  ----------------------------------------------------------
 |                                                          |
 |   now it's time to try a probe into the endgame table-   |
-|   base files.  this is done if (a) the previous move was |
-|   a capture or promotion, unless we are at very shallow  |
-|   plies (<4) in the search; (b) there are less than 5    |
-|   pieces left (currently all interesting 4 piece endings |
-|   are available.)                                        |
+|   base files.  this is done if we notice that there are  |
+|   5 or fewer pieces left on the board.  EGTB_use tells   |
+|   us how many pieces to probe on.  note that this can be |
+|   zero when trying to swindle the opponent, so that no   |
+|   probes are done since we know it is a draw.            |
 |                                                          |
  ----------------------------------------------------------
 */
-  if (EGTB_use) {
-    if (TotalPieces<=EGTB_use &&
-        (TotalPieces<5 || (WhiteRooks && BlackRooks))) do {
-      register int wpawn, bpawn;
-      int tb_value;
-      if (TotalWhitePawns && TotalBlackPawns) {
-        wpawn=FirstOne(WhitePawns);
-        bpawn=FirstOne(BlackPawns);
-        if (FileDistance(wpawn,bpawn) == 1) {
-          if(((Rank(wpawn)==RANK2) && (Rank(bpawn)>RANK3)) ||
-             ((Rank(bpawn)==RANK7) && (Rank(wpawn)<RANK6)) || 
-             EnPassant(ply)) break;
-        }
-      }
-      tree->tb_probes++;
-#if defined(SMP)
-      Lock(lock_io);
-#endif
-      if (EGTBScore(tree, ply, wtm, &tb_value)) {
-#if defined(SMP)
-        UnLock(lock_io);
-#endif
-        tree->tb_probes_successful++;
-        alpha=tb_value;
-        if (abs(alpha) > MATE-100) alpha+=(alpha > 0) ? -(ply-1) : +(ply-1);
-        else if (alpha == 0) alpha=DrawScore(root_wtm==wtm);
-        if(alpha < beta) SavePV(tree,ply,alpha,2);
-        return(alpha);
-      }
-#if defined(SMP)
-      UnLock(lock_io);
-#endif
-    } while(0);
+  if (ply<=iteration_depth && TotalPieces<=EGTB_use &&
+      (CaptureOrPromote(tree->current_move[ply-1]) || ply<3)) {
+    int egtb_value;
+    tree->egtb_probes++;
+    if (EGTBProbe(tree, ply, wtm, &egtb_value)) {
+      tree->egtb_probes_successful++;
+      alpha=egtb_value;
+      if (abs(alpha) > MATE-300) alpha+=(alpha > 0) ? -ply+1 : ply;
+      else if (alpha == 0) alpha=DrawScore(ply&1);
+      if(alpha < beta) SavePV(tree,ply,alpha,2);
+      return(alpha);
+    }
   }
 /*
  ----------------------------------------------------------
@@ -163,7 +142,7 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 */
   tree->in_check[ply+1]=0;
   tree->extended_reason[ply+1]=no_extension;
-  initial_alpha=alpha;
+  o_alpha=alpha;
   tree->last[ply]=tree->last[ply-1];
 /*
  ----------------------------------------------------------
@@ -190,7 +169,7 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |  the null-move search is also used to detect certain     |
 |  types of threats.  the original idea of using the value |
 |  returned by the null-move search was reported by C.     |
-|  donninger, but was modified by Bruce Moreland (ferret)  |
+|  Donninger, but was modified by Bruce Moreland (Ferret)  |
 |  in the following way:  if the null-move search returns  |
 |  a score that says "mated in N" then this position is a  |
 |  dangerous one, because not moving gets the side to move |
@@ -200,17 +179,18 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |  that this "threat" condition is hashed so that later,   |
 |  if the hash table says "don't try the null move because |
 |  it likely will fail low, we still know that this is a   |
-|  threat position and should be extended.                 |
+|  threat position and that it should be extended.         |
 |                                                          |
  ----------------------------------------------------------
 */
 # if defined(NULL_MOVE_DEPTH)
   pieces=(wtm) ? TotalWhitePieces : TotalBlackPieces;
-  if (do_null && !tree->in_check[ply] && pieces &&
-      (pieces>5 || depth<421)) {
+  if (do_null && !tree->in_check[ply] && pieces && (pieces>5 || depth<421)) {
+    register BITBOARD save_hash_key;
+    int null_depth;
     tree->current_move[ply]=0;
-    tree->current_phase[ply]=NULL_MOVE;
-#if !defined(FAST)
+    tree->phase[ply]=NULL_MOVE;
+#if defined(TRACE)
     if (ply <= trace_level)
       SearchTrace(tree,ply,depth,wtm,beta-1,beta,"Search",0);
 #endif
@@ -221,15 +201,19 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
       HashEP(EnPassant(ply+1),HashKey);
       EnPassant(ply+1)=0;
     }
-    value=-ABSearch(tree,-beta,-beta+1,ChangeSide(wtm),
-                    depth-NULL_MOVE_DEPTH-INCREMENT_PLY,ply+1,NO_NULL);
+    null_depth=(depth > 6*INCPLY) ? 4*INCPLY : 3*INCPLY;
+    if (depth-null_depth >= INCPLY)
+      value=-Search(tree,-beta,1-beta,ChangeSide(wtm),
+                    depth-null_depth,ply+1,NO_NULL);
+    else
+      value=-Quiesce(tree,-beta,1-beta,ChangeSide(wtm),ply+1);
     HashKey=save_hash_key;
     if (abort_search || tree->stop) return(0);
     if (value >= beta) {
-      StoreRefutation(tree,ply,depth,wtm,value,threat);
+      HashStore(tree,ply,depth,wtm,LOWER,value,threat);
       return(value);
     }
-    if (value < -MATE+30) threat=1;
+    if (value < -MATE+300) threat=1;
   }
 # endif
 /*
@@ -247,25 +231,35 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |                                                          |
  ----------------------------------------------------------
 */
-  tree->next_status[ply].phase=FIRST_PHASE;
-  if (tree->hash_move[ply]==0 && (depth > 2*INCREMENT_PLY) &&
-      (((ply & 1) && alpha == root_alpha && beta == root_beta) ||
-      (!(ply & 1) && alpha == -root_beta && beta == -root_alpha))) {
+  tree->next_status[ply].phase=HASH_MOVE;
+  if (tree->hash_move[ply]==0 && do_null && depth>=3*INCPLY) do {
+    if (ply & 1) {
+      if (alpha!=root_alpha || beta!=root_beta) break;
+    }
+    else {
+      if (alpha!=-root_beta || beta!=-root_alpha) break;
+    }
     tree->current_move[ply]=0;
-    value=ABSearch(tree,alpha,beta,wtm,depth-2*INCREMENT_PLY,ply,DO_NULL);
+    if (depth-2*INCPLY >= INCPLY)
+      value=Search(tree,alpha,beta,wtm,depth-2*INCPLY,ply,DO_NULL);
+    else
+      value=Quiesce(tree,alpha,beta,wtm,ply);
     if (abort_search || tree->stop) return(0);
     if (value <= alpha) {
-      value=ABSearch(tree,-MATE,beta,wtm,depth-2*INCREMENT_PLY,ply,DO_NULL);
+      if (depth-2*INCPLY >= INCPLY)
+        value=Search(tree,-MATE,beta,wtm,depth-2*INCPLY,ply,DO_NULL);
+      else
+        value=Quiesce(tree,-MATE,beta,wtm,ply);
       if (abort_search || tree->stop) return(0);
     }
     else if (value < beta) {
-      if ((int) tree->pv[ply-1].path_length >= ply) 
+      if ((int) tree->pv[ply-1].pathl >= ply) 
         tree->hash_move[ply]=tree->pv[ply-1].path[ply];
     }
     else tree->hash_move[ply]=tree->current_move[ply];
     tree->last[ply]=tree->last[ply-1];
-    tree->next_status[ply].phase=FIRST_PHASE;
-  }
+    tree->next_status[ply].phase=HASH_MOVE;
+  } while(0);
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -277,16 +271,31 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |                                                          |
  ----------------------------------------------------------
 */
-  while ((tree->current_phase[ply]=(tree->in_check[ply]) ? NextEvasion(tree,ply,wtm) : 
-                                               NextMove(tree,ply,wtm))) {
+  while ((tree->phase[ply]=(tree->in_check[ply]) ?
+         NextEvasion(tree,ply,wtm) : NextMove(tree,ply,wtm))) {
     tree->extended_reason[ply]&=check_extension;
-#if !defined(FAST)
+#if defined(TRACE)
     if (ply <= trace_level)
-      SearchTrace(tree,ply,depth,wtm,alpha,beta,"Search",tree->current_phase[ply]);
+      SearchTrace(tree,ply,depth,wtm,alpha,beta,"Search",tree->phase[ply]);
 #endif
 /*
  ----------------------------------------------------------
 |                                                          |
+|   if the null move found that the side on move gets      |
+|   mated by not moving, then there must be some strong    |
+|   threat at this position.  extend the search to make    |
+|   sure it is analyzed carefully.                         |
+|                                                          |
+ ----------------------------------------------------------
+*/
+    extensions=-60;
+    if (threat) {
+      extensions+=(full_extension) ? threat_depth : threat_depth>>1;
+      tree->threat_extensions_done++;
+    }
+/*
+ ----------------------------------------------------------
+|                                                          |
 |   if two successive moves are capture / re-capture so    |
 |   that the material score is restored, extend the search |
 |   by one ply on the re-capture since it is pretty much   |
@@ -294,10 +303,8 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |                                                          |
  ----------------------------------------------------------
 */
-    extensions=-60;
-    if (threat) 
-      extensions+=(ply<=2*iteration_depth) ? threat_depth : threat_depth>>1;
-    if (Captured(tree->current_move[ply]) && Captured(tree->current_move[ply-1]) &&
+    if (Captured(tree->current_move[ply]) &&
+        Captured(tree->current_move[ply-1]) &&
         To(tree->current_move[ply-1]) == To(tree->current_move[ply]) &&
         (p_values[Captured(tree->current_move[ply-1])+7] == 
          p_values[Captured(tree->current_move[ply])+7] ||
@@ -305,7 +312,7 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
         !(tree->extended_reason[ply-1]&recapture_extension)) {
       tree->extended_reason[ply]|=recapture_extension;
       tree->recapture_extensions_done++;
-      extensions+=(ply<=2*iteration_depth) ? recap_depth : recap_depth>>1;
+      extensions+=(full_extension) ? recap_depth : recap_depth>>1;
     }
 /*
  ----------------------------------------------------------
@@ -315,17 +322,11 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 |                                                          |
  ----------------------------------------------------------
 */
-    if (Piece(tree->current_move[ply])==pawn && 
-         ((wtm && To(tree->current_move[ply])>H5 && TotalBlackPieces<16 &&
-          !And(mask_pawn_passed_w[To(tree->current_move[ply])],BlackPawns)) ||
-         (!wtm && To(tree->current_move[ply])<A4 && TotalWhitePieces<16 &&
-          !And(mask_pawn_passed_b[To(tree->current_move[ply])],WhitePawns)) ||
-         push_extensions[To(tree->current_move[ply])]) &&
-         Swap(tree,From(tree->current_move[ply]),To(tree->current_move[ply]),wtm) ==
-           p_values[Captured(tree->current_move[ply])+7]) {
+    if (Piece(tree->current_move[ply])==pawn &&
+      push_extensions[To(tree->current_move[ply])]) {
       tree->extended_reason[ply]|=passed_pawn_extension;
       tree->passed_pawn_extensions_done++;
-      extensions+=(ply<=2*iteration_depth) ? pushpp_depth : pushpp_depth>>1;
+      extensions+=(full_extension) ? pushpp_depth : pushpp_depth>>1;
     }
 /*
  ----------------------------------------------------------
@@ -353,7 +354,7 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
         tree->in_check[ply+1]=1;
         tree->extended_reason[ply+1]=check_extension;
         tree->check_extensions_done++;
-        extensions+=(ply<=2*iteration_depth) ? incheck_depth : incheck_depth>>1;
+        extensions+=(full_extension) ? incheck_depth : incheck_depth>>1;
       }
       else {
         tree->in_check[ply+1]=0;
@@ -362,36 +363,31 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
 /*
  ----------------------------------------------------------
 |                                                          |
-|   now we toss in the "razoring" trick, which simply says |
-|   if we are doing fairly badly, we can reduce the depth  |
-|   an additional ply, if there was nothing at the current |
-|   ply that caused an extension.                          |
-|                                                          |
- ----------------------------------------------------------
-*/
-      if (depth<3*INCREMENT_PLY && depth>=2*INCREMENT_PLY &&
-          !tree->in_check[ply] && extensions == -60) {
-        register int value=-Evaluate(tree,ply+1,ChangeSide(wtm),
-                                     -(beta+51),-(alpha-51));
-        if (value+50 < alpha) extensions-=60;
-      }
-/*
- ----------------------------------------------------------
-|                                                          |
 |   if there's only one legal move, extend the search one  |
 |   additional ply since this node is very easy to search. |
 |                                                          |
  ----------------------------------------------------------
 */
       if (!moves_searched) {
-        if (tree->last[ply]-tree->last[ply-1] == 1) {
+        if (tree->in_check[ply] && tree->last[ply]-tree->last[ply-1] == 1) {
           tree->extended_reason[ply]|=one_reply_extension;
           tree->one_reply_extensions_done++;
-          extensions+=(ply<=2*iteration_depth) ? onerep_depth : onerep_depth>>1;
+          extensions+=(full_extension) ? onerep_depth : onerep_depth>>1;
         }
+/*
+ ----------------------------------------------------------
+|                                                          |
+|   now it is time to call Search()/Quiesce to find out if |
+|   this move is reasonable or not.                        |
+|                                                          |
+ ----------------------------------------------------------
+*/
         extensions=Min(extensions,0);
-        value=-ABSearch(tree,-beta,-alpha,ChangeSide(wtm),
+        if (depth+extensions >= INCPLY)
+          value=-Search(tree,-beta,-alpha,ChangeSide(wtm),
                         depth+extensions,ply+1,DO_NULL);
+        else
+          value=-Quiesce(tree,-beta,-alpha,ChangeSide(wtm),ply+1);
         if (abort_search || tree->stop) {
           UnMakeMove(tree,ply,tree->current_move[ply],wtm);
           return(0);
@@ -399,15 +395,21 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
       }
       else {
         extensions=Min(extensions,0);
-        value=-ABSearch(tree,-alpha-1,-alpha,ChangeSide(wtm),
+        if (depth+extensions >= INCPLY)
+          value=-Search(tree,-alpha-1,-alpha,ChangeSide(wtm),
                         depth+extensions,ply+1,DO_NULL);
+        else
+          value=-Quiesce(tree,-alpha-1,-alpha,ChangeSide(wtm),ply+1);
         if (abort_search || tree->stop) {
           UnMakeMove(tree,ply,tree->current_move[ply],wtm);
           return(0);
         }
         if (value>alpha && value<beta) {
-          value=-ABSearch(tree,-beta,-alpha,ChangeSide(wtm),
+          if (depth+extensions >= INCPLY)
+            value=-Search(tree,-beta,-alpha,ChangeSide(wtm),
                           depth+extensions,ply+1,DO_NULL);
+          else
+            value=-Quiesce(tree,-beta,-alpha,ChangeSide(wtm),ply+1);
           if (abort_search || tree->stop) {
             UnMakeMove(tree,ply,tree->current_move[ply],wtm);
             return(0);
@@ -418,7 +420,7 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
         if(value >= beta) {
           History(tree,ply,depth,wtm,tree->current_move[ply]);
           UnMakeMove(tree,ply,tree->current_move[ply],wtm);
-          StoreRefutation(tree,ply,depth,wtm,value,threat);
+          HashStore(tree,ply,depth,wtm,LOWER,value,threat);
           tree->fail_high++;
           if (!moves_searched) tree->fail_high_first++;
           return(value);
@@ -429,29 +431,27 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
     } else tree->nodes_searched++;
     UnMakeMove(tree,ply,tree->current_move[ply],wtm);
 #if defined(SMP)
-    if (smp_idle) {
-      if (moves_searched>0 && min_thread_depth<=depth && 
-        (!tree->in_check[ply] || tree->last[ply]-tree->last[ply-1]>1)) {
-        tree->alpha=alpha;
-        tree->beta=beta;
-        tree->value=value;
-        tree->wtm=wtm;
-        tree->ply=ply;
-        tree->depth=depth;
-        tree->threat=threat;
-        if(Thread(tree)) {
-          if (CheckInput()) Interrupt(ply);
-          value=tree->search_value;
-          if (value > alpha) {
-            if(value >= beta) {
-              History(tree,ply,depth,wtm,tree->current_move[ply]);
-              StoreRefutation(tree,ply,depth,wtm,value,threat);
-              tree->fail_high++;
-              return(value);
-            }
-            alpha=value;
-            break;
+    if (smp_idle && moves_searched && min_thread_depth<=depth) {
+      tree->alpha=alpha;
+      tree->beta=beta;
+      tree->value=alpha;
+      tree->wtm=wtm;
+      tree->ply=ply;
+      tree->depth=depth;
+      tree->threat=threat;
+      if(Thread(tree)) {
+        if (abort_search || tree->stop) return(0);
+        if (CheckInput()) Interrupt(ply);
+        value=tree->search_value;
+        if (value > alpha) {
+          if(value >= beta) {
+            History(tree,ply,depth,wtm,tree->current_move[ply]);
+            HashStore(tree,ply,depth,wtm,LOWER,value,threat);
+            tree->fail_high++;
+            return(value);
           }
+          alpha=value;
+          break;
         }
       }
     }
@@ -467,23 +467,23 @@ int Search(TREE *tree, int alpha, int beta, int wtm, int depth,
  ----------------------------------------------------------
 */
   if (moves_searched == 0) {
-    value=(Check(wtm)) ? -(MATE-ply) : DrawScore(root_wtm==wtm);
+    value=(Check(wtm)) ? -(MATE-ply) : DrawScore(ply&1);
     if (value>=alpha && value<beta) {
       SavePV(tree,ply,value,0);
-#if !defined(FAST)
+#if defined(TRACE)
       if (ply <= trace_level) printf("Search() no moves!  ply=%d\n",ply);
 #endif
     }
     return(value);
   }
   else {
-    if (alpha != initial_alpha) {
-      memcpy(&tree->pv[ply-1].path[ply],&tree->pv[ply].path[ply],(tree->pv[ply].path_length-ply+1)*4);
-      memcpy(&tree->pv[ply-1].path_hashed,&tree->pv[ply].path_hashed,3);
+    if (alpha != o_alpha) {
+      memcpy(&tree->pv[ply-1].path[ply],&tree->pv[ply].path[ply],(tree->pv[ply].pathl-ply+1)*4);
+      memcpy(&tree->pv[ply-1].pathh,&tree->pv[ply].pathh,3);
       tree->pv[ply-1].path[ply-1]=tree->current_move[ply-1];
       History(tree,ply,depth,wtm,tree->pv[ply].path[ply]);
     }
-    StoreBest(tree,ply,depth,wtm,alpha,initial_alpha,threat);
+    HashStore(tree,ply,depth,wtm,(alpha==o_alpha)?UPPER:EXACT,alpha,threat);
     return(alpha);
   }
 }
