@@ -5,7 +5,7 @@
 #include "data.h"
 #include "epdglue.h"
 
-/* modified 06/05/98 */
+/* modified 10/18/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -47,11 +47,11 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
 |                                                          |
  ----------------------------------------------------------
 */
-  while ((tree->current_phase[1]=NextRootMove(tree,wtm))) {
+  while ((tree->phase[1]=NextRootMove(tree,wtm))) {
     tree->extended_reason[1]=0;
-#if !defined(FAST)
+#if defined(TRACE)
     if (1 <= trace_level)
-      SearchTrace(tree,1,depth,wtm,alpha,beta,"SearchRoot",tree->current_phase[1]);
+      SearchTrace(tree,1,depth,wtm,alpha,beta,"SearchRoot",tree->phase[1]);
 #endif
 /*
  ----------------------------------------------------------
@@ -63,12 +63,7 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
 */
     extensions=-60;
     if (Piece(tree->current_move[1])==pawn &&
-        ((wtm && To(tree->current_move[1]) > H5 && TotalBlackPieces<16 &&
-         !And(mask_pawn_passed_w[To(tree->current_move[1])],BlackPawns)) ||
-        (!wtm && To(tree->current_move[1]) < A4 && TotalWhitePieces<16 &&
-         !And(mask_pawn_passed_b[To(tree->current_move[1])],WhitePawns)) ||
-        push_extensions[To(tree->current_move[1])]) &&
-        Swap(tree,From(tree->current_move[1]),To(tree->current_move[1]),wtm) >= 0) {
+      push_extensions[To(tree->current_move[1])]) {
       tree->extended_reason[1]|=passed_pawn_extension;
       tree->passed_pawn_extensions_done++;
       extensions+=pushpp_depth;
@@ -110,8 +105,11 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
     begin_root_nodes=tree->nodes_searched;
     extensions=Min(extensions,0);
     if (first_move) {
-      value=-ABSearch(tree,-beta,-alpha,ChangeSide(wtm),
+      if (depth+extensions >= INCPLY)
+        value=-Search(tree,-beta,-alpha,ChangeSide(wtm),
                       depth+extensions,2,DO_NULL);
+      else
+        value=-Quiesce(tree,-beta,-alpha,ChangeSide(wtm),2);
       if (abort_search) {
         UnMakeMove(tree,1,tree->current_move[1],wtm);
         return(alpha);
@@ -119,36 +117,67 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
       first_move=0;
     }
     else {
-      value=-ABSearch(tree,-alpha-1,-alpha,ChangeSide(wtm),
+      if (depth+extensions >= INCPLY)
+        value=-Search(tree,-alpha-1,-alpha,ChangeSide(wtm),
                       depth+extensions,2,DO_NULL);
+      else
+        value=-Quiesce(tree,-alpha-1,-alpha,ChangeSide(wtm),2);
       if (abort_search) {
         UnMakeMove(tree,1,tree->current_move[1],wtm);
         return(alpha);
       }
       if ((value > alpha) && (value < beta)) {
-        value=-ABSearch(tree,-beta,-alpha,ChangeSide(wtm),
-                        depth+extensions,2,DO_NULL);
+      if (depth+extensions >= INCPLY)
+        value=-Search(tree,-beta,-alpha,ChangeSide(wtm),
+                      depth+extensions,2,DO_NULL);
+      else
+        value=-Quiesce(tree,-beta,-alpha,ChangeSide(wtm),2);
         if (abort_search) {
           UnMakeMove(tree,1,tree->current_move[1],wtm);
           return(alpha);
         }
       }
     }
-    tree->root_nodes[root_move]=tree->nodes_searched-begin_root_nodes;
+    root_moves[tree->root_move].nodes=tree->nodes_searched-begin_root_nodes;
     if (value > alpha) {
       SearchOutput(tree,value,beta);
+      root_value=alpha;
       if(value >= beta) {
         History(tree,1,depth,wtm,tree->current_move[1]);
         UnMakeMove(tree,1,tree->current_move[1],wtm);
-        StoreRefutation(tree,1,depth,wtm,value,0);
         return(value);
       }
       alpha=value;
-      root_value=alpha;
-      beta=alpha+30;
+      beta=value+40;
       root_beta=beta;
     }
+    root_value=alpha;
     UnMakeMove(tree,1,tree->current_move[1],wtm);
+#if defined(SMP)
+    if (split_at_root && smp_idle && NextRootMoveParallel()) {
+      tree->alpha=alpha;
+      tree->beta=beta;
+      tree->value=alpha;
+      tree->wtm=wtm;
+      tree->ply=1;
+      tree->depth=depth;
+      tree->threat=0;
+      if(Thread(tree)) {
+        if (abort_search || tree->stop) return(0);
+        if (CheckInput()) Interrupt(1);
+        value=tree->search_value;
+        if (value > alpha) {
+          if(value >= beta) {
+            History(tree,1,depth,wtm,tree->current_move[1]);
+            tree->fail_high++;
+            return(value);
+          }
+          alpha=value;
+          break;
+        }
+      }
+    }
+#endif
   }
 /*
  ----------------------------------------------------------
@@ -159,24 +188,22 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
 |                                                          |
  ----------------------------------------------------------
 */
-  if (abort_search) return(0);
+  if (abort_search || time_abort) return(0);
   if (first_move == 1) {
-    value=(Check(wtm)) ? -(MATE-1) : DrawScore(root_wtm==wtm);
+    value=(Check(wtm)) ? -(MATE-1) : DrawScore(1);
     if (value >=alpha && value <beta) {
-      SavePVS(tree,1,value,0);
-#if !defined(FAST)
+      tree->pv[0].pathl=0;
+      tree->pv[0].pathh=0;
+      tree->pv[0].pathd=iteration_depth;
+      SearchOutput(tree,value,beta);
+#if defined(TRACE)
       if (1 <= trace_level) printf("Search() no moves!  ply=1\n");
 #endif
     }
     return(value);
   }
   else {
-    if (alpha != initial_alpha) {
-      memcpy(&tree->pv[0].path[1],&tree->pv[1].path[1],(tree->pv[1].path_length)*4);
-      memcpy(&tree->pv[0].path_hashed,&tree->pv[1].path_hashed,3);
-      History(tree,1,depth,wtm,tree->pv[1].path[1]);
-    }
-    StoreBest(tree,1,depth,wtm,alpha,initial_alpha,0);
+    History(tree,1,depth,wtm,tree->pv[1].path[1]);
     return(alpha);
   }
 }
@@ -194,13 +221,10 @@ int SearchRoot(TREE *tree, int alpha, int beta, int wtm, int depth) {
 *                                                                              *
 ********************************************************************************
 */
-void SearchOutput(TREE *tree, int value, int bound)
-{
-#define PrintOK() (tree->nodes_searched>noise_level || value>(MATE-100))
-  register int *mv, *mvp;
+void SearchOutput(TREE *tree, int value, int bound) {
   register int wtm;
-  int temp_root_nodes;
-
+  int i;
+  ROOT_MOVE temp_rm;
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -210,19 +234,18 @@ void SearchOutput(TREE *tree, int value, int bound)
 |                                                          |
  ----------------------------------------------------------
 */
+  root_print_ok=root_print_ok || tree->nodes_searched>noise_level ||
+                abs(value)>MATE-300;
   wtm=root_wtm;
   if (!abort_search) {
     whisper_value=(analyze_mode && !root_wtm) ? -value : value;
     whisper_depth=iteration_depth;
-    for (mvp=tree->last[0];mvp<tree->last[1];mvp++) if(tree->current_move[1]== *mvp) break;
-    if (mvp != tree->last[0]) {
-      temp_root_nodes=tree->root_nodes[mvp-tree->last[0]];
-      for (mv=mvp;mv>tree->last[0];mv--) {
-        *mv=*(mv-1);
-        tree->root_nodes[mv-tree->last[0]]=tree->root_nodes[mv-1-tree->last[0]];
-      }
-      tree->root_nodes[0]=temp_root_nodes;
-      *tree->last[0]=tree->current_move[1];
+    for (i=0;i<n_root_moves;i++)
+      if (tree->current_move[1] == root_moves[i].move) break;
+    if (i < n_root_moves) {
+      temp_rm=root_moves[i];
+      for (;i>0;i--) root_moves[i]=root_moves[i-1];
+      root_moves[0]=temp_rm;
       easy_move=0;
     }
     end_time=ReadClock(time_type);
@@ -240,7 +263,7 @@ void SearchOutput(TREE *tree, int value, int bound)
       MakeMove(tree,1,tree->pv[1].path[1],root_wtm);
     }
     else {
-      if (PrintOK()) {
+      if (root_print_ok) {
         Print(2,"               %2i   %s     ++   ",iteration_depth,
         DisplayTime(end_time-start_time));
         UnMakeMove(tree,1,tree->current_move[1],wtm);
@@ -256,16 +279,18 @@ void SearchOutput(TREE *tree, int value, int bound)
                 OutputMove(tree,tree->current_move[1],1,wtm));
         MakeMove(tree,1,tree->current_move[1],wtm);
         Whisper(6,iteration_depth,end_time-start_time,whisper_value,
-                tree->nodes_searched,-1,whisper_text);
+                tree->nodes_searched,-1, tree->egtb_probes_successful,
+                whisper_text);
       }
       if (tree->current_move[1] != tree->pv[1].path[1]) {
         tree->pv[1].path[1]=tree->current_move[1];
-        tree->pv[1].path_length=1;
-        tree->pv[1].path_hashed=0;
-        tree->pv[1].path_iteration_depth=iteration_depth;
+        tree->pv[1].pathl=1;
+        tree->pv[1].pathh=0;
+        tree->pv[1].pathd=iteration_depth;
       }
     }
     tree->pv[0]=tree->pv[1];
+    local[0]->pv[0]=tree->pv[1];
   }
 }
 
@@ -279,20 +304,16 @@ void SearchOutput(TREE *tree, int value, int bound)
 ********************************************************************************
 */
 void SearchTrace(TREE *tree, int ply, int depth, int wtm,
-                 int alpha, int beta, char* name, int phase)
-{
+                 int alpha, int beta, char* name, int phase) {
   int i;
-#if defined(SMP)
   Lock(lock_io);
-#endif
   for (i=1;i<ply;i++) printf("  ");
-  printf("%d  %s d:%5.2f [%s,",ply,OutputMove(tree,tree->current_move[ply],ply,wtm),
-         (float) depth/ (float) INCREMENT_PLY,DisplayEvaluation(alpha));
+  printf("%d  %s d:%5.2f [%s,",
+         ply,OutputMove(tree,tree->current_move[ply],ply,wtm),
+         (float) depth/ (float) INCPLY,DisplayEvaluation(alpha));
   printf("%s] n:%d %s(%d)", DisplayEvaluation(beta),
          (tree->nodes_searched),name,phase);
   if (max_threads > 1) printf(" (t=%d) ",tree->thread_id);
   printf("\n");
-#if defined(SMP)
   UnLock(lock_io);
-#endif
 }
