@@ -4,7 +4,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 05/13/97 */
+/* last modified 05/03/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -23,7 +23,7 @@
 *                                                                              *
 *   the following input will setup the board position that given below:        *
 *                                                                              *
-*         K2R/PPP////q/5ppp/7k/ b                                              *
+*         K2R/PPP////q/5ppp/7k/ b - -                                          *
 *                                                                              *
 *   this assumes that k represents a white king and -q represents a black      *
 *   queen.                                                                     *
@@ -45,16 +45,18 @@
 *                                                                              *
 ********************************************************************************
 */
-void SetBoard(int nargs, char *args[], int special)
-{
+void SetBoard(int nargs, char *args[], int special) {
   int twtm, i, match, num, pos, square, tboard[64];
   int bcastle, ep, wcastle;
   char input[80];
-  char bdinfo[] = {'q','r','b','*','k','n','p','*','P','N','K','*','B','R',
-                   'Q','*', '1','2','3','4','5','6','7','8','/'};
-  char status[13]={'K','Q','k','q','a','b','c','d','e','f','g','h',' '};
-  int whichsq, firstsq[8]={56,48,40,32,24,16,8,0};
-  TREE *tree=local[0];
+  static const char bdinfo[] = {'q','r','b','*','k','n','p','*','P','N',
+                                'K','*','B','R', 'Q','*','1','2','3','4',
+                                '5','6','7','8','/'};
+  static const char status[13]={'K','Q','k','q','a','b','c','d','e','f','g',
+                                'h',' '};
+  int whichsq;
+  static const int firstsq[8]={56,48,40,32,24,16,8,0};
+  TREE * const tree=local[0];
 
   if (special)
     strcpy(input,initial_position);
@@ -81,8 +83,8 @@ void SetBoard(int nargs, char *args[], int special)
 */
     else if (match == 24) {
       num=0;
+      if (whichsq > 6) break;
       square=firstsq[++whichsq];
-      if (whichsq > 7) break;
     }
 /*
    "1-8" -> empty squares.
@@ -138,32 +140,44 @@ void SetBoard(int nargs, char *args[], int special)
  ----------------------------------------------------------
 */
   if (nargs>2 && strlen(args[2])) {
-    if (args[2][0]>='a' && args[2][0]<='h' &&
-        args[2][1]>'0' && args[2][1]<'9') {
-      ep=(args[2][1]-'1')*8+args[2][0]-'a';
-      pos++;
-    }
-    else for (pos=0;pos<(int) strlen(args[2]);pos++) {
-      for (match=0;(match<13) && (args[2][pos]!=status[match]);match++);
-      if (match == 0) wcastle+=1;
-      else if (match == 1) wcastle+=2;
-      else if (match == 2) bcastle+=1;
-      else if (match == 3) bcastle+=2;
-      else if (args[2][0]!='-') printf("castling status is bad.\n");
+    if (strcmp(args[2],"-")) {
+      for (pos=0;pos<(int) strlen(args[2]);pos++) {
+        for (match=0;(match<13) && (args[2][pos]!=status[match]);match++);
+        if (match == 0) wcastle+=1;
+        else if (match == 1) wcastle+=2;
+        else if (match == 2) bcastle+=1;
+        else if (match == 3) bcastle+=2;
+        else if (args[2][0]!='-') printf("castling status is bad.\n");
+      }
     }
   }
   if (nargs>3 && strlen(args[3])) {
-    if (args[3][0]>='a' && args[3][0]<='h' &&
-        args[3][1]>'0' && args[3][1]<'9') {
-      ep=(args[3][1]-'1')*8+args[3][0]-'a';
-      pos++;
+    if (strcmp(args[3],"-")) {
+      if (args[3][0]>='a' && args[3][0]<='h' &&
+          args[3][1]>'0' && args[3][1]<'9') {
+        ep=(args[3][1]-'1')*8+args[3][0]-'a';
+      }
+      else if (args[3][0]!='-') printf("enpassant status is bad.\n");
     }
-    else if (args[3][0]!='-') printf("enpassant status is bad.\n");
   }
-  for (i=0;i<64;i++) PieceOnSquare(i)=tboard[i];
+  for (i=0;i<64;i++) PcOnSq(i)=tboard[i];
   WhiteCastle(0)=wcastle;
   BlackCastle(0)=bcastle;
-  EnPassant(0)=ep;
+  EnPassant(0)=0;
+  if (ep) {
+    if (Rank(ep) == RANK6) {
+      if (PcOnSq(ep-8) != -pawn) ep=0;
+    }
+    else if (Rank(ep) == RANK3) {
+      if (PcOnSq(ep+8) != pawn) ep=0;
+    }
+    else ep=0;
+    if (!ep) {
+      printf("enpassant status is bad (must be on 3rd/6th rank only.\n");
+      ep=0;
+    }
+    EnPassant(0)=ep;
+  }
   Rule50Moves(0)=0;
 /*
  ----------------------------------------------------------
@@ -174,19 +188,19 @@ void SetBoard(int nargs, char *args[], int special)
 |                                                          |
  ----------------------------------------------------------
 */
-  if (((WhiteCastle(0) & 2) && (PieceOnSquare(A1) != rook)) ||
-      ((WhiteCastle(0) & 1) && (PieceOnSquare(H1) != rook)) ||
-      ((BlackCastle(0) & 2) && (PieceOnSquare(A8) != -rook)) ||
-      ((BlackCastle(0) & 1) && (PieceOnSquare(H8) != -rook))) {
+  if (((WhiteCastle(0) & 2) && (PcOnSq(A1) != rook)) ||
+      ((WhiteCastle(0) & 1) && (PcOnSq(H1) != rook)) ||
+      ((BlackCastle(0) & 2) && (PcOnSq(A8) != -rook)) ||
+      ((BlackCastle(0) & 1) && (PcOnSq(H8) != -rook))) {
     printf("ERROR-- castling status does not match board position\n");
     InitializeChessBoard(&tree->position[0]);
   }
-  if ((twtm && EnPassant(0) && (PieceOnSquare(EnPassant(0)+8) != -pawn) &&
-       (PieceOnSquare(EnPassant(0)-7) != pawn) &&
-       (PieceOnSquare(EnPassant(0)-9) != pawn)) ||
-      (ChangeSide(twtm) && EnPassant(0) && (PieceOnSquare(EnPassant(0)-8) != pawn) &&
-       (PieceOnSquare(EnPassant(0)+7) != -pawn) &&
-       (PieceOnSquare(EnPassant(0)+9) != -pawn))) {
+  if ((twtm && EnPassant(0) && (PcOnSq(EnPassant(0)+8) != -pawn) &&
+       (PcOnSq(EnPassant(0)-7) != pawn) &&
+       (PcOnSq(EnPassant(0)-9) != pawn)) ||
+      (ChangeSide(twtm) && EnPassant(0) && (PcOnSq(EnPassant(0)-8) != pawn) &&
+       (PcOnSq(EnPassant(0)+7) != -pawn) &&
+       (PcOnSq(EnPassant(0)+9) != -pawn))) {
     EnPassant(0)=0;
   }
   SetChessBitBoards(&tree->position[0]);
@@ -203,13 +217,13 @@ void SetBoard(int nargs, char *args[], int special)
       history_b[i]=0;
     }
     for (i=0;i<MAXPLY;i++) {
-      tree->killer_move1[i]=0;
-      tree->killer_move2[i]=0;
+      tree->killers[i].move1=0;
+      tree->killers[i].move2=0;
     }
-    last_pv.path_iteration_depth=0;
-    last_pv.path_length=0;
-    tree->pv[0].path_iteration_depth=0;
-    tree->pv[0].path_length=0;
+    last_pv.pathd=0;
+    last_pv.pathl=0;
+    tree->pv[0].pathd=0;
+    tree->pv[0].pathl=0;
     moves_out_of_book=0;
     largest_positional_score=100;
     opening=0;
