@@ -3,7 +3,7 @@
 #include "chess.h"
 #include "data.h"
 
-/* last modified 03/07/97 */
+/* last modified 06/29/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -24,8 +24,7 @@
 *                                                                              *
 ********************************************************************************
 */
-int Swap(TREE *tree, int source, int target, int wtm)
-{
+int Swap(TREE *tree, int source, int target, int wtm) {
   register BITBOARD attacks;
   register int attacked_piece;
   register int square, direction;
@@ -35,19 +34,13 @@ int Swap(TREE *tree, int source, int target, int wtm)
  ----------------------------------------------------------
 |                                                          |
 |   determine which squares attack <target> for each side. |
+|   initialize by placing the piece on <target> first in   |
+|   the list as it is being captured to start things off.  |
 |                                                          |
  ----------------------------------------------------------
 */
   attacks=AttacksTo(tree,target);
-/*
- ----------------------------------------------------------
-|                                                          |
-|   initialize by placing the piece on <target> first in   |
-| the list as it is being captured to start things off.    |
-|                                                          |
- ----------------------------------------------------------
-*/
-  attacked_piece=p_values[PieceOnSquare(target)+7];
+  attacked_piece=p_values[PcOnSq(target)+7];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -59,7 +52,7 @@ int Swap(TREE *tree, int source, int target, int wtm)
   color=ChangeSide(wtm);
   swap_list[0]=attacked_piece;
   sign=-1;
-  attacked_piece=p_values[PieceOnSquare(source)+7];
+  attacked_piece=p_values[PcOnSq(source)+7];
   Clear(source,attacks);
   direction=directions[target][source];
   if (direction) attacks=SwapXray(tree,attacks,source,direction);
@@ -75,32 +68,32 @@ int Swap(TREE *tree, int source, int target, int wtm)
 */
   while (attacks) {
     if (color) {
-      if (And(WhitePawns,attacks))
-        square=FirstOne(And(WhitePawns,attacks));
-      else if (And(WhiteKnights,attacks))
-        square=FirstOne(And(WhiteKnights,attacks));
-      else if (And(WhiteBishops,attacks))
-        square=FirstOne(And(WhiteBishops,attacks));
-      else if (And(WhiteRooks,attacks))
-        square=FirstOne(And(WhiteRooks,attacks));
-      else if (And(WhiteQueens,attacks))
-        square=FirstOne(And(WhiteQueens,attacks));
-      else if (And(WhiteKing,attacks))
+      if (WhitePawns & attacks)
+        square=FirstOne(WhitePawns & attacks);
+      else if (WhiteKnights & attacks)
+        square=FirstOne(WhiteKnights & attacks);
+      else if (WhiteBishops & attacks)
+        square=FirstOne(WhiteBishops & attacks);
+      else if (WhiteRooks & attacks)
+        square=FirstOne(WhiteRooks & attacks);
+      else if (WhiteQueens & attacks)
+        square=FirstOne(WhiteQueens & attacks);
+      else if (WhiteKing & attacks)
         square=WhiteKingSQ;
       else break;
     }
     else {
-      if (And(BlackPawns,attacks))
-        square=FirstOne(And(BlackPawns,attacks));
-      else if (And(BlackKnights,attacks))
-        square=FirstOne(And(BlackKnights,attacks));
-      else if (And(BlackBishops,attacks))
-        square=FirstOne(And(BlackBishops,attacks));
-      else if (And(BlackRooks,attacks))
-        square=FirstOne(And(BlackRooks,attacks));
-      else if (And(BlackQueens,attacks))
-        square=FirstOne(And(BlackQueens,attacks));
-      else if (And(BlackKing,attacks))
+      if (BlackPawns & attacks)
+        square=FirstOne(BlackPawns & attacks);
+      else if (BlackKnights & attacks)
+        square=FirstOne(BlackKnights & attacks);
+      else if (BlackBishops & attacks)
+        square=FirstOne(BlackBishops & attacks);
+      else if (BlackRooks & attacks)
+        square=FirstOne(BlackRooks & attacks);
+      else if (BlackQueens & attacks)
+        square=FirstOne(BlackQueens & attacks);
+      else if (BlackKing & attacks)
         square=BlackKingSQ;
       else break;
     }
@@ -115,7 +108,7 @@ int Swap(TREE *tree, int source, int target, int wtm)
  ------------------------------------------------
 */
     swap_list[next_capture]=swap_list[next_capture-1]+sign*attacked_piece;
-    attacked_piece=p_values[PieceOnSquare(square)+7];
+    attacked_piece=p_values[PcOnSq(square)+7];
     Clear(square,attacks);
     direction=directions[target][square];
     if (direction) attacks=SwapXray(tree,attacks,square,direction);
@@ -160,33 +153,24 @@ int Swap(TREE *tree, int source, int target, int wtm)
 *                                                                              *
 ********************************************************************************
 */
-BITBOARD SwapXray(TREE *tree, BITBOARD attacks, int from, int direction)
-{
+BITBOARD SwapXray(TREE *tree, BITBOARD attacks, int from, int direction) {
   switch (direction) {
   case 1: 
-    return(Or(attacks,
-              And(And(AttacksRank(from),RooksQueens),plus1dir[from])));
+    return(attacks | (AttacksRank(from) & RooksQueens & plus1dir[from]));
   case 7: 
-    return(Or(attacks,
-              And(And(AttacksDiaga1(from),BishopsQueens),plus7dir[from])));
+    return(attacks | (AttacksDiaga1(from) & BishopsQueens & plus7dir[from]));
   case 8: 
-    return(Or(attacks,
-              And(And(AttacksFile(from),RooksQueens),plus8dir[from])));
+    return(attacks | (AttacksFile(from) & RooksQueens & plus8dir[from]));
   case 9: 
-    return(Or(attacks,
-              And(And(AttacksDiagh1(from),BishopsQueens),plus9dir[from])));
+    return(attacks | (AttacksDiagh1(from) & BishopsQueens & plus9dir[from]));
   case -1: 
-    return(Or(attacks,
-              And(And(AttacksRank(from),RooksQueens),minus1dir[from])));
+    return(attacks | (AttacksRank(from) & RooksQueens & minus1dir[from]));
   case -7: 
-    return(Or(attacks,
-              And(And(AttacksDiaga1(from),BishopsQueens),minus7dir[from])));
+    return(attacks | (AttacksDiaga1(from) & BishopsQueens & minus7dir[from]));
   case -8: 
-    return(Or(attacks,
-              And(And(AttacksFile(from),RooksQueens),minus8dir[from])));
+    return(attacks | (AttacksFile(from) & RooksQueens & minus8dir[from]));
   case -9: 
-    return(Or(attacks,
-              And(And(AttacksDiagh1(from),BishopsQueens),minus9dir[from])));
+    return(attacks | (AttacksDiagh1(from) & BishopsQueens & minus9dir[from]));
   }
   return(attacks);
 }
