@@ -32,15 +32,14 @@
 *                                                                              *
 ********************************************************************************
 */
-void Test(char *filename)
-{
+void Test(char *filename) {
   FILE *test_input;
   int i, move, right=0, wrong=0, correct;
   int time=0, len;
   double nodes=0.0;
   char *eof;
   float avg_depth=0.0;
-  TREE *tree=local[0];
+  TREE * const tree=local[0];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -87,10 +86,10 @@ void Test(char *filename)
       Print(4095,"!\n");
       Print(4095,"======================================================================\n");
     }
-    else if (!strcmp(args[0],"setboard")) {
-      SetBoard(nargs-1,args+1,0);
+    else if (strcmp(args[0],"solution")) {
+      Option(tree);
     }
-    else if (!strcmp(args[0],"solution")) {
+    else {
       number_of_solutions=0;
       solution_type=0;
       Print(4095,"solution ");
@@ -114,7 +113,7 @@ void Test(char *filename)
       }
       Print(4095,"\n");
       InitializeHashTables();
-      last_pv.path_iteration_depth=0;
+      last_pv.pathd=0;
       largest_positional_score=100;
       thinking=1;
       tree->position[1]=tree->position[0];
@@ -153,14 +152,14 @@ void Test(char *filename)
   if (right+wrong) {
     Print(4095,"\n\n\n");
     Print(4095,"test results summary:\n\n");
-    Print(4095,"total positions searched..........%10d\n",right+wrong);
-    Print(4095,"number right......................%10d\n",right);
-    Print(4095,"number wrong......................%10d\n",wrong);
-    Print(4095,"percentage right..................%10d\n",right*100/(right+wrong));
-    Print(4095,"percentage wrong..................%10d\n",wrong*100/(right+wrong));
-    Print(4095,"total nodes searched..............%10.1f\n",nodes);
-    Print(4095,"average search depth..............%10.1f\n",avg_depth/(right+wrong));
-    Print(4095,"nodes per second..................%10d\n",(int) ((float) nodes/(float) time*100.0));
+    Print(4095,"total positions searched..........%12d\n",right+wrong);
+    Print(4095,"number right......................%12d\n",right);
+    Print(4095,"number wrong......................%12d\n",wrong);
+    Print(4095,"percentage right..................%12d\n",right*100/(right+wrong));
+    Print(4095,"percentage wrong..................%12d\n",wrong*100/(right+wrong));
+    Print(4095,"total nodes searched..............%12.1f\n",nodes);
+    Print(4095,"average search depth..............%12.1f\n",avg_depth/(right+wrong));
+    Print(4095,"nodes per second..................%12d\n",(int) ((float) nodes/(float) time*100.0));
   }
   input_stream=stdin;
   early_exit=99;
