@@ -15,8 +15,7 @@
 *                                                                              *
 ********************************************************************************
 */
-void TimeAdjust(int time_used, PLAYER player)
-{
+void TimeAdjust(int time_used, PLAYER player) {
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -47,7 +46,7 @@ void TimeAdjust(int time_used, PLAYER player)
   }
 }
 
-/* last modified 06/15/98 */
+/* last modified 06/04/99 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -62,12 +61,11 @@ void TimeAdjust(int time_used, PLAYER player)
 *                                                                              *
 ********************************************************************************
 */
-int TimeCheck(int abort)
-{
+int TimeCheck(int abort) {
   int time_used;
-  int value, last_value, searched;
-  int *i, ndone;
-  TREE *tree=local[0];
+  int value, last_value;
+  int i, ndone;
+  TREE * const tree=local[0];
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -78,11 +76,12 @@ int TimeCheck(int abort)
 |                                                          |
  ----------------------------------------------------------
 */
-  if (tree->last[0]==(tree->last[1]-1) && !booking && !annotate_mode &&
+  if (search_nodes && tree->nodes_searched > search_nodes) return(1);
+  if (n_root_moves==1 && !booking && !annotate_mode &&
       !pondering && iteration_depth>4) return(1);
   ndone=0;
-  for (i=tree->last[0];i<tree->last[1];i++)
-    if (tree->searched_this_root_move[i-tree->last[0]]) ndone++;
+  for (i=0;i<n_root_moves;i++)
+    if (root_moves[i].status&128) ndone++;
   if (ndone == 1) abort=1;
   if (iteration_depth <= 2) return(0);
 /*
@@ -95,10 +94,9 @@ int TimeCheck(int abort)
  ----------------------------------------------------------
 */
   time_used=(ReadClock(time_type)-start_time);
-  if (tree->nodes_searched>noise_level && (display_options&32) && time_used>burp) {
-#if defined(SMP)
+  if (tree->nodes_searched>noise_level &&
+      display_options&32 && time_used>burp) {
     Lock(lock_io);
-#endif
 #if defined(MACOS)
     printf("               %2i   %s\n",iteration_depth,DisplayTime(time_used));
 #else
@@ -106,9 +104,7 @@ int TimeCheck(int abort)
 #endif
     burp=(time_used/1500)*1500+1500;
     fflush(stdout);
-#if defined(SMP)
     UnLock(lock_io);
-#endif
   }
   if (pondering || analyze_mode) return(0);
   if (time_used > absolute_time_limit) return(1);
@@ -129,12 +125,8 @@ int TimeCheck(int abort)
 |                                                          |
  ----------------------------------------------------------
 */
-  if ((root_value == root_alpha) && !search_failed_low) {
-    searched=0;
-    for (i=tree->last[0];i<tree->last[1];i++)
-      if (tree->searched_this_root_move[i-tree->last[0]]) searched++;
-    if (searched == 1) return(1);
-  }
+  if (root_value==root_alpha && !(root_moves[0].status&1) &&
+      ndone==1) return(1);
 /*
  ----------------------------------------------------------
 |                                                          |
@@ -149,8 +141,8 @@ int TimeCheck(int abort)
 */
   value=root_value;
   last_value=last_search_value;
-  if ((value>=last_value-33 && !search_failed_low) ||
-      (value>350 && value >= last_value-67)) {
+  if ((value>=last_value-24 && !(root_moves[0].status&1)) ||
+      (value>350 && value >= last_value-50)) {
     if (time_used > time_limit*2) return(1);
     else return(abort);
   }
@@ -166,7 +158,7 @@ int TimeCheck(int abort)
  ----------------------------------------------------------
 */
   if (time_used < time_limit*2.5 && time_used+500<tc_time_remaining) return(0);
-  if ((value >= last_value-67 && !search_failed_low) ||
+  if ((value >= last_value-67 && !(root_moves[0].status&1)) ||
       value>550) return(abort);
 /*
  ----------------------------------------------------------
@@ -182,7 +174,7 @@ int TimeCheck(int abort)
   return(1);
 }
 
-/* last modified 10/17/97 */
+/* last modified 01/04/98 */
 /*
 ********************************************************************************
 *                                                                              *
@@ -194,10 +186,9 @@ int TimeCheck(int abort)
 *                                                                              *
 ********************************************************************************
 */
-void TimeSet(int search_type)
-{
-  float behind[6] = {32.0, 16.0, 8.0, 4.0, 2.0, 1.5};
-  int reduce[6] = {96, 48, 24, 12, 6, 3};
+void TimeSet(int search_type) {
+  static const float behind[6] = {32.0, 16.0, 8.0, 4.0, 2.0, 1.5};
+  static const int reduce[6] = {96, 48, 24, 12, 6, 3};
   int i;
   int surplus, average;
   int simple_average;
@@ -215,14 +206,14 @@ void TimeSet(int search_type)
 */
   if (tc_sudden_death == 1) {
     if (tc_increment) {
-      time_limit=(tc_time_remaining-tc_operator_time*tc_moves_remaining)/30+
+      time_limit=(tc_time_remaining-tc_operator_time*tc_moves_remaining)/35+
                  tc_increment;
       if (tc_time_remaining < 3000) time_limit=tc_increment;
       if (tc_time_remaining < 1500) time_limit=tc_increment/2;
       absolute_time_limit=tc_time_remaining/2;
     }
     else {
-      time_limit=tc_time_remaining/35;
+      time_limit=tc_time_remaining/40;
       absolute_time_limit=Min(time_limit*6,tc_time_remaining/2);
     }
   }
@@ -281,7 +272,7 @@ void TimeSet(int search_type)
 |                                                          |
  ----------------------------------------------------------
 */
-  if (mode!=tournament_mode && !tc_increment) {
+  if (mode!=tournament_mode && !computer_opponent) {
     for (i=0;i<6;i++) {
       if ((float)tc_time_remaining*behind[i] <
           (float)tc_time_remaining_opponent) {
@@ -334,5 +325,4 @@ void TimeSet(int search_type)
     time_limit= 1;
     usage_level=0;
   }
-
 }
